package com.up.mls.config;

import java.io.IOException;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.http.HttpStatus;
import org.codehaus.jackson.JsonGenerationException;
import org.codehaus.jackson.map.JsonMappingException;
import org.codehaus.jackson.map.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClient;
import com.aliyun.oss.OSSClientBuilder;
import com.aliyun.oss.model.ObjectMetadata;
import com.aliyun.oss.model.PutObjectResult;
import com.google.common.collect.Maps;
import com.up.mls.util.Ret;

@Controller
@RequestMapping("oss")
public class AliOssUploadController {
	private static final Logger log = LoggerFactory.getLogger(AliOssUploadController.class);
	@Autowired
	HttpServletRequest request;
	@Autowired
	HttpServletResponse response;

	@Autowired
	AliyunOssConfig aliyunOssConfig;
	@Autowired
	AliyunOssVideoConfig aliyunOssVideoConfig;

	@RequestMapping("policy")
	public @ResponseBody Map<String, String> getSign() {
		return aliyunOssConfig.getSig(aliyunOssConfig.getBucket(), aliyunOssConfig.getEndpoint(),
				aliyunOssConfig.getAccessId(), aliyunOssConfig.getAccessKey(), aliyunOssConfig.getDir());
	}
	
	@RequestMapping("policyVideo")
	public @ResponseBody Map<String, String> getSignForVideo() {
		return aliyunOssVideoConfig.getSig(aliyunOssVideoConfig.getBucket(), aliyunOssVideoConfig.getEndpoint(),
				aliyunOssVideoConfig.getAccessId(), aliyunOssVideoConfig.getAccessKey(), aliyunOssVideoConfig.getDir());
	}

	@PostMapping("callBack")
	public @ResponseBody Map<String, String> getCallBack()
			throws JsonGenerationException, JsonMappingException, IOException {
		String fileName = request.getParameter("filename");
		String size = request.getParameter("size");
		String mimeType = request.getParameter("mimeType");
		Map<String, String> map = Maps.newHashMap();
		map.put("fileName", fileName);
		map.put("size", size);
		map.put("mimeType", mimeType);
		log.info(new ObjectMapper().writeValueAsString(map));
		response.setStatus(HttpServletResponse.SC_OK);
		return map;
	}

	@GetMapping("delObject")
	public @ResponseBody Map<?, ?> delObject(String objectKey) {
		Map<String, Object> map = Maps.newHashMap();
		try {
			OSS ossClient = new OSSClientBuilder().build(aliyunOssConfig.getEndpoint(), aliyunOssConfig.getAccessId(),
					aliyunOssConfig.getAccessKey());
			boolean found = ossClient.doesObjectExist(aliyunOssConfig.getBucket(), objectKey);
			if (found) {
				ossClient.deleteObject(aliyunOssConfig.getBucket(), objectKey);
			}
			ossClient.shutdown();
			map.put("code", HttpStatus.SC_OK);
		} catch (Exception e) {
			map.put("code", HttpStatus.SC_INTERNAL_SERVER_ERROR);
		}
		return map;
	}
	
	
	@GetMapping("delVideo")
	public @ResponseBody Map<?, ?> delVideo(String objectKey) {
		Map<String, Object> map = Maps.newHashMap();
		try {
			OSS ossClient = new OSSClientBuilder().build(aliyunOssVideoConfig.getEndpoint(), aliyunOssVideoConfig.getAccessId(),
					aliyunOssVideoConfig.getAccessKey());
			boolean found = ossClient.doesObjectExist(aliyunOssVideoConfig.getBucket(), objectKey);
			if (found) {
				ossClient.deleteObject(aliyunOssVideoConfig.getBucket(), objectKey);
			}
			ossClient.shutdown();
			map.put("code", HttpStatus.SC_OK);
		} catch (Exception e) {
			map.put("code", HttpStatus.SC_INTERNAL_SERVER_ERROR);
		}
		return map;
	}
	
	/**
	 * 流方式上传
	 * @param files
	 * @return
	 * @throws IOException 
	 */
	@ResponseBody
	@PostMapping("uploads")
	public String uploads(@RequestParam("imgFile") MultipartFile files) throws IOException {
		OSSClient ossClient = new OSSClient(aliyunOssConfig.getEndpoint(), aliyunOssConfig.getAccessId(),
				aliyunOssConfig.getAccessKey());
		InputStream is = files.getInputStream();
		ObjectMetadata meta = new ObjectMetadata();
		meta.setContentType("image/jpeg");
		meta.setHeader("Access-Control-Allow-Origin", "*");
		String fileName = System.currentTimeMillis() + ".png";
		// 存储路径
		SimpleDateFormat format = new SimpleDateFormat("yyyy/MM/dd");
		String date = format.format(new Date());
		String filePath = ossFilePath(aliyunOssConfig.getDir() + date + "/", fileName);
		ossClient.putObject(aliyunOssConfig.getBucket(), filePath, is, meta);
		String url = "https://up-img.oss-cn-beijing.aliyuncs.com/" + filePath;
		System.out.println(url);
		return Ret.ok("msg",url);
	}

	public static String ossFilePath(String path, String filename) {
		String filepath = path + filename;
		return filepath;
	}
}
