package com.up.mls.config;


import java.time.Duration;

import org.redisson.Redisson;
import org.redisson.api.RedissonClient;
import org.redisson.config.Config;
import org.springframework.boot.autoconfigure.cache.CacheProperties;
import org.springframework.boot.autoconfigure.data.redis.RedisProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.cache.RedisCacheConfiguration;
import org.springframework.data.redis.connection.RedisConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.Jackson2JsonRedisSerializer;
import org.springframework.data.redis.serializer.StringRedisSerializer;
import org.springframework.data.redis.serializer.RedisSerializationContext.SerializationPair;


@Configuration
public class RedisConfig {
	@Bean
	public RedisTemplate<String, Object> redisTemplate(RedisConnectionFactory factory) {
		RedisTemplate<String, Object> template = new RedisTemplate<String, Object>();
		template.setConnectionFactory(factory);
		template.setKeySerializer(new StringRedisSerializer());
		template.setValueSerializer(template.getKeySerializer());
		template.setDefaultSerializer(template.getKeySerializer());
		template.setEnableDefaultSerializer(true);
		template.afterPropertiesSet();
		return template;
	}

	
	
	@Bean 
	public RedisCacheConfiguration RedisCacheConfiguration(){
		RedisCacheConfiguration defaultCacheConfig = RedisCacheConfiguration.defaultCacheConfig()
				.serializeValuesWith(SerializationPair.fromSerializer(new Jackson2JsonRedisSerializer<>(Object.class)))
				.entryTtl(Duration.ofSeconds(300));
        return defaultCacheConfig;
	}

	@Bean(destroyMethod = "shutdown")
	public RedissonClient redissonClient(RedisProperties redisProperties) throws Exception {
		RedissonClient redisson;
		Config config = new Config();
		String address = String.format("redis://%s:%s", redisProperties.getHost(), redisProperties.getPort());
		System.out.println("redis : ");
		config.useSingleServer().setAddress(address).setPassword(redisProperties.getPassword());// 指定使用单节点部署方式
		//config.useSentinelServers().setMasterName("mymaster").addSentinelAddress("redis://47.93.63.193:26379","redis://47.93.63.193:26380").setPassword("123456");
		redisson = Redisson.create(config);// 创建客户端
		return redisson;
		// RedissonClient redisson = Redisson
		// .create(Config.fromYAML(new
		// ClassPathResource("redisson.yml").getInputStream()));
		// return redisson;

	}

}
