package com.up.mls.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.web.servlet.ServletRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.builders.WebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.web.authentication.SimpleUrlAuthenticationFailureHandler;
import org.springframework.security.web.authentication.SimpleUrlAuthenticationSuccessHandler;
import org.springframework.security.web.header.writers.frameoptions.XFrameOptionsHeaderWriter;
import org.springframework.security.web.header.writers.frameoptions.XFrameOptionsHeaderWriter.XFrameOptionsMode;

import com.up.mls.controller.system.PostObjectPolicy;
import com.up.mls.handler.AjaxAuthFailureHandler;
import com.up.mls.handler.AjaxAuthSuccessHandler;
import com.up.mls.service.system.IUserService;

@Configuration
public class WebSecurityConfig extends WebSecurityConfigurerAdapter {

	@Autowired
	IUserService userService;

	@SuppressWarnings({ "rawtypes", "unchecked" })
	@Bean
	public ServletRegistrationBean servletRegistrationBean() {
		return new ServletRegistrationBean(new PostObjectPolicy(), "/osssignuature");// ServletName默认值为首字母小写，即myServlet
	}

	@Override
	public void configure(WebSecurity web) throws Exception {
		// 每一个请求对应一个空的filter链,这里一般不要配置过多,
		// 因为查找处是一个for循环,过多就导致每个请求都需要循环一遍直到找到
		web.ignoring().antMatchers("/", "/css/**","/oss/callBack", "/image/**", "/js/**", "/**/*.js", "/**/*.css", "/img/**", "/fonts/**", "/actuator/**").antMatchers("/oss/policy");
	}

	@Override
	public void configure(AuthenticationManagerBuilder auth) throws Exception {
		auth.userDetailsService(userService);
	}

	/**
	 * 登陆成功处理
	 * 
	 * @return
	 */
	@Bean
	public SimpleUrlAuthenticationSuccessHandler authenticationSuccessHandler() {
		return new AjaxAuthSuccessHandler();
	}

	/**
	 * 登录失败处理
	 * 
	 * @return
	 */
	@Bean
	public SimpleUrlAuthenticationFailureHandler authenticationFailureHandler() {
		return new AjaxAuthFailureHandler();
	}

	@Override
	protected void configure(HttpSecurity http) throws Exception {
		http.cors().and().csrf().disable();
		// 必须允许所有用户访问我们的登录页（例如未验证的用户，否则验证流程就会进入死循环）
		// 这个formLogin().permitAll()方法允许所有用户基于表单登录访问/login这个page。
		http.authorizeRequests().anyRequest().authenticated();
		http.formLogin().loginPage("/login").loginProcessingUrl("/login").usernameParameter("username").permitAll();
		http.formLogin().successHandler(authenticationSuccessHandler()).failureHandler(authenticationFailureHandler())
				.permitAll();
		http.logout().deleteCookies("JSESSIONID").invalidateHttpSession(true).logoutUrl("/logout")
				.logoutSuccessUrl("/");
		// X-Frame-Options 是否允许网页被iFrame 【DENY】 不允许网页被iframe 【SAMEORIGIN】允许网页被同一域名iframe
		// 【ALLOW-FROM】 允许任意网页iframe该网页
		http.headers().addHeaderWriter(new XFrameOptionsHeaderWriter(XFrameOptionsMode.SAMEORIGIN));

	}

}
