/**
 * 
 */
package com.up.mls.controller;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.ModelAttribute;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.up.mls.config.UpConfig;
import com.up.mls.util.ServletUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.system.User;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.PageDomain;
import com.up.mls.web.page.TableDataInfo;
import com.up.mls.web.page.TableSupport;

/**
 * @author mingguangz 所有的controller继承这个类
 */
public abstract class AbstractController {

	protected String getCurrentURL(HttpServletRequest request) {
		return ServletUtils.getCurrentURL(request);
	}

	protected String getBaseURL(HttpServletRequest request) {
		return ServletUtils.getBaseURL(request);
	}

	/**
	 * 获得访问者的IP
	 * 
	 * @param request
	 * @return
	 * @throws Exception
	 */
	protected String getIpAddress(HttpServletRequest request) {
		return ServletUtils.getIpAddress(request);
	}

	protected void addCookie(String name, String value, HttpServletResponse response) {
		this.addCookie(name, value, ServletUtils.DEFAULT_COOKIE_PATH, ServletUtils.DEFAULT_COOKIE_MAXAGE, response);
	}

	protected void addCookie(String name, String value, Integer maxAge, HttpServletResponse response) {
		this.addCookie(name, value, ServletUtils.DEFAULT_COOKIE_PATH, maxAge, response);
	}

	protected void addCookie(String name, String value, String path, Integer maxAge, HttpServletResponse response) {
		ServletUtils.addCookie(name, value, maxAge, response);
	}

	protected void removeCookie(String name, HttpServletResponse response) {
		ServletUtils.removeCookie(name, response);
	}

	protected void removeCookie(String name, String path, HttpServletResponse response) {
		ServletUtils.removeCookie(name, path, response);
	}

	protected Cookie getCookieByName(String name, HttpServletRequest request) {
		return getCookies(request).get(name);
	}

	protected Map<String, Cookie> getCookies(HttpServletRequest request) {
		return ServletUtils.getCookies(request);
	}

	protected String getCookieValueByName(String name, HttpServletRequest request) {
		return getCookieValues(request).get(name);
	}

	protected Map<String, String> getCookieValues(HttpServletRequest request) {
		return ServletUtils.getCookieValues(request);
	}

	protected void responseOutWithJson(HttpServletResponse response, String result) {
		ServletUtils.printWriter(response, result);
	}

	public User getUser() {
		return (User) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
	}

	public Long getUserId() {
		return getUser().getUserId();
	}

	public Long getDeptId() {
		return getUser().getDeptId();
	}

	public Long getCompanyId() {
		return getUser().getCompanyId();
	}

	/**
	 * 
	 * @return 138500:全公司<br>
	 *         138400:子公司:子公司包括子公司所有部门<br>
	 *         138300:所属部门及其子部门: 操作自己、下属和自己所属部门及子部门的数据<br/>
	 *         138200:个人:只能操作自己的数据
	 */
	public Integer getDataAuth() {
		return SpringSecurityUtils.getDataAuth();
	}

	public String getUsername() {
		return getUser().getUsername();
	}

	/**
	 * 将前台传递过来的日期格式的字符串，自动转化为Date类型
	 */
	@InitBinder
	public void initBinder(WebDataBinder binder) {
		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		dateFormat.setLenient(false);
		binder.registerCustomEditor(Date.class, new CustomDateEditor(dateFormat, true));
	}

	/**
	 * 设置请求分页数据
	 */
	protected void startPage() {
		PageDomain pageDomain = TableSupport.buildPageRequest();
		Integer pageNum = pageDomain.getPageNum();
		Integer pageSize = pageDomain.getPageSize();
		if (StringUtils.isNotNull(pageNum) && StringUtils.isNotNull(pageSize)) {
			String orderBy = pageDomain.getOrderBy();
			PageHelper.startPage(pageNum, pageSize, orderBy);
		}
	}

	/**
	 * 响应请求分页数据
	 */
	@SuppressWarnings({ "rawtypes", "unchecked" })
	protected TableDataInfo getDataTable(List<?> list) {
		TableDataInfo rspData = new TableDataInfo();
		rspData.setCode(0);
		rspData.setRows(list);
		rspData.setTotal(new PageInfo(list).getTotal());
		return rspData;
	}

	/**
	 * 响应返回结果
	 * 
	 * @param rows
	 *            影响行数
	 * @return 操作结果
	 */
	protected AjaxResult toAjax(int rows) {
		return rows > 0 ? success() : error();
	}

	/**
	 * 返回成功
	 */
	public AjaxResult success() {
		return AjaxResult.success();
	}

	/**
	 * 返回失败消息
	 */
	public AjaxResult error() {
		return AjaxResult.error();
	}

	/**
	 * 返回成功消息
	 */
	public AjaxResult success(String message) {
		return AjaxResult.success(message);
	}

	/**
	 * 返回失败消息
	 */
	public AjaxResult error(String message) {
		return AjaxResult.error(message);
	}

	/**
	 * 返回错误码消息
	 */
	public AjaxResult error(int code, String message) {
		return AjaxResult.error(code, message);
	}

	/**
	 * 页面跳转
	 */
	public String redirect(String url) {
		return StringUtils.format("redirect:{}", url);
	}
	
	@Autowired
    private UpConfig upConfig;
	@ModelAttribute
	public void getUpConfig(ModelMap mmap) {
		mmap.put("imgPrefix", upConfig.getImgPreFix());
	}
	
	/**
	 * 商铺查询条件检测
	 */
//	public int isQueryParam(Shop shop) {
//		if(StringUtils.isNotBlank(shop.getPhone()) || StringUtils.isNotBlank(shop.getShopName()) || StringUtils.isNotBlank(shop.getCreateType()) || StringUtils.isNotBlank(shop.getType()) ||
//				StringUtils.isNotBlank(shop.getOnlineStatus()) ||StringUtils.isNotBlank(shop.getPhone()) || shop.getParentManageTypeId() != null || shop.getSonManageTypeId() != null || 
//				shop.getParams() != null || shop.getParams() != null) {
//			System.out.println("=== : "+shop.getParams().size());
//			return 1;
//		}else {
//			return 0;
//		}
//	}

}
