package com.up.mls.controller.assess;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.assess.LookOfficeService;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.vo.assess.LookOffice;
import com.up.mls.vo.system.User;
import com.up.mls.vo.user.AppUser;
import com.up.mls.web.page.TableDataInfo;
/**
 * 写字楼委托
 * 委托找写字楼、委托找客
 * @author joker
 *
 */
@Controller
@RequestMapping("lookOffice")
public class LookOfficeController extends AbstractController{

	@Autowired
	private LookOfficeService lookOfficeService;
	@Autowired
	private IAppUserService appUserService;
	
	
	/**
	 * helpType 1：找写字楼 2：找客
	 * ===============【写字楼】======
		【543 写字楼-找客】
		   		helpType=2&
		10、写字楼出租  types=1
		11、写字楼出售  types=2
		12、写字楼新盘出租types=3
		13、写字楼新盘出售types=4
		
		【545  写字楼-找铺】
				 helpType=1&
		14、写字楼求租	types=1
		15、写字楼求购	types=2
		16、写字楼新盘求租types=3
		17、写字楼新盘求购types=4
		=================【end】===========
	 */
	@RequestMapping("list/{helpType}/{distStatus}")
	public String office(@PathVariable("helpType")String helpType,@PathVariable("distStatus")String distStatus,ModelMap mmap) {
		mmap.put("helpType", helpType);
		mmap.put("distStatus", distStatus);
		if("1".equals(helpType)){
			mmap.put("weituoDic", "545");//找铺
		}else{
			mmap.put("weituoDic", "543");//找客
		}
		if("1".equals(distStatus)){
			//已分配
			return "lookOffice/haveOfficeList";
		}
		//待分配
		return "lookOffice/waitOfficeList";
	}
	
	
	/**
	 * 帮我找客列表
	 *  10、写字楼出租       helpType=2&types=1
		11、写字楼出售       helpType=2&types=2
		12、写字楼新盘出租 helpType=2&types=3
		13、写字楼新盘出售 helpType=2&types=4
		
		14、写字楼求租            helpType=1&types=1
		15、写字楼求购            helpType=1&types=2
		16、写字楼新盘求租    helpType=1&types=3
		17、写字楼新盘求购    helpType=1&types=4
	 * @param helpType
	 * @param distStatus
	 * @param lookOffice
	 * @return
	 */
	@RequestMapping("data/{helpType}/{distStatus}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("helpType")String helpType,@PathVariable("distStatus")String distStatus,LookOffice lookOffice) {
		startPage();
		lookOffice.setHelpType(helpType);
		lookOffice.setDistStatus(distStatus);
		String weituoDic=lookOffice.getWeituoDic();
		if("10".equals(weituoDic) || "14".equals(weituoDic)){
			lookOffice.setTypes("1");
		}else if("11".equals(weituoDic) || "15".equals(weituoDic)){
			lookOffice.setTypes("2");
		}else if("12".equals(weituoDic) || "16".equals(weituoDic)){
			lookOffice.setTypes("3");
		}else if("13".equals(weituoDic) || "17".equals(weituoDic)){
			lookOffice.setTypes("4");
		}
		List<LookOffice> list = lookOfficeService.selectList(lookOffice);
		list.forEach(l ->{
			l.setAreaRegions(l.getAreaName()+"-"+l.getRegionsName());
			l.setUnitPrice(l.getUnitMin()+"-"+l.getUnitMax()+"元/㎡");
			l.setDailyPrice(l.getDailyRentMin()+"-"+l.getDailyRentMax()+"/元/天/㎡");
		});
		return getDataTable(list);
	}
	
	@RequestMapping("/detail/{id}")
	public String detail(@PathVariable("id")Long id,ModelMap mmap) {
		mmap.put("lookOffice", lookOfficeService.selectByPrimaryKey(id));
		return "lookOffice/detail";
	}
	
	/**
	 * 分配经济人
	 */
	@GetMapping("toDistribution")
	public String toDistribution(String ids, Model model) {
		//获取 经纪人列表
		List<AppUser> list = appUserService.selectAppUserForAgent(2);
		model.addAttribute("sysAccounts", list);
		model.addAttribute("ids", ids);
		return "lookOffice/distribution";
	}
	
	/**
	 * 保存分配经济人
	 */
	@PostMapping("distribution")
	public @ResponseBody Integer distribution(String saleId,String ids, Model model) {
		//获取当前操作人（登录人）
		User user = getUser();
		int count = lookOfficeService.distribution(saleId, ids, user);
		return count;
	}
}
