package com.up.mls.controller.assess;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.assess.LookShopService;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.vo.assess.LookShop;
import com.up.mls.vo.system.User;
import com.up.mls.vo.user.AppUser;
import com.up.mls.web.page.TableDataInfo;

/**
 * 商铺委托分配Controller
 * 委托找铺分配、委托找客分配
 * @author joker
 *
 */
@Controller
@RequestMapping("lookShop")
public class LookShopController extends AbstractController{

	@Autowired
	private LookShopService lookShopService;
	@Autowired
	private IAppUserService appUserService;
	
	
	/**
	 * helpType 1:找铺 2:找客
	 * distStatus 0:未分配 1:已分配
	 * ==============【商铺】=========
		【542 商铺-找客】 
		helpType=2&
		
		10、商铺出租     types=1
		11、商铺出售	 types=2
		12、商业新盘出租 types=3
		13、商业新盘出售 types=4
		
		【544  商铺-找铺】
			 helpType=1&
		14、商铺求租     types=1
		15、商铺求购	 types=2
		16、商业新盘求租 types=3
		17、商业新盘求购 types=4
		===============【end】================
	 */
	@RequestMapping("list/{helpType}/{distStatus}")
	public String office(@PathVariable("helpType")String helpType,@PathVariable("distStatus")String distStatus,ModelMap mmap) {
		mmap.put("helpType", helpType);
		mmap.put("distStatus", distStatus);
		if("1".equals(helpType)){
			mmap.put("weituoDic", "544");//找铺
		}else{
			mmap.put("weituoDic", "542");//找客
		}
		if("1".equals(distStatus)) {
			//商铺-已分配
			return "lookShop/haveShopList";
		}else {
			//商铺-待分配
			return "lookShop/waitShopList";
		}
	}
	
	/**
	 * 帮我找客列表
	 *  10、商铺出租      helpType=2&types=1
		11、商铺出售      helpType=2&types=2
		12、商业新盘出租 helpType=2&types=3
		13、商业新盘出售 helpType=2&types=4
		        
		14、商铺求租     helpType=1&types=1
		15、商铺求购     helpType=1&types=2
		16、商业新盘求租 helpType=1&types=3
		17、商业新盘求购 helpType=1&types=4
	 * @param helpType
	 * @param distStatus
	 * @param lookShop
	 * @return
	 */
	@RequestMapping("data/{helpType}/{distStatus}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("helpType")String helpType,@PathVariable("distStatus")String distStatus,LookShop lookShop) {
		startPage();
		lookShop.setHelpType(helpType);
		lookShop.setDistStatus(distStatus);
		String weituoDic=lookShop.getWeituoDic();
		if("10".equals(weituoDic) || "14".equals(weituoDic)){
			lookShop.setTypes("1");
		}else if("11".equals(weituoDic) || "15".equals(weituoDic)){
			lookShop.setTypes("2");
		}else if("12".equals(weituoDic) || "16".equals(weituoDic)){
			lookShop.setTypes("3");
		}else if("13".equals(weituoDic) || "17".equals(weituoDic)){
			lookShop.setTypes("4");
		}
		List<LookShop> list = lookShopService.selectList(lookShop);
		list.forEach(l ->{
			l.setAreaRegions(l.getAreaName()+"-"+l.getRegionsName());
			l.setUnitPrice(l.getUnitMin()+"-"+l.getUnitMax()+"元/㎡");
			l.setDailyPrice(l.getDailyRentMin()+"-"+l.getDailyRentMax()+"/元/天/㎡");
		});
		return getDataTable(list);
	}
	
	@RequestMapping("/detail/{id}")
	public String detail(@PathVariable("id")Long id,ModelMap mmap) {
		LookShop  entity=lookShopService.selectByPrimaryKey(id);
		mmap.put("lookShop", entity);
		return "lookShop/detail";
	}
	/**
	 * 为委托 分配经济人
	 */
	@GetMapping("toDistribution")
	public String toDistribution(String ids, Model model) {
		//获取 经纪人列表
		List<AppUser> list = appUserService.selectAppUserForAgent(2); // selectUserByRole(null, "经纪人", companyId);
		model.addAttribute("sysAccounts", list);
		model.addAttribute("ids", ids);
		return "lookShop/distribution";
	}
	/**
	 * 保存分配经济人
	 */
	@PostMapping("distribution")
	public @ResponseBody Integer distribution(String agentId,String ids, Model model) {
		//获取当前操作人（登录用户）
		User user = getUser();
		int count = lookShopService.distribution(agentId, ids, user);
		return count;
	}
}
