package com.up.mls.controller.call;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.call.CallRecordingService;
import com.up.mls.service.call.CallUtilsService;
import com.up.mls.service.system.IDictionaryService;
import com.up.mls.util.DateUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.callRecording.CallRecording;
import com.up.mls.vo.callRecording.GjLog;
import com.up.mls.vo.system.Dictionary;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 * 400查询录音接口
 * @author PJJ
 *	
 */
@Controller
@RequestMapping("/call")
public class CallRecordingController extends AbstractController{

	private static final Logger logger = LoggerFactory.getLogger(CallRecordingController.class);
	@Autowired
	private CallRecordingService callRecordService;
	@Autowired
	private CallUtilsService callUtilsService;
	@Autowired
	private IDictionaryService dictionaryService;


	/**
	 * 跳转到列表
	 * @param mmap
	 * @return
	 */
    @RequestMapping("toPage")
	public String toPage(ModelMap mmap) {
		return "callRecoding/xianSuoList";
	}
    
    
    
    /**
     * 加载分页数据
     * @return
     */
	@RequestMapping("list/{loginUserId}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("loginUserId") String loginUserId,CallRecording entity) {
		startPage();
		if( !loginUserId.equals("all")){
			entity.setRenlinUserId(loginUserId);
		}
		List<CallRecording> list = this.callRecordService.findPage(entity);
		return getDataTable(list);
	}

	
	/**
	 * 详情跟进页面回显数据
	 * @param id
	 * @param mmap
	 * @return
	 */
	@RequestMapping("/toDetail/{id}")
	public String edit(@PathVariable("id") String id, ModelMap mmap) {
		CallRecording  entity=this.callRecordService.findEntity(id);
		if(entity!=null){
			//标题
			String createTimeStr=DateUtils.getStringDate(entity.getCreateTime());
			String title="经纪人      【"+entity.getAniName()+"】"+entity.getAni()+"在["+createTimeStr+"]  电话勾搭了 经纪人【"+entity.getDnisName()+"】"+entity.getDnis();
			mmap.put("title",title);
			mmap.put("sjType",entity.getSjType()==null?"1":entity.getSjType());
			if("2".equals(entity.getSjType())){
				mmap.put("voice", entity.getVoice()==null?"未接通":entity.getVoice());
			}else{
				String voice=this.callUtilsService.findRecordEntity(entity.getUuid());
				if(StringUtils.isNotEmpty(voice) && voice.contains("http")){
					mmap.put("voice", voice);
				}else{
					mmap.put("voice", "未接通");
				}
			}
			mmap.put("entity",entity);
			List<GjLog> gjList=this.callRecordService.findGjList(id);
			mmap.put("gjList",gjList);
		}
		return "callRecoding/xianSuoDetail";
	}
	
	
	
	/**
	 * 保存跟进原因
	 * @param entity
	 * @param result
	 * @return
	 */
	@PostMapping("saveProgress")
	@ResponseBody
	public AjaxResult saveProgress(GjLog entity) {
		entity.setFollowUserId(SpringSecurityUtils.getUserId().toString());
		entity.setFollowUserName(SpringSecurityUtils.getLoginName());
		this.callRecordService.saveProgress(entity);
		return toAjax(1);
	}
	
	/**
	 * 认领提交
	 * @param mmap
	 * @return
	 */
	@PostMapping("saveRenlin")
	@ResponseBody
	public AjaxResult saveRenlin(CallRecording entity) {
		entity.setRenlinUserId(SpringSecurityUtils.getUserId().toString());
		return toAjax(callRecordService.saveRenlin(entity));
	}
	
	/**
	 * 跳转到勾搭跟跟进
	 * @param mmap
	 * @return
	 */
    @RequestMapping("toGdPage")
	public String toGdPage(ModelMap mmap) {
    	mmap.put("renlinUserId", SpringSecurityUtils.getUserId().toString());
		return "callRecoding/gdgjList";
	}
    
    
    /**
	 * 释放提交
	 * @param mmap
	 * @return
	 */
	@PostMapping("saveFree")
	@ResponseBody
	public AjaxResult saveFree(CallRecording entity) {
		entity.setRenlinUserId("-1");
		return toAjax(callRecordService.saveRenlin(entity));
	}
    
	
}


