package com.up.mls.controller.content;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.github.pagehelper.PageHelper;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.content.ArticleService;
import com.up.mls.vo.content.Article;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.PageDomain;
import com.up.mls.web.page.TableDataInfo;
import com.up.mls.web.page.TableSupport;

/**
 * <Description> 内容管理 行业资讯
 *
 * @author Yuesiwei
 * @createDate 2019/02/16 上午11:45
 * @see com.up.mls.controller.content
 */
@Controller
@RequestMapping("/content/article")
public class ArticleController extends AbstractController {

    private String prefix = "content/article";

    @Autowired
    private ArticleService articleService;

    @GetMapping()
    public String index() {
        return prefix + "/article";
    }

    @ResponseBody
    @RequestMapping("/list")
    public TableDataInfo list(Article article) {
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        PageHelper.startPage(pageNum,pageSize);
        List<Article> articleList = articleService.selectList(article);
        return getDataTable(articleList);
    }

    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap model) {
        Article article = articleService.selectById(id);
        model.put("entity", article);
        return prefix + "/edit";
    }

    @ResponseBody
    @RequestMapping("/save")
    public AjaxResult save(Article article) {
        return toAjax(articleService.sava(article));
    }

    @ResponseBody
    @RequestMapping("/remove")
    public AjaxResult remove(String ids) {
        try {
            return toAjax(articleService.remove(ids));
        } catch (Exception e) {
            e.printStackTrace();
            return error(e.getMessage());
        }
    }

}
