package com.up.mls.controller.content;

import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.content.IBrandLinkmanService;
import com.up.mls.service.content.IBrandService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.content.Brand;
import com.up.mls.vo.content.BrandLinkman;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;


/**
 * 品牌联系人 审核  controller
 * 
 * 用户在APP端 为品牌新增联系人， 后台对新增的联系人信息进行审核，
 * 审核通过则新增到品牌联系人中，审核不通过则不添加
 * 
 * @author joker
 *
 */
@Controller
@RequestMapping("/brandContacts")
public class BrandContactsController extends AbstractController{
	
	private static final Logger logger = LoggerFactory.getLogger(BrandContactsController.class);
	@Autowired
	private IBrandService brandService;
	@Autowired
	private IBrandLinkmanService brandContactsService;
//	@Autowired
//	private BrandBusinessService brandBusinessService;
	
	@Secured("brand:contacts")
	@RequestMapping("contacts")
	public String list() {
		return "brandContacts/list";
	}
	
	@Secured("contacts:list")
	@PostMapping("/list")
	@ResponseBody
	public TableDataInfo list(BrandLinkman brandContacts) {
		startPage();
		List<BrandLinkman> list = brandContactsService.selectListForAudit(brandContacts);
		return getDataTable(list);
	}
	
	@GetMapping("verify/{id}")
	public String verify(@PathVariable("id")String id, ModelMap mmap) {
		 BrandLinkman brandContacts = brandContactsService.selectById(id);
		 mmap.put("brandContacts", brandContacts);
	     return  "brandContacts/verify";
	}
	
	@Secured("brand:edit")
	@PostMapping("saveVerify")
	@ResponseBody
	public AjaxResult saveVerify(BrandLinkman brandLinkman) {
		return toAjax(brandContactsService.updateForAudit(brandLinkman, getUserId()));
	}
	
	
	/**
	 * 品牌联系人审核 详情
	 * @param id
	 * @param mmap
	 * @return
	 */
	@GetMapping("detail/{id}")
	public String detail(@PathVariable("id")String id, ModelMap mmap) {
		 BrandLinkman brandContacts = brandContactsService.selectById(id);
		 mmap.put("brandContacts", brandContacts);
	    return  "brandContacts/detail";
	}
	
	  /**
     * 品牌联系人审核Controller异常报错捕获
     * @param request
     * @param exception
     * @return 错误所在的类、方法、行号
     * @throws Exception
     */
    @ExceptionHandler(value=Exception.class)  
    public String exceptionHandler(HttpServletRequest request,  Exception exception, Model model){  
       StackTraceElement[] errorStr = exception.getStackTrace();
        StringBuffer sb = new StringBuffer();  
        sb.append(exception.toString());
        sb.append("<br/>");
        for(int i=0;i<errorStr.length;i++) {
        		String errorInfo = errorStr[i].toString();
        		if(errorInfo.contains("com.up.sell.controller")) {
        			sb.append(errorInfo);
        			sb.append("<br/>");
        		}
        }
        exception.printStackTrace();
        logger.info("品牌联系人controller出错：{}",sb);
        model.addAttribute("sb", sb);
        return "500";  
    } 

}
