package com.up.mls.controller.content;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.up.mls.service.content.*;
import com.up.mls.vo.content.BrandLinkman;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import com.up.mls.controller.AbstractController;
import com.up.mls.vo.content.Brand;
import com.up.mls.vo.content.BrandArea;
import com.up.mls.vo.content.BrandType;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 * <Description>
 * 内容管理 品牌列表
 *
 * @author Yuesiwei
 * @createDate 2019/02/16 下午3:07
 * @see com.up.mls.controller.content
 */
@Controller
@RequestMapping("/content/brand")
public class BrandController extends AbstractController {

    private String prefix = "content/brand";

    @Autowired
    private IBrandAreaService iBrandAreaService;
 
    @Autowired
    private IBrandService iBrandService;
    
    @Autowired
    private IBrandBrandAreaService iBrandBrandAreaService;

    @Autowired
	private IBrandLinkmanService iBrandLinkmanService;

    @Autowired
    private IBrandTypeService iBrandTypeService;

    /**
     * 1:直营 2：加盟
     * @param brand
     * @return
     */
    @Secured("content:brand:view")
    @GetMapping("/list/{nature}")
    public String index(@PathVariable Integer nature) {
    		if(nature == 1) {
    			return prefix + "/listJoin";//直营品牌列表
        }else {
        		return prefix + "/listChain";//加盟品牌列表
        }
    }
    
	@ResponseBody
	@RequestMapping("/data")
	public TableDataInfo list(Brand brand) {
		startPage();
		brand.setAuditStatus(2);//审核通过了的才显示到直营或加盟列表
		List<Brand> articleList = iBrandService.selectList(brand);
		return getDataTable(articleList);
	}
    
    @GetMapping("/add")
    public String add(Model model) {
    	List<BrandArea> userBrandAreas = iBrandAreaService.findByLevel();
    	model.addAttribute("userBrandAreas", userBrandAreas);
        return prefix + "/add";
    }

	@ResponseBody
	@RequestMapping("/save")
	public AjaxResult save(Brand brand) {
		return toAjax(iBrandService.save(brand));
	}

	@GetMapping("/edit/{id}")
	public String edit(@PathVariable("id") String id,Model model) {
		Brand brand = iBrandService.selectById(id);
		model.addAttribute("entity", brand);
		List<BrandArea> userBrandAreas = iBrandAreaService.findByLevel();
		model.addAttribute("userBrandAreas", userBrandAreas);
		List<String> brandAreaId = iBrandBrandAreaService.selectId(Integer.decode(id));
		model.addAttribute("brandAreaId", brandAreaId);
		return prefix + "/edit";
	}

	@ResponseBody
	@RequestMapping("/remove")
	public AjaxResult remove(String ids) {
		try {
			return toAjax(iBrandService.remove(ids));
		} catch (Exception e) {
			e.printStackTrace();
			return error(e.getMessage());
		}
	}

	@ResponseBody
	@GetMapping("/getBrand")
	public List<BrandType> getBrand(BrandType brandType){
    	return iBrandTypeService.selectList(brandType);
	}

	@GetMapping("/catDetailPage/{id}")
	public String catDetail(@PathVariable("id") String id,Model model){
		Brand brand = iBrandService.selectById(id);
		model.addAttribute("entity", brand);
		List<BrandArea> userBrandAreas = iBrandAreaService.findByLevel();
		model.addAttribute("userBrandAreas", userBrandAreas);
		List<String> brandAreaId = iBrandBrandAreaService.selectId(Integer.decode(id));
		model.addAttribute("brandAreaId", brandAreaId);
		List<BrandLinkman> brandLinkmen = iBrandLinkmanService.selectList(id);
		model.addAttribute("brandLinkmen", brandLinkmen);
		if(brandLinkmen.isEmpty()){
		    model.addAttribute("notAvailable","true");
        }
		return prefix + "/catDetail";
	}

	@ResponseBody
	@PostMapping("/delLinkman")
	public AjaxResult delLinkman(String ids) {
		try {
			return toAjax(iBrandLinkmanService.remove(ids));
		} catch (Exception e) {
			e.printStackTrace();
			return error(e.getMessage());
		}
	}

	@GetMapping("/addLinkmanPage/{id}")
	public String addLinkman(@PathVariable("id") String id,Model model){
		model.addAttribute("brandId",id);
    	return prefix + "/addLinkman";
	}

	@ResponseBody
	@PostMapping("/saveBrandLinkman")
	public AjaxResult saveBrandLinkman(BrandLinkman brandLinkman) {
		return toAjax(iBrandLinkmanService.save(brandLinkman));
	}
	
	/**
	 * 获取上下架数量
	 * @param mmap
	 * @return
	 * @throws InterruptedException
	 */
	@ResponseBody
	@RequestMapping("findOnOfflineNum")
	public Map<String,Integer> findOnOfflineNum(Brand brand) throws InterruptedException {
		Map<String,Integer> map = new HashMap<String,Integer>();
		brand.setAdvFlag(0);
		map.put("onlineNum", iBrandService.selectOnOfflineCount(brand));
		brand.setAdvFlag(1);
		map.put("offlineNum", iBrandService.selectOnOfflineCount(brand));
		return map;
	}

}
