package com.up.mls.controller.content;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.content.IMogulService;
import com.up.mls.vo.content.Mogul;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

import java.util.List;

/**
 * <Description>
 * 大咖
 *
 * @author Yuesiwei
 * @createDate 2019/02/19 上午10:23
 * @see com.up.mls.controller.content
 */
@Controller
@RequestMapping("/content/mogul")
public class MogulController extends AbstractController {

    private String prefix = "content/mogul";

    @Autowired
    private IMogulService iMogulService;


    @Secured("content:mogul:view")
    @GetMapping()
    public String index() {
        return prefix + "/index";
    }

    @ResponseBody
    @RequestMapping("/list")
    public TableDataInfo list(Mogul mogul) {
        startPage();
        List<Mogul> mogulList = iMogulService.selectList(mogul);
        return getDataTable(mogulList);
    }

    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    @GetMapping("/edit/{id}")
    public String add(@PathVariable("id") String id, ModelMap modelMap) {
        Mogul mogul = iMogulService.selectById(id);
        modelMap.put("entity", mogul);
        return prefix + "/edit";
    }

    @ResponseBody
    @RequestMapping("/save")
    public AjaxResult save(Mogul mogul) {
        return toAjax(iMogulService.sava(mogul));
    }

    @ResponseBody
    @RequestMapping("/remove")
    public AjaxResult remove(String ids) throws Exception {
        try {
            return toAjax(iMogulService.remove(ids));
        }catch(Exception e){
            e.printStackTrace();
            return error(e.getMessage());
        }
    }



}
