package com.up.mls.controller.content;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.content.ISlideShowService;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.content.Banner;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 *@author liuwei
 *@createDate 2019/08/06 上午10:21
 *@see com.up.mls.controller.content
 * 运营管理 -->  轮播图管理 -->  轮播图
 */
@Controller
@RequestMapping("/content/slideShow")
public class SlideShowController extends AbstractController {

	private static final Logger logger = LoggerFactory.getLogger(SlideShowController.class);
    private String prefix = "content/slideShow";

    @Autowired
    private ISlideShowService iSlideShowService;

    @GetMapping()
    public String index() {
        return prefix + "/index";
    }

    @ResponseBody
    @RequestMapping("/list")
    public TableDataInfo list(Banner banner) {
        startPage();
        List<Banner> list = iSlideShowService.findBannerList(banner);
        return getDataTable(list);
    }

    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    
    /**
     * 新增或修改banner图
     * @param bannerSlideShow
     * @return
     */
    @ResponseBody
    @RequestMapping("/save")
    public AjaxResult save(Banner banner) {
    	if(banner.getId()==null){
    		String cityId=banner.getCityId();
    		if(StringUtils.isEmpty(cityId)){
    			logger.info("cityId不能为空");
    			return  toAjax(-1);
    		}
    		return toAjax(iSlideShowService.insertBanner(banner));
    	}else{
    		return toAjax(iSlideShowService.updateBanner(banner));
    	}
    }


    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap model) {
    	Banner  entity=this.iSlideShowService.selectById(id);
        if(entity.getType() ==1){
            entity.setUrl(entity.getAppUrl());// app
            entity.setPic(entity.getAppPic());
            entity.setAdress(2);
        }else {
            entity.setUrl(entity.getPcUrl());// pc
            entity.setPic(entity.getPcPic());
            entity.setAdress(1);
        }
        model.put("entity", entity);
        return prefix + "/edit";
    }
    
    
    @ResponseBody
    @RequestMapping("/remove")
    public AjaxResult remove(String ids) {
        try {
            return toAjax(iSlideShowService.remove(ids));
        } catch (Exception e) {
            e.printStackTrace();
            return error(e.getMessage());
        }
    }
    
}
