package com.up.mls.controller.customer;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.customer.CustomerService;
import com.up.mls.vo.customer.Customer;
import com.up.mls.web.page.TableDataInfo;
/**
 * 客源Controller（经纪人在前台录入）
 * 客源：委托经纪人租/买商铺或写字楼的客户
 * 具体分类：类型:0-买写字楼;1-租写字楼 ;2-买写字楼新盘;3-租写字楼新盘;4-买商铺;5-租商铺;6-买商铺新盘;7-租商铺新盘
 * 功能：客源的列表展示，条件查询、上下架管理
 * @author joker
 *
 */
@Controller
@RequestMapping("/customer")
public class CustomerController extends AbstractController{
	
	@Autowired
	private CustomerService customerService;
	
	@RequestMapping("/list")
	public String list() {
		return "customer/list";
	}
	
	@ResponseBody
	@RequestMapping("/data")
	public TableDataInfo data(Customer customer) {
		startPage();
		List<Customer> list = customerService.selectList(customer);
		return getDataTable(list);
	}
	
	@RequestMapping("/detail/{id}")
	public String detail(@PathVariable("id")Long id,ModelMap mmap) {
		mmap.put("customer", customerService.selectByPrimaryKey(id));
		return "customer/detail";
	}
	
	/**
	 * 上架
	 */
	@PostMapping("online")
	public @ResponseBody Boolean onlineBrand(Integer id) {
		Customer customer = new Customer();
		customer.setId(id);
		customer.setStatus("1");
		customerService.updateCustomerStatus(customer);
		return true;
	}
	/**
	 * 下架
	 */
	@PostMapping("offline")
	public @ResponseBody Boolean offlineBrand(Integer id) {
		Customer customer = new Customer();
		customer.setId(id);
		customer.setStatus("0");
		customerService.updateCustomerStatus(customer);
		return true;
	}
	/**
	 * 获取上下架数量
	 * @param mmap
	 * @return
	 * @throws InterruptedException
	 */
	@ResponseBody
	@RequestMapping("findOnOfflineNum")
	public Map<String,Integer> findOnOfflineNum() throws InterruptedException {
		Map<String,Integer> map = new HashMap<String,Integer>();
		map.put("onlineNum", customerService.selectOnOfflineCount("1"));
		map.put("offlineNum", customerService.selectOnOfflineCount("0"));
		return map;
	}
}
