package com.up.mls.controller.deal;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.deal.ProjectOrderService;
import com.up.mls.service.deal.ProjectOrderTrackService;
import com.up.mls.service.system.IAreasSerevice;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.vo.deal.ProjectOrder;
import com.up.mls.vo.deal.ProjectOrderTrack;
import com.up.mls.vo.user.AppUser;
import com.up.mls.web.page.TableDataInfo;


/**
 * 写字楼交易查询  Controller
 * 
 * 管理员查看 写字楼（出租、销售）交易的完整流程及节点信息
 * 节点信息包括：节点凭证、备注、失败原因、佣金信息
 * 
 * @author joker
 *
 */
@Controller
@RequestMapping("/officeOrder")
public class OfficeOrderController extends AbstractController{
	
	private static final Logger logger = LoggerFactory.getLogger(OfficeOrderController.class);
	@Autowired
	private ProjectOrderService projectOrderService;
	@Autowired
	private ProjectOrderTrackService projectOrderTrackService;
	@Autowired
	private IAppUserService appUserService;
	@Autowired
	private IAreasSerevice areasSerevice;

	
	
	/**
	 * 销售-交易列表
	 * @return
	 */
	@Secured("office:saleList")
	@RequestMapping("list/{sonType}")
	public String officeList(ModelMap mmap,@PathVariable("sonType")Integer sonType,HttpServletRequest request) {
		String projectIdStr = request.getParameter("projectId");
		Long projectId = 0L;
		if(projectIdStr != null)
			projectId = Long.parseLong(projectIdStr);
		mmap.put("projectId", projectId);
		mmap.put("sonType", sonType);
		mmap.put("areas", areasSerevice.findByCityAuth("2", ""));
		return "deal/officeList";
	}
	
	@Secured("project:list")
	@PostMapping("/list/{sonType}")
	@ResponseBody
	public TableDataInfo list(ProjectOrder projectOrder,@PathVariable("sonType")Integer sonType) {
		startPage();
		if(projectOrder.getProjectId() != null && projectOrder.getProjectId() == 0l)
			projectOrder.setProjectId(null);
		projectOrder.setSonType(sonType);
		List<ProjectOrder> list = projectOrderService.findOfficeOrder(projectOrder);
		return getDataTable(list);
	}
	
	
	/**
	 * 交易详情
	 * @param orderNo
	 * @param mmap
	 * @return
	 */
	@GetMapping("detail/{orderNo}")
	public String detail(@PathVariable("orderNo")String orderNo, ModelMap mmap) {
		//报备 - 项目订单信息
		ProjectOrder projectOrder = projectOrderService.findByProjectOrderNo(orderNo);
		mmap.put("projectOrder", projectOrder);
		//报备人信息
		AppUser member = appUserService.selectByPrimaryKey(projectOrder.getAgentId().toString());
		mmap.put("member", member);
		mmap.put("order", projectOrder);
		//报备人 - 客户信息
//		MemberCustomer customer = memberCustomerServcie.findById(Long.valueOf(projectOrder.getCustomerId()));
//		mmap.put("customer", customer);
		
		
		
		
		ProjectOrderTrack projectOrderTrack = new ProjectOrderTrack();
		projectOrderTrack.setOrderNo(orderNo);
		List<ProjectOrderTrack> list = projectOrderTrackService.findProjectOrderTrack(projectOrderTrack);
	    
	    List<String> flowStatus = Arrays.asList("","","","");
	    List<Date> flowDate = new ArrayList<Date>();
	    for(int i=0;i<list.size();i++) {
	    		Integer status = list.get(i).getOrderStatus();
	    		if(status == 1) {
	    			flowStatus.set(i, "报备提交");
	    			flowDate.add(list.get(i).getCreateTime());
	    		}else if(status == 2) {
	    			flowStatus.set(i-1, "报备成功");
	    			//flowDate.add(list.get(i).getCreateTime());
	    		}else if(status == 3) {
	    			flowStatus.set(i, "到访成功");
	    			flowDate.add(list.get(i).getCreateTime());
	    			mmap.put("dfpic", list.get(i).getPicPath());
	    			mmap.put("dfcause", list.get(i).getEndCause());
	    			mmap.put("dfdesc", list.get(i).getDescription());
	    		}else if(status == 4) {
	    			flowStatus.set(i, "认购成功");
//	    			if(projectOrder.getProjectType() == 1) {
//	    				flowStatus.set(i-1, "认购成功");
//	    			}else {
//	    				flowStatus.set(i-1, "意向成功");
//	    			}
	    			flowDate.add(list.get(i).getCreateTime());
	    			mmap.put("rgpic", list.get(i).getPicPath());
	    			mmap.put("rgcause", list.get(i).getEndCause());
	    			mmap.put("rgdesc", list.get(i).getDescription());
	    		}else if(status == 5) {
	    			flowStatus.set(i, "签约成功");
	    			flowDate.add(list.get(i).getCreateTime());
	    			mmap.put("qypic", list.get(i).getPicPath());
	    			mmap.put("qycause", list.get(i).getEndCause());
	    			mmap.put("qydesc", list.get(i).getDescription());
	    			//查询项目信息
	    			
	    		}else if(status == 6) {
	    			flowStatus.set(i, "结佣成功");
	    			flowDate.add(list.get(i).getCreateTime());
//	    			flowStatus.set(i, "完结");
//	    			flowDate.add(list.get(i).getCreateTime());
	    		}else if(status == 7) {
	    			flowStatus.set(i-2, "完结");
	    			flowDate.add(list.get(i).getCreateTime());
	    		}else if(status == 0) {
	    			int n = list.size();
	    			if(n == 2) {
	    				flowStatus.set(n-2, "报备失败");
		    			//flowDate.add(list.get(i).getCreateTime());
		    			mmap.put("dfpic", list.get(i).getPicPath());
		    			mmap.put("bbcause", list.get(i).getEndCause());
		    			mmap.put("bbdesc", list.get(i).getDescription());
	    			}else if(n == 3) {
	    				flowStatus.set(i-1, "报备成功");
		    			//flowDate.add(list.get(i).getCreateTime());
	    				
	    				flowStatus.set(n-2, "到访失败");
		    			flowDate.add(list.get(i).getCreateTime());
		    			mmap.put("dfpic", list.get(i).getPicPath());
		    			mmap.put("dfcause", list.get(i).getEndCause());
		    			mmap.put("dfdesc", list.get(i).getDescription());
	    			}else if(n == 4) {
	    				flowStatus.set(i-1, "到访成功");
		    			//flowDate.add(list.get(i).getCreateTime());
		    			mmap.put("dfpic", list.get(i).getPicPath());
		    			mmap.put("dfcause", list.get(i).getEndCause());
		    			if(projectOrder.getProjectType() == 1) {
		    				flowStatus.set(n-2, "认购失败");
	    				}else {
	    					flowStatus.set(n-2, "意向失败");
	    				}
		    			flowDate.add(list.get(i).getCreateTime());
		    			mmap.put("rgpic", list.get(i).getPicPath());
		    			mmap.put("rgcause", list.get(i).getEndCause());
		    			mmap.put("rgdesc", list.get(i).getDescription());
	    			}else if(n == 5) {
	    				flowStatus.set(i-1, "认购成功");
//	    				if(projectOrder.getProjectType() == 1) {
//	    					flowStatus.set(i-1, "认购成功");
//	    				}else {
//	    					flowStatus.set(i-1, "意向成功");
//	    				}
	    				
		    			//flowDate.add(list.get(i).getCreateTime());
		    			mmap.put("rgpic", list.get(i).getPicPath());
		    			mmap.put("rgcause", list.get(i).getEndCause());
	    				
	    				flowStatus.set(n-2, "签约失败");
		    			flowDate.add(list.get(i).getCreateTime());
		    			mmap.put("qypic", list.get(i).getPicPath());
		    			mmap.put("qydesc", list.get(i).getDescription());
		    			mmap.put("qycause", list.get(i).getEndCause());
	    			}
	    		}
	    }
	    for(String s:flowStatus) {
	    		System.out.println("s : "+s);
	    }
	    mmap.put("flowStatus", flowStatus);
	    mmap.put("flowDate", flowDate);
	    mmap.put("node", list.size());
	    int n = list.size();
	    System.out.println("node  : "+n);
	    String url = "";
//	   if(projectOrder.getProjectType() == 1) {
//		   url = "project/detail";
//	   }else {
//		   url = "project/detail_recruit";
//	   }
		return  "deal/detail";
	}
	
	
	/**
     * 项目交易订单审批记录Controller异常报错捕获
     * @param request
     * @param exception
     * @return 错误所在的类、方法、行号
     * @throws Exception
     */
    @ExceptionHandler(value=Exception.class)  
    public String exceptionHandler(HttpServletRequest request,  Exception exception, Model model){  
       StackTraceElement[] errorStr = exception.getStackTrace();
        StringBuffer sb = new StringBuffer();  
        sb.append(exception.toString());
        sb.append("<br/>");
        for(int i=0;i<errorStr.length;i++) {
        		String errorInfo = errorStr[i].toString();
        		if(errorInfo.contains("com.up.sell.controller")) {
        			sb.append(errorInfo);
        			sb.append("<br/>");
        		}
        }
        exception.printStackTrace();
        System.out.println("sb : "+sb);
        model.addAttribute("sb", sb);
        return "500";  
    } 

}
