package com.up.mls.controller.flow;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.deal.ProjectConcatService;
import com.up.mls.service.deal.ProjectOrderService;
import com.up.mls.service.deal.ProjectOrderTrackService;
import com.up.mls.service.system.IAreasSerevice;
import com.up.mls.vo.deal.ProjectOrder;
import com.up.mls.web.page.TableDataInfo;

/**
 * 写字楼流程查看Controller
 * 展示正在交易过程中的数据（联系、到访、认购、签约）
 * @author joker
 *
 */
@Controller
@RequestMapping("office/flow")
public class OfficeFlowController extends AbstractController{
	
	@Autowired
	private ProjectOrderService projectOrderService;
	@Autowired
	private ProjectOrderTrackService projectOrderTrackService;
	@Autowired
	private ProjectConcatService projectConcatService;
	@Autowired
	private IAreasSerevice areasSerevice;
	
	/**
	 * 写字楼-出租流程列表
	 * @return
	 */
	@Secured("office:saleList")
	@RequestMapping("officeList/{projectType}/{sonType}")
	public String officeList(@PathVariable("projectType") String projectType,@PathVariable("sonType") String sonType,
			ModelMap mmap,HttpServletRequest request) {
		String projectIdStr = request.getParameter("projectId");
		Long projectId = 0L;
		if(projectIdStr != null)
			projectId = Long.parseLong(projectIdStr);
		mmap.put("projectId", projectId);
		mmap.put("sonType", sonType);
		mmap.put("areas", areasSerevice.findByCityAuth("2", ""));
		return "deal/officeFlowList";
	}
	
	@Secured("project:list")
	@PostMapping("/data/{projectType}/{sonType}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("projectType") Integer projectType,@PathVariable("sonType") Integer sonType,ProjectOrder projectOrder) {
		startPage();
		if(projectOrder.getProjectId() != null && projectOrder.getProjectId() == 0l)
			projectOrder.setProjectId(null);
		projectOrder.setProjectType(projectType);
		projectOrder.setSonType(sonType);
		List<ProjectOrder> list = projectOrderService.selectOfficeFlow(projectOrder);
		list.forEach(o ->{
			o.setLxNum(projectConcatService.selectProjectConcatCount(o.getProjectId().toString()));
			o.setDfNum(projectOrderTrackService.selectProjectOrderTrackCount(o.getOrderNo(), "3"));
			o.setRgNum(projectOrderTrackService.selectProjectOrderTrackCount(o.getOrderNo(), "4"));
			o.setQyNum(projectOrderTrackService.selectProjectOrderTrackCount(o.getOrderNo(), "5"));
			o.setZzNum(projectOrderTrackService.selectProjectOrderTrackCount(o.getOrderNo(), "0"));
		});
		return getDataTable(list);
	}
}
