package com.up.mls.controller.news;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.news.NewsService;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.util.ServletUtils;
import com.up.mls.vo.news.News;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;


/**
 * 公告管理控制器
 */
@Controller
@RequestMapping("/news")
public class NewsController extends AbstractController {

    private String prefix = "news";

    @Autowired
    private NewsService newsService;

    @Autowired
    private ICompanyService companyService;

    @GetMapping("/index")
    public String index() {
        return prefix + "/index";
    }

    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, Model model) {
        Map<String, Object> map = newsService.selectById(id);
        model.addAttribute("entity", map);
        return prefix + "/edit";
    }

    @ResponseBody
    @GetMapping("/companyList")
    public List<Map<String, Object>> companyList() {
        return companyService.selectCompany();
    }

    @ResponseBody
    @PostMapping("save")
    public AjaxResult saveProgress(News news) throws Exception {
        return toAjax(newsService.save(news));
    }

    @ResponseBody
    @PostMapping("/list")
    public TableDataInfo list(HttpServletRequest request) {
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        startPage();
        List<Map<String, Object>> list = newsService.selectList(parameters);
        return getDataTable(list);
    }

    /**
     * 删除
     *
     * @param ids
     * @return
     */
    @ResponseBody
    @PostMapping("/remove")
    public AjaxResult remove(String ids) {
        return toAjax(newsService.remove(ids));
    }

    /**
     * 下架
     *
     * @param id
     * @return
     */
    @ResponseBody
    @PostMapping("/offlineBrand")
    public AjaxResult offlineBrand(String id) {
        return toAjax(newsService.offlineBrand(id));
    }

    /**
     * 上架
     *
     * @param id
     * @return
     */
    @ResponseBody
    @PostMapping("/onlineBrand")
    public AjaxResult onlineBrand(String id) {
        return toAjax(newsService.onlineBrand(id));
    }


}
