package com.up.mls.controller.office;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.news.NewsService;
import com.up.mls.service.office.OfficeService;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.office.Audit;
import com.up.mls.vo.office.Office;
import com.up.mls.vo.office.OfficeExtend;
import com.up.mls.vo.user.AppUser;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

import jodd.util.ObjectUtil;
/**
 * 写字楼审核&认领Controller
 * @author joker
 *
 */
@Controller
@RequestMapping("officeAudit")
public class OfficeAuditController extends AbstractController{

	@Autowired
	private OfficeService officeService;
	@Autowired
	private IAppUserService appUserService;
	@Autowired
	private NewsService newService;
	
	/**
	 * 跳转到写字楼认领与查询
	 * @param mmap
	 * @return
	 */
	@RequestMapping("toAuditPage")
	public String toAuditPage(ModelMap mmap) {
		return "audit/office/officeCxRlList";
	}
	/**
	 * 跳转到认领
	 * @param mmap
	 * @return
	 */
	@RequestMapping("toMy")
	public String toMy(ModelMap mmap) {
		mmap.put("loginUserId",SpringSecurityUtils.getUserId());
		mmap.put("currUserName",SpringSecurityUtils.getUser().getUserName());
		return "audit/office/officeMyAudit";
	}
	
	/**
	 * 写字楼审核分页列表
	 * @param office
	 * @return
	 */
	@Secured("office:list")
	@RequestMapping("data/{loginUserId}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("loginUserId") String loginUserId,Office office) {
		startPage();
		if( !loginUserId.equals("all")){
			//【我的写字楼审核】
			if(office.getAuditStatus()==null ){
				office.setAuditStatus(1);//my默认待审核
			}else if(office.getAuditStatus() == -1){
				office.setAuditStatus(null);//全部审核状态
			}
			office.setRenlinUserId(Integer.valueOf(loginUserId));
		}else{
			//【写字楼查询&认领】
			if(StringUtils.isEmpty(office.getRenlinType())){
				office.setRenlinType("-11");//默认未认领
			}else if("-13".equals(office.getRenlinType())){
				//全部的认领状态
				office.setRenlinType(null);
			}
		}
		List<Office> offices = officeService.selectOfficeList(office);
		if(offices !=null && offices.size()>0){
			for(Office temp:offices){
				List<Audit> auditList=this.officeService.findAuditList(temp.getId()+"");
				temp.setShCount(auditList==null?"0":auditList.size()+"");
			}
		}
		return getDataTable(offices);
	}
	
	
	
	//点击审核次数-跳转
	@RequestMapping("/toDetail/{id}")
	public String toDetail(@PathVariable("id") String id,ModelMap mmap) {
		mmap.put("objectId",id);
		List<Audit> auditList=this.officeService.findAuditList(id+"");
		mmap.put("auditList",auditList);
		return "audit/office/detailAudit";
	}
	//查看-跳转
	@RequestMapping("/toShow/{id}")
	public String toShow(@PathVariable("id") String id,ModelMap mmap) {
		mmap.put("objectId",id);
		List<Audit> auditList=this.officeService.findAuditList(id+"");
		mmap.put("auditList",auditList);
		return "audit/office/detailShow";
	}
	
	/**
	 * 认领提交
	 * @param mmap
	 * @return
	 */
	@PostMapping("saveRenlin")
	@ResponseBody
	public AjaxResult saveRenlin(Office entity) {
			entity.setRenlinUserId(Integer.valueOf(SpringSecurityUtils.getUserId().toString()));
			entity.setRenlinUserName(SpringSecurityUtils.getUser().getUserName());
			entity.setRenlinTime(new Date());
		return toAjax(officeService.saveRenlin(entity));
	}
	
	/**
	 * 批量认领提交
	 * @param mmap
	 * @return
	 */
	@GetMapping("saveRenlinBatch")
	@ResponseBody
	public Map<String,Object> saveRenlinBatch(Long[] ids) {
			Map<String,Object> map = new HashMap<String,Object>();
			map.put("ids", ids);
			map.put("renlinUserId", Integer.valueOf(SpringSecurityUtils.getUserId().toString()));
			map.put("renlinUserName", SpringSecurityUtils.getUser().getUserName());
			map.put("renlinTime", new Date());
			officeService.saveRenlinBatch(map);
			map.put("count", ids.length);
		return map;
	}
	

    /**
	 * 释放提交
	 * @param mmap
	 * @return
	 */
	@PostMapping("saveFree")
	@ResponseBody
	public AjaxResult saveFree(Office entity) {
		entity.setRenlinUserId(-1);
		return toAjax(officeService.saveRenlin(entity));
	}
	
	/**
	 * 释放提交批量
	 * @param mmap
	 * @return
	 */
	@GetMapping("saveFreeBatch")
	@ResponseBody
	public Map<String,Object> saveFreeBatch(Long[] ids) {
		Map<String,Object> map = new HashMap<String,Object>();
		map.put("ids", ids);
		map.put("renlinUserId", -1);
		officeService.realseRenlinBatch(map);
		map.put("count", ids.length);
		return map;
	}
	
	/**
	 * 编辑之前回显写字楼详情
	 * @param id
	 * @param mmap
	 * @return
	 */
	@RequestMapping("/toAuditEdit/{id}")
	public String edit(@PathVariable("id") Long id, ModelMap mmap) {
		Office  office=officeService.toEdit(id);
		//格式化佣金
		this.officeService.jsonHuiXianOfficeCommission(office);
		
		//内外经济人
		AppUser  appUser=this.appUserService.selectByPrimaryKey(office.getAgentId()+"");
		mmap.put("own",appUser==null?1:appUser.getOwn());//0：外部 ；1：内部
		//扩展信息
		OfficeExtend  offExtend=this.officeService.findExtendEntity(id+"");
		mmap.put("offExtend",offExtend);
		if(offExtend!=null){
			office.setJiafangUserId(offExtend.getJiafangUserId());
			office.setJiedaiUserId(offExtend.getJiedaiUserId());
		}
		mmap.put("office",office);
		return "audit/office/auditEdit";
	}
	
	/**
	 * 保存编辑
	 * @param shp
	 * @return
	 */
	@PostMapping("saveAuditEdit")
	@ResponseBody
	public AjaxResult saveEdit(@RequestBody Office office) {
		int resInt=0;
		try {
			Office oldOffice=this.officeService.selectByPrimaryKey(office.getId());
			String loginUserId=SpringSecurityUtils.getUserId().toString();
			String loginUserName=SpringSecurityUtils.getUser().getUserName();
			office.setAuditUserId(Integer.valueOf(loginUserId));
			office.setAuditUserName(loginUserName);
			office.setAuditTime(new Date());
			if(office.getAuditStatus() == 2){
				//审核通过,自动上架；
				office.setOnlineStatus("1");
				office.setOnlineTime(new Date());
			}else{
				//审核拒绝，自动下架
				office.setOnlineStatus("0");
				SimpleDateFormat simFormat = new SimpleDateFormat("yyyy.MM.dd HH:mm:ss"); 
				Date dtBeg = simFormat.parse("1997.01.01 23:59:59");
				office.setOnlineTime(dtBeg);
			}
			office.setAuditRemark(office.getAuditReasion());
			
			//1）更新写字楼表
			resInt= officeService.updateOffice(office);
			//2）添加审核记录
			this.officeService.addAudit(oldOffice,office);
			
			//3)添加写字楼扩展表
			if( office.getJiafangUserId() !=null && office.getJiedaiUserId() !=null ){
				OfficeExtend  offExtend=this.officeService.findExtendEntity(office.getId()+"");
				if(offExtend ==null){
					offExtend=new OfficeExtend();
					offExtend.setOfficeId(office.getId().intValue());
					offExtend.setJiafangUserId(office.getJiafangUserId());
					offExtend.setJiedaiUserId(office.getJiedaiUserId());
					offExtend.setJiafangUserName(office.getJiafangUserName());
					offExtend.setJiedaiUserName(office.getJiedaiUserName());
					this.officeService.addExtend(offExtend);
				}else{
					offExtend.setOfficeId(office.getId().intValue());
					offExtend.setJiafangUserId(office.getJiafangUserId());
					offExtend.setJiedaiUserId(office.getJiedaiUserId());
					offExtend.setJiafangUserName(office.getJiafangUserName());
					offExtend.setJiedaiUserName(office.getJiedaiUserName());
					this.officeService.updateExtend(offExtend);
				}
			}
			if(office.getAuditStatus() == 2){
				newService.sendSuccessMessage(oldOffice.getTitle(), oldOffice.getAgentId());
			}else {
				newService.sendFailMessage(oldOffice.getTitle(), oldOffice.getAgentId());
			}
		} catch (Exception e) {
			e.printStackTrace();
			return toAjax(0);
		}
		return toAjax(resInt);
	}
	
	
	
	
}
