package com.up.mls.controller.office;

import java.util.Collections;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.repository.query.Param;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.office.OfficeService;
import com.up.mls.service.shop.ShopBusinessTypeService;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.util.DateUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.office.Office;
import com.up.mls.vo.shop.Shop;
import com.up.mls.vo.shop.ShopBusinessType;
import com.up.mls.vo.user.AppUser;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 * 写字楼Controller
 * 写字楼类别：写字楼出租、写字楼出售、新盘出租、新盘出售
 * 功能：新增、修改、查看、上架、下架
 * 
 * @author boat
 *
 */
@Controller
@RequestMapping("/office")
public class OfficeController extends AbstractController{

	@Autowired
	private OfficeService officeService;
	@Autowired
	private ShopBusinessTypeService shopBusinessTypeService;
	@Autowired
	private IAppUserService appUserService;

    private static final Logger log = LoggerFactory.getLogger(OfficeController.class);


	//跳转到列表页面	 type 1=出租；2=出售；3=新盘出租；4=新盘出售
    @RequestMapping("office")
	public String office(String rentType,String type,ModelMap mmap) {
		/*mmap.put("onlineNum", officeService.selectOnOfflineCount("1",rentType));
		mmap.put("offlineNum", officeService.selectOnOfflineCount("0",rentType));*/
		mmap.put("rentType", rentType);
		mmap.put("today", DateUtils.getToday(new Date()));
		if (type.equals("1")){
			//1=写字楼出租
			return "office/rentList";
		}else if (type.equals("2")){
			//2=写字楼出售
			return "office/saleList";
		}else if (type.equals("3")){
			//3=写字楼新盘出租
			return "office/newRentList";
		}else {
			//4=写字楼新盘出售
			return "office/newSaleList";
		}
	}
	
    /**
     * 分页数据   写字楼出租-出售-新盘出租-新盘出售
     * @param rentType
     * @param office
     * @return
     */
	@Secured("office:list")
	@RequestMapping("list/{rentType}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("rentType") String rentType,Office office) {
		startPage();
		office.setUserId(SpringSecurityUtils.getUserId().toString());
		office.setRentType(rentType);
		if(office.getDateType() ==null){
			//默认当天
			office.setDateType("1");
			String today=DateUtils.getStringDate(new Date());
			office.setBeginTime(today);
			office.setEndTime(today);
		}else if("-1".equals(office.getDateType())){
			//全部类型
			office.setDateType(null);
		}
		List<Office> offices = officeService.selectOfficeList(office);
		return getDataTable(offices);
	}

	/**
	 * renType 写字楼类别（1:出租 2:出售 3:新盘出租 4-新盘出售）
	 * @param rentType
	 * @param mmap
	 * @return
	 */
	@RequestMapping("toSave/{rentType}")
	public String add(@PathVariable("rentType") String rentType,ModelMap mmap) {
		mmap.put("rentType", rentType);
		return "office/add";
	}
	
	@PostMapping("save")
	@ResponseBody
	public AjaxResult save(@RequestBody Office office,BindingResult result) {
		return toAjax(officeService.insertOffice(office));
	}
	
	
	/**
	 * 编辑之前回显写字楼详情
	 * @param id
	 * @param mmap
	 * @return
	 */
	@RequestMapping("/toEdit/{id}")
	public String edit(@PathVariable("id") Long id, ModelMap mmap) {
		Office  office=officeService.toEdit(id);
		//格式化佣金(乘以100回显)
		this.officeService.jsonHuiXianOfficeCommission(office);
		//内外经济人
		AppUser  appUser=this.appUserService.selectByPrimaryKey(office.getAgentId()+"");
		mmap.put("own",appUser==null?1:appUser.getOwn());//0：外部 ；1：内部
		mmap.put("office",office);
		return "office/edit";
	}
	/**
	 * 保存编辑
	 * @param shp
	 * @return
	 */
	@Secured("office:saveEdit")
	@PostMapping("saveEdit")
	@ResponseBody
	public AjaxResult saveEdit(@RequestBody Office office) {
		
		//编辑时状态：下架且待审核
		office.setAuditStatus(1);
		office.setOnlineStatus("0");
		//office.setRenlinUserId(-1);//待认领
		return toAjax(officeService.updateOffice(office));
	}
	
	
	@RequestMapping("/detail/{id}")
	public String detail(@PathVariable("id") Long id, ModelMap mmap) {
        Office detail = officeService.detail(id);
        //格式化佣金(乘以100回显)
      	this.officeService.jsonHuiXianOfficeCommission(detail);
        mmap.put("office",detail);
        log.error("=======================================================mlgb:{}",detail.toString());
		return "office/detail";
	}
	
	/**
	 * 上架
	 */
	@PostMapping("onlineBrand")
	public @ResponseBody Boolean onlineBrand(Long id) {
		Office office = officeService.selectByPrimaryKey(id);
		office.setOnlineStatus("1");
		officeService.updateOfficeOnlineStatus(office);
		return true;
	}
	/**
	 * 下架
	 */
	@PostMapping("offlineBrand")
	public @ResponseBody Boolean offlineBrand(Long id) {
		Office office = officeService.selectByPrimaryKey(id);
		office.setOnlineStatus("0");
		officeService.updateOfficeOnlineStatus(office);
		return true;
	}
	
	/**
	 * 保存排序
	 */
	@PostMapping("saveSort")
	public @ResponseBody Boolean saveSort(Long id,String sort) {
		int sortValue = 0;
		try{
			sortValue = Integer.valueOf(sort);
		}catch(Exception e) {
			System.out.println(e);
			return false;
		}
		Office office = new Office();
		office.setId(id);
		office.setSort(sortValue);
		officeService.updateOfficeSort(office);
		return true;
	}
	
	
	
	/**
	 * 查找二级业态
	 */
	@SuppressWarnings("unchecked")
	@GetMapping("findSon")
	public @ResponseBody List<ShopBusinessType> findSon(@Param("pid") String pid) {
		if (StringUtils.isNotBlank(pid) && NumberUtils.isCreatable(pid)) {
			List<ShopBusinessType> list = shopBusinessTypeService.selectSBTByPid(Long.valueOf(pid));
			System.out.println("list : "+list.size());
			return shopBusinessTypeService.selectSBTByPid(Long.valueOf(pid));
		}
		return Collections.EMPTY_LIST;
	}

	/**
	 * 查找一级业态
	 */
	@GetMapping("findParent")
	public @ResponseBody List<ShopBusinessType> findParent() {
		List<ShopBusinessType> list = shopBusinessTypeService.selectSBTByPidNot();
		System.out.println("list : "+list.size());
		return shopBusinessTypeService.selectSBTByPidNot();
	}
	
	
	/**
	 * 商铺查询条件检测
	 */
	public int isQueryParam(Shop shop) {
		if(StringUtils.isNotBlank(shop.getPhone()) || StringUtils.isNotBlank(shop.getShopName()) || StringUtils.isNotBlank(shop.getCreateType()) || StringUtils.isNotBlank(shop.getType()) ||
				StringUtils.isNotBlank(shop.getOnlineStatus()) ||StringUtils.isNotBlank(shop.getPhone()) || shop.getParentManageTypeId() != null || shop.getSonManageTypeId() != null || 
				shop.getParams() != null || shop.getParams() != null) {
			System.out.println("=== : "+shop.getParams().size());
			return 1;
		}else {
			return 0;
		}
	}
	
	/**
	 * 是否置顶
	 */
	@PostMapping("updateTopStatus")
	public @ResponseBody Boolean updateTopStatus(Long id) {
		Office entity = this.officeService.selectByPrimaryKey(id);
		if(entity.getTopStatus() !=null && "1".equals(entity.getTopStatus())){
			entity.setTopStatus("0");
			entity.setTopBeginTime(null);
		}else{
			entity.setTopStatus("1");
			entity.setTopBeginTime(new Date());
		}
		this.officeService.updateTopStatus(entity);
		return true;
	}
	
	
	
}


