package com.up.mls.controller.order;

import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.order.OrderService;
import com.up.mls.util.ServletUtils;
import com.up.mls.vo.deal.ProjectOrder;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 * 线下结佣管理
 */
@Controller
@RequestMapping("/order")
public class OrderController extends AbstractController {

    private String prefix = "order";

    @Autowired
    private OrderService orderService;

    
    /**
     * 跳转到结佣分页列表
     * @return
     */
    @GetMapping("index")
    public String index(){
        return prefix + "/jyOrderList";
    }

	/**	
	 * 结佣审核列表加载分页数据
	 * @param request
	 * @return
	 */
	@ResponseBody
    @PostMapping("/list")
    public TableDataInfo list(HttpServletRequest request) {
        startPage();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        List<Map<String,Object>> list = orderService.selectList(parameters);
        return getDataTable(list);
    }
	
	
	/**
     * 跳转到结佣审核列表
     * @param orderNo
     * @param mmap
     * @return
     */
	@RequestMapping("toDetail/{orderNo}")
	public String add(@PathVariable("orderNo") String orderNo,ModelMap mmap) {
		mmap.put("list", this.orderService.findOrderLogList(orderNo));
		mmap.put("orderNo",orderNo);
		return prefix + "/jyOrderlog";
	}
	
	/**
     * 审核提交保存
     * @param orderNo
     * @param mmap
     * @return
     */
	@Secured("brand:edit")
	@PostMapping("saveVerify")
	@ResponseBody
	public AjaxResult saveVerify(ProjectOrder entity) {
		return toAjax(orderService.updateOrder(entity));
	}
    
}
