package com.up.mls.controller.photo;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.photo.ShopMoneyService;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.shop.ShopPhoto;
import com.up.mls.vo.system.Company;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 奖金发放
 */
@Controller
@RequestMapping("/shopMoney")
public class ShopMoneyController extends AbstractController {

    @Autowired
    private ShopMoneyService shopMoneyService;

    @Autowired
    private ICompanyService companyService;

    @GetMapping("/index")
    public String index(ShopPhoto shopPhoto) {
        Long companyId = SpringSecurityUtils.getUser().getCompanyId();
        Company company = companyService.selectCompanyById(companyId);
        if (shopPhoto.getGrant() == 1) {
            if (company.getCityId() == 110100){
                return "shopPhoto/shopMoneyWait";
            }
            //其他地区奖金未发放页面
            return "shopPhoto/otherShopMoneyWait";
        }
        if (company.getCityId() == 110100){
            //北京地区奖金已发放页面
            return "shopPhoto/shopMoney";
        }
        return "shopPhoto/otherShopMoney";
    }

    /**
     * 奖金未发放
     *
     * @param shopPhoto
     * @return
     */
    @ResponseBody
    @PostMapping("/shopWaitMoney")
    public TableDataInfo waitlist(ShopPhoto shopPhoto) {
        startPage();
        List<ShopPhoto> shopPhotoList = shopMoneyService.selectWaitList(shopPhoto);
        return getDataTable(shopPhotoList);
    }

    /**
     * 奖金已发放
     * @param shopPhoto
     * @return
     */
    @ResponseBody
    @PostMapping("/shopMoney")
    public TableDataInfo shopMoney(ShopPhoto shopPhoto){
        startPage();
        List<ShopPhoto> shopPhotoList = shopMoneyService.shopMoney(shopPhoto);
        return getDataTable(shopPhotoList);
    }


    /**
     * 奖金发放详情页面 未发放
     *
     * @param parameter
     * @param model
     * @return
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String parameter, Model model) {
        Long companyId = SpringSecurityUtils.getUser().getCompanyId();
        Company company = companyService.selectCompanyById(companyId);
        ShopPhoto shopPhoto = shopMoneyService.selectDetail(parameter);
        model.addAttribute("entity", shopPhoto);
        if (company.getCityId() == 110100){
            return "shopPhoto/moneyDetail";
        }
        return "shopPhoto/otherMoneyDetail";
    }


    /**
     * 奖金发放详情 已发放
     *
     * @param parameter
     * @param model
     * @return
     */
    @GetMapping("/editFinish/{id}")
    public String editFinish(@PathVariable("id") String parameter, Model model) {
        Long companyId = SpringSecurityUtils.getUser().getCompanyId();
        Company company = companyService.selectCompanyById(companyId);
        ShopPhoto shopPhoto = shopMoneyService.selectFinishDetail(parameter);
        model.addAttribute("entity", shopPhoto);
        if (company.getCityId() == 110100){
            return "shopPhoto/moneyFinishDetail";
        }
        return "shopPhoto/otherMoneyFinishDetail";
    }


    /**
     * 奖金发放确认
     *
     * @param shopPhoto
     * @return
     */
    @ResponseBody
    @PostMapping("/update")
    public AjaxResult update(ShopPhoto shopPhoto) {
        return toAjax(shopMoneyService.update(shopPhoto));
    }

}
