package com.up.mls.controller.photo;


import com.up.mls.controller.AbstractController;
import com.up.mls.service.photo.ShopPhotoService;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.shop.ShopPhoto;
import com.up.mls.vo.system.Company;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

@Controller
@RequestMapping("/shopPhoto")
public class ShopPhotoController extends AbstractController {

    @Autowired
    private ShopPhotoService shopPhotoService;

    @Autowired
    private ICompanyService companyService;

    @GetMapping("/index")
    public String index(ShopPhoto shopPhoto) {
        Long companyId = SpringSecurityUtils.getUser().getCompanyId();
        Company company = companyService.selectCompanyById(companyId);
        if (shopPhoto.getState() == 2) {
            if (company.getCityId() == 110100) {
                return "shopPhoto/indexAdopt";
            }
            return "shopPhoto/indexOtherAdopt";
        } else if (shopPhoto.getState() == 3) {
            if (company.getCityId() == 110100) {
                return "shopPhoto/indexRefuse";
            }
            return "shopPhoto/indexOtherRefuse";
        }
        //待审核都走这个页面
        return "shopPhoto/index";
    }

    /**
     * 待审核查询列表
     *
     * @param shopPhoto
     * @return
     */
    @ResponseBody
    @RequestMapping("/adoptList")
    public TableDataInfo adoptList(ShopPhoto shopPhoto) {
        startPage();
        List<ShopPhoto> shopPhotoList = shopPhotoService.adoptList(shopPhoto);
        return getDataTable(shopPhotoList);
    }


    /**
     * 查询列表
     *
     * @param shopPhoto
     * @return
     */
    @ResponseBody
    @RequestMapping("/list")
    public TableDataInfo list(ShopPhoto shopPhoto) {
        startPage();
        List<ShopPhoto> shopPhotoList = shopPhotoService.selectList(shopPhoto);
        return getDataTable(shopPhotoList);
    }

    /**
     * 审核拍店
     *
     * @param id
     * @param model
     * @return
     */
    @RequestMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, Model model) {
        Long companyId = SpringSecurityUtils.getUser().getCompanyId();
        Company company = companyService.selectCompanyById(companyId);
        ShopPhoto shopPhoto = shopPhotoService.selectId(id);
        shopPhoto.setImg(Arrays.asList(shopPhoto.getPhotoImgs().split(",")));
        model.addAttribute("shopPhoto", shopPhoto);
        if (company.getCityId() == 110100) {
            return "shopPhoto/edit";
        }
        return "shopPhoto/otherEdit";
    }

    /**
     * 查看审核拍店详情 数据回显
     *
     * @param id
     * @param model
     * @return
     */
    @RequestMapping("/detail/{id}")
    public String detail(@PathVariable("id") Long id, Model model) {
        Long companyId = SpringSecurityUtils.getUser().getCompanyId();
        Company company = companyService.selectCompanyById(companyId);
        ShopPhoto shopPhoto = shopPhotoService.selectId(id);
        shopPhoto.setImg(Arrays.asList(shopPhoto.getPhotoImgs().split(",")));
        model.addAttribute("shopPhoto", shopPhoto);
        if (company.getCityId() == 110100) {
            return "shopPhoto/detail";
        }
        return "shopPhoto/otherDetail";
    }


    @ResponseBody
    @PostMapping("/update/{type}")
    public AjaxResult save(@PathVariable("type") String type, ShopPhoto shopPhoto) throws Exception {
        if (type.equals("adopt")) {
            shopPhoto.setState(2);
        } else {
            shopPhoto.setState(3);
        }
        return toAjax(shopPhotoService.update(shopPhoto));
    }


}
