package com.up.mls.controller.shop;


import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.google.common.collect.ImmutableMap;
import com.up.mls.common.constant.FlowStatus;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.shop.ShopService;
import com.up.mls.util.DateUtils;
import com.up.mls.vo.shop.Shop;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

import cn.org.rapid_framework.util.ObjectUtils;
/**
 * 商铺审核模块Controller
 * 包括：认领、释放、审核
 * 注：谁认领谁审核
 * @author joker
 *
 */
@Controller
@RequestMapping("shopAudit")
public class ShopAuditController extends AbstractController{

	@Autowired
	private ShopService shopService;
	
	/**
	 * 商铺审核待认领列表(公共)
	 * 待认领、已认领
	 * @param rentType
	 * @param mmap
	 * @return
	 */
	@RequestMapping("listClaim")
	public String shopClaim(String rentType,ModelMap mmap) {
		mmap.put("rentType", rentType);
		return "audit/shop/listClaim";
	}
	@Secured("shop:list")
	@RequestMapping("dataClaim")
	@ResponseBody
	public TableDataInfo list(Shop shop) {
		//临时处理列表数据加载过慢问题，列表初始化时只加载当天的数据
		if(ObjectUtils.isNullOrEmptyString(shop.getParams())) {
			Map<String, Object> params = new HashMap<String,Object>();
			params.put("beginTime", DateUtils.getToday(new Date()));
			shop.setParams(params);
		}
		shop.setListType(1);
		if(shop.getClaimStatus() == null) {
			shop.setClaimStatus(0);}
		startPage();
		List<Shop> shops = shopService.selectShopList(shop);
		return getDataTable(shops);
	}
	
	/**
	 * 认领审核商铺
	 */
	@RequestMapping("claimAudit")
	@ResponseBody
	public AjaxResult claimAudit( Shop shop) {
		Map<String, String> map = new HashMap<>();
		shopService.updateShopClaimForAudit(shop, getUserId());
		map.put("Type", "200");
		return toAjax(1);
	}
	
	/**
	 * 批量认领审核商铺
	 */
	@RequestMapping("claimAuditBatch")
	@ResponseBody
	public Map<String, String> claimAuditBatch(Long[] ids) {
		shopService.updateShopClaimForAuditByBatch(ids, getUserId());
		return ImmutableMap.of("count", String.valueOf(ids.length));
	}
	
	/**
	 * 释放商铺
	 */
	@RequestMapping("releaseShop")
	@ResponseBody
	public AjaxResult releaseShop(Shop shop) {
		Map<String, String> map = new HashMap<>();
		shopService.releaseShop(shop);
		map.put("Type", "200");
		return toAjax(1);
	}
	/**
	 * 批量释放
	 */
	@RequestMapping("releaseShopBatch")
	@ResponseBody
	public Map<String,String> releaseShopBatch(Long[] ids){
		shopService.releaseShopByBatch(ids, getUserId());
		return ImmutableMap.of("count", String.valueOf(ids.length));
	}
	
	/**
	 * 商铺待审核列表（个人）
	 * @param rentType
	 * @param mmap
	 * @return
	 */
	@RequestMapping("listAudit")
	public String shopAudit(String rentType,ModelMap mmap) {
		mmap.put("currUserName", getUsername());
		return "audit/shop/listAudit";
	}
	@Secured("shop:list")
	@RequestMapping("dataAudit")
	@ResponseBody
	public TableDataInfo DataAudit(Shop shop) {
		startPage();
		shop.setClaimAuditAccountId(getUserId());
		shop.setClaimStatus(1); 	//已认领
		shop.setListType(2);
		//默认查询待审核数据
		if(shop.getShopAudit() == null) {
			shop.setShopAudit(FlowStatus.AUDIT_OF_WAIT);
		}
		List<Shop> shops = shopService.selectShopList(shop);
		return getDataTable(shops);
	}
	
	
	/**
	 *跳转核实商铺页面 
	 * 
	 * @param 
	 * @return
	 */
	@GetMapping("toAudit/{id}")
	public String auditAddPage(@PathVariable("id") Long id, ModelMap mmap) {
		Shop shop = shopService.detail(id);
		mmap.put("shop",shop);
		if("1".equals(shop.getRentType())) {
			return "audit/shop/auditRent";
		}else if("2".equals(shop.getRentType())) {
			return "audit/shop/auditSell";
		}else if("3".equals(shop.getRentType())) {
			return "audit/shop/auditNewRent";
		}else{
			return "audit/shop/auditNewSell";
		}
	}
	
	/**
	 * 保存商铺核实
	 * 0:拒绝 1:通过
	 */
	@Secured("shop:saveAudit")
	@PostMapping("saveAudit")
	@ResponseBody
	public AjaxResult saveAudit(@RequestBody Shop shop) {
//		showFile(shop);
		Map<String, String> map = new HashMap<>();
		shopService.updateShopAudit(shop,getUserId(),getUsername());
		map.put("Type", "200");
		return toAjax(1);
	}
	
	@RequestMapping("findAuditRecord")
	public String findAuditRecord(String shopId,ModelMap mmap) throws InterruptedException {
		System.out.println("====== "+shopId);
		mmap.put("auditList", shopService.findAuditList(shopId));
		return "audit/shop/auditRecord";
	}
	
	/**
	 * 现在商铺字段
	 */
	public void showFile(Shop shop) {
		System.out.println(shop.getAreaId()+"  "+shop.getBusinessAreaId()+"  "+shop.getRealAddress()+"  "+shop.getType());
		System.out.println(shop.getBuildArea()+"   "+shop.getUseArea()+"  "+shop.getParentManageTypeId()+"   "+shop.getSonManageTypeId());
		System.out.println(shop.getShopSupportingsId()+"  "+shop.getFloor1()+"  "+shop.getManageStatus()+"   "+shop.getFrontage());
		System.out.println(shop.getFaceWidth()+"  "+shop.getDepth()+"  "+shop.getFloorHeight());
		System.out.println("=======");
		System.out.println(shop.getDailyRent()+"  "+shop.getTransferFee()+"  "+shop.getPledgeInfo()+" "+shop.getPayMethod());
		System.out.println("========");
//		System.out.println(shop.getShopTagId()+"  "+shop.getLicense()+"  "+shop.getShopPaperId().size());
		System.out.println(shop.getImgs()+"  "+shop.getIntroduce()+"   "+shop.getSupportProfile());
		System.out.println("========");
		System.out.println(shop.getCommission()+"   "+shop.getCommissionType()+"  "+shop.getCommissionValue()+"  "+shop.getExpired());
		System.out.println(shop.getLinkman()+"  "+shop.getPhone()+"  "+shop.getEntrustPaper());
		System.out.println(shop.getPhoneOld()+"    "+shop.getCommissionValueOld());
	}
}
