package com.up.mls.controller.shop;

import java.util.*;

import com.alibaba.fastjson.JSON;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.repository.query.Param;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.service.shop.ShopBusinessTypeService;
import com.up.mls.service.shop.ShopService;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.util.DateUtils;
import com.up.mls.vo.shop.Shop;
import com.up.mls.vo.shop.ShopBusinessType;
import com.up.mls.vo.user.AppUser;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

import cn.org.rapid_framework.util.ObjectUtils;



/**
 * 商铺Controller
 * 商铺类别：商铺出租、商铺出售、新盘商铺出租、新盘商铺出售
 * 商铺新增、修改、查看、上架、下架
 * 
 * @author joker
 *
 */
@Controller
@RequestMapping("/shop")
public class ShopController extends AbstractController{

	@Autowired
	private ShopService shopService;
	@Autowired
	private ShopBusinessTypeService shopBusinessTypeService;
	@Autowired
	private IAppUserService appUserService;


	/**
	 * 商铺列表
	 * @param rentType
	 * @param mmap
	 * @return
	 */
	@RequestMapping("list")
	public String shop(String rentType,ModelMap mmap) {
		mmap.put("rentType", rentType);
		return "shop/list";
	}

	@Secured("shop:list")
	@RequestMapping("data/{rentType}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("rentType")String rentType,Shop shop) {
		//临时处理列表数据加载过慢问题，列表初始化时只加载当天的数据
		if(ObjectUtils.isNullOrEmptyString(shop.getParams())) {
			Map<String, Object> params = new HashMap<String,Object>();
			params.put("beginTime", DateUtils.getToday(new Date()));
			shop.setParams(params);
		}
		shop.setListType(3);
		startPage();
		shop.setRentType(rentType);
		List<Shop> shops = shopService.selectShopList(shop);
		return getDataTable(shops);
	}
	
	@RequestMapping("toSave/{rentType}")
	public String add(@PathVariable("rentType") int rentType,ModelMap mmap) {
		mmap.put("rentType", rentType);
		return "shop/add";
	}

	@RequestMapping("toSaveNewShop/{rentType}")
	public String addNewShop(@PathVariable("rentType") int rentType,ModelMap mmap) {
		mmap.put("rentType", rentType);
		return "shop/addNewShop";
	}


	@PostMapping("save")
	@ResponseBody
	public AjaxResult save(@RequestBody Shop shop,BindingResult result) {
		showShopFiled(shop);
		//设置一些必填值
		shop.setAgentId(new Long(1));//经纪人id
		return toAjax(shopService.insertShop(shop));
	}

	@RequestMapping("/toEdit/{id}")
	public String edit(@PathVariable("id") Long id, ModelMap mmap) {
		Shop shop = shopService.toEdit(id);
		mmap.put("shop",shop);
		if("1".equals(shop.getRentType())) {
			return "shop/editRent";
		}else if("2".equals(shop.getRentType())) {
			return "shop/editSell";
		}else if("3".equals(shop.getRentType())) {
			return "shop/editNewRent";
		}else {
			return "shop/editNewSell";
		}
	}

	/**
	 * 保存shop编辑
	 * @param shp
	 * @return
	 */
	@Secured("shop:saveEdit")
	@PostMapping("saveEdit")
	@ResponseBody
	public AjaxResult saveEdit(@RequestBody Shop shop) {
		shop.setAgentId(new Long(1));//经纪人id
		return toAjax(shopService.saveEdit(shop));
	}
	
	
	@RequestMapping("/detail/{id}")
	public String detail(@PathVariable("id") Long id, ModelMap mmap) {
		Shop shop = shopService.detail(id);
		mmap.put("shop",shop);
		if("1".equals(shop.getRentType())){
			return "shop/detailRent";
		}else if("2".equals(shop.getRentType())) {
			return "shop/detailSell";
		}else if("3".equals(shop.getRentType())) {
			return "shop/detailNewRent";
		}else {
			return "shop/detailNewSell";
		}
	}
	
	
	/**
	 * 上架
	 */
	@PostMapping("onlineBrand")
	public @ResponseBody Boolean onlineBrand(Long id) {
		Shop shop = shopService.selectByPrimaryKey(id);
		shop.setOnlineStatus("1");
		shopService.updateShopOnlineStatus(shop);
		return true;
	}
	
	/**
	 * 下架
	 */
	@PostMapping("offlineBrand")
	public @ResponseBody Boolean offlineBrand(Long id) {
		Shop shop = shopService.selectByPrimaryKey(id);
		shop.setOnlineStatus("0");
		shopService.updateShopOnlineStatus(shop);
		return true;
	}
	
	
	/**
	 * 是否置顶
	 */
	@PostMapping("updateTopStatus")
	public @ResponseBody Boolean updateTopStatus(Long id) {
		Shop entity = shopService.selectByPrimaryKey(id);
		if(entity.getTopStatus() !=null && "1".equals(entity.getTopStatus())){
			entity.setTopStatus("0");
			entity.setTopBeginTime(null);
		}else{
			entity.setTopStatus("1");
			entity.setTopBeginTime(new Date());
		}
		shopService.updateTopStatus(entity);
		return true;
	}
	
	
	
	/**
	 * 保存排序
	 */
	@PostMapping("saveSort")
	public @ResponseBody Boolean saveSort(Long id,String sort) {
		int sortValue = 0;
		try{
			sortValue = Integer.valueOf(sort);
		}catch(Exception e) {
			return false;
		}
		Shop shop = new Shop();
		shop.setId(id);
		shop.setSort(sortValue);
		shopService.updateShopSort(shop);
		return true;
	}
	
	
	
	
	@GetMapping("isShopNumber")
	public @ResponseBody Integer isShopNumber(String shopNumber) {
		return shopService.isShopNumber(shopNumber);
	}
	
	@GetMapping("/getAgent")
	@ResponseBody
	public List<AppUser> getAgent(){
		//获取 经纪人列表
		List<AppUser> list = appUserService.selectAppUserForAgent(2);
		System.out.println("size : "+list.size());
		return list;
	}


	/**
	 * 获取审核人列表
	 * @return
	 */
	@GetMapping("/getAuditAccount")
	@ResponseBody
	public String getAuditAccount(){
		return JSON.toJSONString(appUserService.selectAuditAccount());
	}


	/**
	 * 查找二级业态
	 */
	@SuppressWarnings("unchecked")
	@GetMapping("findSon")
	public @ResponseBody List<ShopBusinessType> findSon(@Param("pid") String pid) {
		if (StringUtils.isNotBlank(pid) && NumberUtils.isCreatable(pid)) {
			List<ShopBusinessType> list = shopBusinessTypeService.selectSBTByPid(Long.valueOf(pid));
			System.out.println("list : "+list.size());
			return shopBusinessTypeService.selectSBTByPid(Long.valueOf(pid));
		}
		return Collections.EMPTY_LIST;
	}

	/**
	 * 查找一级业态
	 */
	@GetMapping("findParent")
	public @ResponseBody List<ShopBusinessType> findParent() {
		List<ShopBusinessType> list = shopBusinessTypeService.selectSBTByPidNot();
		System.out.println("list : "+list.size());
		return shopBusinessTypeService.selectSBTByPidNot();
	}
	
	
	/**
	 * 商铺查询条件检测
	 */
	public int isQueryParam(Shop shop) {
		if(StringUtils.isNotBlank(shop.getShopNumber()) || StringUtils.isNotBlank(shop.getCreateType()) || StringUtils.isNotBlank(shop.getType()) ||
				shop.getAuditAccountId() != null || shop.getCityId() != null || shop.getAgentId() != null ||
				StringUtils.isNotBlank(shop.getOnlineStatus()) ||StringUtils.isNotBlank(shop.getPhone()) || shop.getParentManageTypeId() != null || shop.getSonManageTypeId() != null || 
				(shop.getParams() != null && (shop.getParams().get("beginTime") != null && shop.getParams().get("beginTime") != "")) || (shop.getParams() != null && (shop.getParams().get("endTime") != null && shop.getParams().get("endTime") != ""))) {
			System.out.println("=== : "+shop.getParams().size());
			return 1;
		}else {
			return 0;
		}
	}
	
	/**
	 * 新增商铺 字段查看
	 */
	public void showShopFiled(Shop shop) {
//		System.out.println("linkman : "+shop.getLinkman()+"  phone:"+shop.getPhone());
//		System.out.println("monthlyRent : "+shop.getMonthlyRent()+"  turnoverShare:"+shop.getTurnoverShare()+"  dailyRent:"+shop.getDailyRent()+"  yearlyRent:"+shop.getYearlyRent()+"   transferFee:"+shop.getTransferFee()+"  pledgeMethod:"+shop.getPledgeMethod()+"  pledgeInfo:"+shop.getPledgeInfo()+"  payMethod:"+shop.getPayMethod());
//		System.out.println("stauts : "+shop.getStatus()+"  rentType:"+shop.getRentType()+"  timeRent:"+shop.getTimeRent()+" currLease:"+shop.getCurrLease()+"   residue:"+shop.getResidue()+"   maxleas:"+shop.getMaxLease()+"  leaseCase0:"+shop.getLeaseCase0()+"  leaseCase1:"+shop.getLeaseCase1());
//		System.out.println("type:"+shop.getType()+"  buildArea:"+shop.getBuildArea()+"  useArea:"+shop.getUseArea()+"  spearate:"+shop.getSeparate()+"  frontage:"+shop.getFrontage()+"  floor:"+shop.getFloor1()+" "+shop.getFloorHigh()+" "+shop.getFloorUnder());
//		System.out.println("shopSupporting:"+shop.getShopSupportingsId()+"  shopTagId:"+shop.getShopTagId()+"  license:"+shop.getLicense()+"  shopPapers:"+shop.getShopPaperId()+"  manageeStatus:"+shop.getManageStatus());
//		System.out.println("parentManageTypeId:"+shop.getParentManageTypeId()+"  sonManageTypeId:"+shop.getSonManageTypeId()+"  shopTagId:"+shop.getShopTagId()+"  license:"+shop.getLicense()+"  shopPapers:"+shop.getShopPaperId()+"  manageeStatus:"+shop.getManageStatus());
//		System.out.println("imgs : "+shop.getImgs());
//		Set<String> set = shop.getShopSupportingsId();
//		if (null != set){
//			Iterator<String> it = set.iterator();
//			while (it.hasNext()) {
//				String str = it.next();
//				System.out.println(str);
//			}
//		}
	}
	
	
	
	
	
//	//配套
//			List<ShopShopSupporting> sssting = shopShopSupportingService.selectSupportingByShop(shop.getId());
//			Set<String> supportSet = new HashSet<String>();
//			sssting.forEach(s -> {
//				String supportId = s.getShopSupportingId();
//				supportSet.add(supportId);
//			});
//			shop.setShopSupportingsId(supportSet);
//			//特色标签
//			List<ShopShopTag> tagList = shopShopTagService.selectTagByShop(shop.getId());
//			Set<String> tagSet = new HashSet<String>();
//			tagList.forEach(s -> {
//				String tagId = s.getShopTagId();
//				tagSet.add(tagId);
//			});
//			shop.setShopTagId(tagSet);
//			//已有证件
//			List<ShopShopPaper> paperList =  shopShopPaperService.selectPaperByShop(shop.getId());
//			Set<String> paperSet = new HashSet<String>();
//			paperList.forEach(s -> {
//				String paperId = s.getShopPaperId();
//				paperSet.add(paperId);
//			});
//			shop.setShopPaperId(paperSet);
}