package com.up.mls.controller.system;

import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.annotation.Log;
import com.up.mls.common.constant.BusinessType;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.service.system.IUserService;
import com.up.mls.vo.system.Company;
import com.up.mls.vo.system.User;
import com.up.mls.web.domain.AjaxResult;

/**
 * 参数配置 信息操作处理
 * 
 * @author j.x.j
 */
@Controller
@RequestMapping("system/company")
public class CompanyController extends AbstractController {

	private String prefix = "system/company";

	@Autowired
	private ICompanyService companyService;
	
	@Autowired
	private IUserService userService;

	@Secured("system:company:view")
	@GetMapping()
	public String config() {
		return prefix + "/company";
	}

	/**
	 * 查询公司列表
	 */
	@Secured("system:company:list")
	@GetMapping("/list")
	@ResponseBody
	public List<?> list(Company company) {
		return companyService.selectCompanyList(company);
	}

	/**
	 * 新增公司页面
	 */
	@GetMapping("/add/{parentId}")
	public String add(@PathVariable("parentId") Long companyId, ModelMap mmap) {
		mmap.addAttribute("company", companyService.selectCompanyById(companyId));
		return prefix + "/add";
	}

	/**
	 * 新增公司处理
	 */
	@Secured("system:company:add")
	@Log(title = "公司管理", action = BusinessType.INSERT)
	@PostMapping("/add")
	@ResponseBody
	public AjaxResult addSave(Company company) {
		try{
			if(companyService.findByVerifyCity(company).size() > 0)
				return error("该城市已有分公司！");		
			return toAjax(companyService.insertCompany(company));
		}catch(Exception e){
			return error();
		}
	}

	/**
	 * 修改公司信息页面
	 */
	@GetMapping("/edit/{companyId}")
	public String edit(@PathVariable("companyId") Long companyId, ModelMap mmap) {
		Company entity = companyService.selectCompanyById(companyId);
		mmap.put("entity", entity);
		mmap.put("parentCompanyName", companyService.selectCompanyById(entity.getParentId()).getCompanyName());
		return prefix + "/edit";
	}

	/**
	 * 修改公司处理
	 */
	@Secured("system:company:edit")
	@Log(title = "公司管理", action = BusinessType.UPDATE)
	@PostMapping("/edit")
	@ResponseBody
	public AjaxResult editSave(Company company) {
		return toAjax(companyService.updateCompany(company));
	}

	/**
	 * 删除公司
	 */
	@Secured("system:config:remove")
	@Log(title = "公司管理", action = BusinessType.DELETE)
	@PostMapping("/remove/{companyId}")
	@ResponseBody
	public AjaxResult remove(@PathVariable("companyId") Long companyId) {
		try{
			User user =new User();
			user.setCompanyId(companyId);
			
			if(userService.selectUserList(user).size() > 0)
				return error("请先删除公司的员工！");
			companyService.deleteCompanyById(companyId);
			return success();
		}catch(Exception e){
			return error();			
		}
	}

	/**
	 * 校验参数键名
	 */
	@PostMapping("/checkCompnayKeyUnique")
	@ResponseBody
	public int checkConfigKeyUnique(Company company) {
		return Optional.ofNullable(company).map(c -> companyService.checkCompanyNameUnique(c)).orElse(0);
	}

	/**
	 * 加载部门列表树
	 */
	@GetMapping("/treeData")
	@ResponseBody
	public List<?> treeData() {
		return companyService.selectCompanyTree();
	}
	
	
	@GetMapping("/findCityForCompany")
	@ResponseBody
	public List<Company> findCityForCompany() {
		return companyService.selectCityForCompany();
	}
}
