package com.up.mls.controller.system;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.annotation.Log;
import com.up.mls.common.constant.BusinessType;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.system.IConfigService;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.system.Config;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 * 参数配置 信息操作处理
 * 
 * @author j.x.j
 */
@Controller
@RequestMapping("/system/config")
public class ConfigController extends AbstractController {
	private String prefix = "system/config";

	@Autowired
	private IConfigService configService;

	@Secured("system:config:view")
	@GetMapping()
	public String config() {
		return prefix + "/config";
	}

	/**
	 * 查询参数配置列表
	 */
	@Secured("system:config:list")
	@PostMapping("/list")
	@ResponseBody
	public TableDataInfo list(Config config) {
		startPage();
		List<Config> list = configService.selectConfigList(config);
		return getDataTable(list);
	}

	/**
	 * 新增参数配置
	 */
	@GetMapping("/add")
	public String add() {
		return prefix + "/add";
	}

	/**
	 * 新增保存参数配置
	 */
	@Secured("system:config:add")
	@Log(title = "参数管理", action = BusinessType.INSERT)
	@PostMapping("/add")
	@ResponseBody
	public AjaxResult addSave(Config config) {
		return toAjax(configService.insertConfig(config));
	}

	/**
	 * 修改参数配置
	 */
	@GetMapping("/edit/{configId}")
	public String edit(@PathVariable("configId") Long configId, ModelMap mmap) {
		mmap.put("config", configService.selectConfigById(configId));
		return prefix + "/edit";
	}

	/**
	 * 修改保存参数配置
	 */
	@Secured("system:config:edit")
	@Log(title = "参数管理", action = BusinessType.UPDATE)
	@PostMapping("/edit")
	@ResponseBody
	public AjaxResult editSave(Config config) {
		return toAjax(configService.updateConfig(config));
	}

	/**
	 * 删除参数配置
	 */
	@Secured("system:config:remove")
	@Log(title = "参数管理", action = BusinessType.DELETE)
	@PostMapping("/remove")
	@ResponseBody
	public AjaxResult remove(String ids) {
		return toAjax(configService.deleteConfigByIds(ids));
	}

	/**
	 * 校验参数键名
	 */
	@PostMapping("/checkConfigKeyUnique")
	@ResponseBody
	public String checkConfigKeyUnique(Config config) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(config)) {
			uniqueFlag = configService.checkConfigKeyUnique(config);
		}
		return uniqueFlag;
	}

}
