package com.up.mls.controller.system;

import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.annotation.Log;
import com.up.mls.common.constant.BusinessType;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.system.IDeptService;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.system.Dept;
import com.up.mls.web.domain.AjaxResult;

/**
 * 部门信息
 * 
 * @author j.x.j
 */
@Controller
@RequestMapping("/system/dept")
public class DeptController extends AbstractController {
	private String prefix = "system/dept";

	@Autowired
	private IDeptService deptService;

	@Secured("system:dept:view")
	@GetMapping()
	public String dept() {
		return prefix + "/dept";
	}

	@Secured("system:dept:list")
	@GetMapping("/list")
	@ResponseBody
	public List<Dept> list(Dept dept) {
		List<Dept> deptList = deptService.selectDeptList(dept);
		return deptList;
	}

	/**
	 * 新增部门
	 */
	@GetMapping("/add/{parentId}")
	public String add(@PathVariable("parentId") Long parentId, ModelMap mmap) {
		mmap.put("dept", deptService.selectDeptById(parentId));
		return prefix + "/add";
	}

	/**
	 * 新增保存部门
	 */
	@Log(title = "部门管理", action = BusinessType.INSERT)
	@Secured("system:dept:add")
	@PostMapping("/add")
	@ResponseBody
	public AjaxResult addSave(Dept dept) {
		return toAjax(deptService.insertDept(dept));
	}

	/**
	 * 修改
	 */
	@GetMapping("/edit/{deptId}")
	public String edit(@PathVariable("deptId") Long deptId, ModelMap mmap) {
		mmap.put("dept", deptService.selectDeptById(deptId));
		return prefix + "/edit";
	}

	/**
	 * 保存
	 */
	@Log(title = "部门管理", action = BusinessType.UPDATE)
	@Secured("system:dept:edit")
	@PostMapping("/edit")
	@ResponseBody
	public AjaxResult editSave(Dept dept) {
		return toAjax(deptService.updateDept(dept));
	}

	/**
	 * 删除
	 */
	@Log(title = "部门管理", action = BusinessType.DELETE)
	@Secured("system:dept:remove")
	@PostMapping("/remove/{deptId}")
	@ResponseBody
	public AjaxResult remove(@PathVariable("deptId") Long deptId) {
		if (deptService.selectDeptCount(deptId) > 0) {
			return error(1, "存在下级部门,不允许删除");
		}
		if (deptService.checkDeptExistUser(deptId)) {
			return error(1, "部门存在用户,不允许删除");
		}
		return toAjax(deptService.deleteDeptById(deptId));
	}

	/**
	 * 校验部门名称
	 */
	@PostMapping("/checkDeptNameUnique")
	@ResponseBody
	public String checkDeptNameUnique(Dept dept) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(dept)) {
			uniqueFlag = deptService.checkDeptNameUnique(dept);
		}
		return uniqueFlag;
	}

	/**
	 * 选择部门树
	 */
	@GetMapping("/selectDeptTree/{deptId}")
	public String selectDeptTree(@PathVariable("deptId") Long deptId, ModelMap mmap) {
		mmap.put("dept", deptService.selectDeptById(deptId));
		return prefix + "/tree";
	}

	/**
	 * 加载部门列表树
	 */
	@GetMapping("/treeData")
	@ResponseBody
	public List<Map<String, Object>> treeData() {
		List<Map<String, Object>> tree = deptService.selectDeptTree();
		return tree;
	}
}
