package com.up.mls.controller.system;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.annotation.Log;
import com.up.mls.common.constant.BusinessType;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.system.IRoleService;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.system.Role;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

/**
 * 角色信息
 * 
 * @author j.x.j
 */
@Controller
@RequestMapping("/system/role")
public class RoleController extends AbstractController {

	private String prefix = "system/role";

	@Autowired
	private IRoleService roleService;

	@Secured("system:role:view")
	@GetMapping()
	public String role() {
		return prefix + "/role";
	}

	@Secured("system:role:list")
	@PostMapping("/list")
	@ResponseBody
	public TableDataInfo list(Role role) {
		startPage();
		List<Role> list = roleService.selectRoleList(role);
		return getDataTable(list);
	}

	/**
	 * 新增角色
	 */
	@GetMapping("/add")
	public String add() {
		return prefix + "/add";
	}

	/**
	 * 新增保存角色
	 */
	@Secured("system:role:add")
	@Log(title = "角色管理", action = BusinessType.INSERT)
	@PostMapping("/add")
	@Transactional(rollbackFor = Exception.class)
	@ResponseBody
	public AjaxResult addSave(Role role) {
		return toAjax(roleService.insertRole(role));

	}

	/**
	 * 修改角色
	 */
	@GetMapping("/edit/{roleId}")
	public String edit(@PathVariable("roleId") Long roleId, ModelMap mmap) {
		mmap.put("role", roleService.selectRoleById(roleId));
		return prefix + "/edit";
	}

	/**
	 * 修改保存角色
	 */
	@Secured("system:role:edit")
	@Log(title = "角色管理", action = BusinessType.UPDATE)
	@PostMapping("/edit")
	@Transactional(rollbackFor = Exception.class)
	@ResponseBody
	public AjaxResult editSave(Role role) {
		return toAjax(roleService.updateRole(role));
	}

	@Secured("system:role:remove")
	@Log(title = "角色管理", action = BusinessType.DELETE)
	@PostMapping("/remove")
	@ResponseBody
	public AjaxResult remove(String ids) {
		try {
			return toAjax(roleService.deleteRoleByIds(ids));
		} catch (Exception e) {
			return error(e.getMessage());
		}
	}

	/**
	 * 校验角色名称
	 */
	@PostMapping("/checkRoleNameUnique")
	@ResponseBody
	public String checkRoleNameUnique(Role role) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(role)) {
			uniqueFlag = roleService.checkRoleNameUnique(role);
		}
		return uniqueFlag;
	}

	/**
	 * 校验角色权限
	 */
	@PostMapping("/checkRoleKeyUnique")
	@ResponseBody
	public String checkRoleKeyUnique(Role role) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(role)) {
			uniqueFlag = roleService.checkRoleKeyUnique(role);
		}
		return uniqueFlag;
	}

	/**
	 * 选择菜单树
	 */
	@GetMapping("/selectMenuTree")
	public String selectMenuTree() {
		return prefix + "/tree";
	}

}