package com.up.mls.controller.system;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.StandardCopyOption;
import java.util.List;
import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.repository.query.Param;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import com.up.mls.annotation.Log;
import com.up.mls.common.constant.BusinessType;
import com.up.mls.controller.AbstractController;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.service.system.IRoleService;
import com.up.mls.service.system.IUserService;
import com.up.mls.service.system.UserProjectRelationService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.system.User;
import com.up.mls.vo.system.UserProjectRelation;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

import java.nio.file.Files;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 用户信息
 * 
 * @author j.x.j
 */
@Controller
@RequestMapping("/system/user")
public class UserController extends AbstractController {
	private String prefix = "system/user";

	@Autowired
	private IUserService userService;

	@Autowired
	private IRoleService roleService;

	@Autowired
	private UserProjectRelationService userProjectRelationService;

	@Autowired
	private ICompanyService companyService;

	@Secured("system:user:view")
	@GetMapping()
	public String user() {
		Long companyId = getUser().getCompanyId();
		if (Objects.equals(1L, companyId)) {
			return prefix + "/user";
		} else if(companyService.countChildByCompanyId(companyId) > 1) {
			return prefix + "/user";
		}else {
			 return prefix + "/user_company";
		}
	}

	@ApiOperation(value = "查询用户列表", notes = "根据user查询参数查询用户列表")
	@ApiImplicitParam(name = "user", dataTypeClass = User.class, value = "查询条件对象", required = false)
	@Secured("system:user:list")
	@RequestMapping("/list")
	@ResponseBody
	public TableDataInfo list(User user) {
		startPage();
		if(Objects.isNull(user.getCompanyId())) {
			user.setCompanyId(getCompanyId());
		}
		List<User> list = userService.selectUserList(user);
		return getDataTable(list);
	}

	@ApiOperation(value = "查询用户列表", notes = "根据user查询参数查询用户列表")
	@ApiImplicitParam(name = "user", dataTypeClass = User.class, value = "查询条件对象", required = false)
	@Secured("system:user:list")
	@PostMapping("/listByCompany")
	@ResponseBody
	public TableDataInfo listByCompanyId(User user) {
		startPage();
		user.setCompanyId(getUser().getCompanyId());
		List<User> list = userService.selectUserList(user);
		return getDataTable(list);
	}

	/**
	 * 新增用户
	 */
	@GetMapping("/add")
	public String add(ModelMap mmap) {
		mmap.put("roles", roleService.selectRoleAll());
		return prefix + "/add";
	}

	/**
	 * 总部新增用户
	 */
	@GetMapping("/add/{companyId}")
	public String add(@PathVariable("companyId") Long companyId, ModelMap mmap) {
		mmap.put("roles", roleService.selectRoleAll());
		mmap.put("company", companyService.selectCompanyById(companyId));
		return prefix + "/add";
	}

	/**
	 * 新增保存用户
	 */
	@Secured("system:user:add")
	@Log(title = "用户管理", action = BusinessType.INSERT)
	@PostMapping("/add")
	@Transactional(rollbackFor = Exception.class)
	@ResponseBody
	public AjaxResult addSave(User user) {
		if (StringUtils.isNotNull(user.getUserId()) && User.isAdmin(user.getUserId())) {
			return error("不允许修改超级管理员用户");
		}
		return toAjax(userService.insertUser(user));
	}
	
	/**
	 * 新增保存用户_项目关联
	 */
	@Secured("system:user:addUserProjectRelation")
	@Log(title = "用户管理", action = BusinessType.INSERT)
	@PostMapping("/addUserProjectRelation")
	@Transactional(rollbackFor = Exception.class)
	@ResponseBody
	public AjaxResult addUserProjectRelation(UserProjectRelation userProject) {
		userProjectRelationService.deleteByUserId(userProject.getUserId());
		String[] projectIds = userProject.getProjectList().split(",");
		userProject.setCreatedBy(SpringSecurityUtils.getLoginName());
		int i = 0;
		for (String string : projectIds) {
			userProject.setProjectId(Integer.parseInt(string));
			userProjectRelationService.add(userProject);
			i++;
		}
		return toAjax(i);
	}

	/**
	 * 修改用户
	 */
	@GetMapping("/edit/{userId}")
	@ApiOperation(value = "修改用户", notes = "根据用户id修改用户")
	@ApiImplicitParam(name = "userId", dataTypeClass = Long.class, value = "用户id", required = false)
	public String edit(@PathVariable("userId") Long userId, ModelMap mmap) {
		User user = userService.selectUserById(userId);
		mmap.put("user", user);
		mmap.put("roles", roleService.selectRolesByUserId(userId));
		mmap.put("company", companyService.selectCompanyById(user.getCompanyId()));
		// mmap.put("posts", postService.selectPostsByUserId(userId));
		return prefix + "/edit";
	}
	
	/**
	 * 个人信息
	 */
	@GetMapping("/profile")		
	public String profile(ModelMap mmap) {		
		User user = userService.selectUserById(getUser().getUserId());
		mmap.put("user", user);
		mmap.put("roles", roleService.selectRolesByUserId(getUser().getUserId()));
		mmap.put("company", companyService.selectCompanyById(user.getCompanyId()));
		// mmap.put("posts", postService.selectPostsByUserId(userId));
		return prefix + "/profile/profile";
	}
	
	@GetMapping("/profile/resetPwd/{userId}")
	public String profileResetPwd(@PathVariable("userId") Long userId, ModelMap mmap) {
		mmap.put("user", userService.selectUserById(userId));
		return prefix + "/profile/resetPwd";
	}
	
	@PostMapping("/profile/modifyPwd")
	@ResponseBody
	public AjaxResult modifyPwd(User user) {		
		return toAjax(userService.resetUserPwd(user));
	}
	
	@GetMapping("/profile/avatar/{userId}")
	public String avatar(@PathVariable("userId") Long userId, ModelMap mmap) {
		mmap.put("user", userService.selectUserById(userId));
		return prefix + "/profile/avatar";
	}
	
	@PostMapping("/profile/updateAvatar")
	@ResponseBody
	public AjaxResult updateAvatar(String userId, MultipartFile avatarfile) {		
       
        try {
        	InputStream is = avatarfile.getInputStream();
			Files.copy(is, new File("F://a.png").toPath(), StandardCopyOption.REPLACE_EXISTING);
		} catch (IOException e) {
			e.printStackTrace();
		}
		//return toAjax(userService.resetUserPwd(user));
		return null;
	}

	/**
	 * 修改保存用户
	 */

	@Secured("system:user:edit")
	@Log(title = "用户管理", action = BusinessType.UPDATE)
	@PostMapping("/edit")
	@Transactional(rollbackFor = Exception.class)
	@ResponseBody
	public AjaxResult editSave(User user) {
		if (StringUtils.isNotNull(user.getUserId()) && User.isAdmin(user.getUserId())) {
			return error("不允许修改超级管理员用户");
		}
		return toAjax(userService.updateUser(user));
	}

	@Secured("system:user:edit")
	@Log(title = "用户管理", action = BusinessType.UPDATE)
	@PostMapping("/editStatus")
	@Transactional(rollbackFor = Exception.class)
	@ResponseBody
	public AjaxResult editStatusSave(User user) {
		if (StringUtils.isNotNull(user.getUserId()) && User.isAdmin(user.getUserId())) {
			return error("不允许修改超级管理员用户");
		}
		return toAjax(userService.updateUserStatus(user));
	}

	@Secured("system:user:resetPwd")
	@Log(title = "重置密码", action = BusinessType.UPDATE)
	@GetMapping("/resetPwd/{userId}")
	public String resetPwd(@PathVariable("userId") Long userId, ModelMap mmap) {
		mmap.put("user", userService.selectUserById(userId));
		return prefix + "/resetPwd";
	}
	
	@Secured("system:user:allotProject")
	@Log(title = "分配交易项目", action = BusinessType.UPDATE)
	@GetMapping("/allotProject/{userId}")
	public String allotProject(@PathVariable("userId") Long userId, ModelMap mmap) {
		mmap.put("user", userService.selectUserById(userId));
		mmap.put("projects", userProjectRelationService.selectUserById(userId));
		return prefix + "/allot_project";
	}

	@Secured("system:user:resetPwd")
	@Log(title = "重置密码", action = BusinessType.UPDATE)
	@PostMapping("/resetPwd")
	@ResponseBody
	public AjaxResult resetPwd(User user) {
		return toAjax(userService.resetUserPwd(user));
	}

	@Secured("system:user:remove")
	@Log(title = "用户管理", action = BusinessType.DELETE)
	@PostMapping("/remove")
	@ResponseBody
	public AjaxResult remove(String ids) {
		try {
			return toAjax(userService.deleteUserByIds(ids));
		} catch (Exception e) {
			return error(e.getMessage());
		}
	}

	/**
	 * 校验用户名
	 */
	@PostMapping("/checkLoginNameUnique")
	@ResponseBody
	public String checkLoginNameUnique(User user) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(user)) {
			uniqueFlag = userService.checkLoginNameUnique(user.getLoginName());
		}
		return uniqueFlag;
	}

	/**
	 * 校验手机号码
	 */
	@PostMapping("/checkPhoneUnique")
	@ResponseBody
	public String checkPhoneUnique(User user) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(user)) {
			uniqueFlag = userService.checkPhoneUnique(user);
		}
		return uniqueFlag;
	}

	/**
	 * 校验email邮箱
	 */
	@PostMapping("/checkEmailUnique")
	@ResponseBody
	public String checkEmailUnique(User user) {
		String uniqueFlag = "0";
		if (StringUtils.isNotNull(user)) {
			uniqueFlag = userService.checkEmailUnique(user);
		}
		return uniqueFlag;
	}
	
	/**
	 * 获取核实用户
	 */
	@GetMapping("findUserByRold")
	public @ResponseBody List<User> findSon(@Param("pid") String pid) {
		String companyId = SpringSecurityUtils.getUser().getCompanyId().toString();
		List<User> list = userService.selectUserByRole("4", null, companyId);
		System.out.println("sysUser list : "+list.size());
		return list;
	}
	
	
	/**
	 * 获取电销顾问
	 */
	@GetMapping("findUsersByRoldName")
	public @ResponseBody List<User> findUsersByRoldName(@Param("roleName") String roleName) {
		String companyId = SpringSecurityUtils.getUser().getCompanyId().toString();
		List<User> list = userService.selectUserByRole(null, roleName, companyId);
		return list;
	}
}