package com.up.mls.controller.user;

import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.controller.AbstractController;
import com.up.mls.mapper.system.DictionaryMapper;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.util.DateUtils;
import com.up.mls.util.ServletUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.app.TongJiEntity;
import com.up.mls.vo.result.ReferrerResult;
import com.up.mls.vo.user.AppUser;
import com.up.mls.vo.user.AppUserReferrer;
import com.up.mls.vo.user.Fenpei;
import com.up.mls.vo.user.Follow;
import com.up.mls.web.domain.AjaxResult;
import com.up.mls.web.page.TableDataInfo;

import jodd.util.ObjectUtil;

/**
 * 客户Controller
 */
@Controller
@RequestMapping("/users")
public class AppUserController extends AbstractController {


    @Autowired
	private IAppUserService appUserService;
    @Autowired
    private DictionaryMapper dictionaryMapper;
    

    @GetMapping("index")
    public String index() {
        return "user/index";
    }


    @ResponseBody
    @RequestMapping("/list")
    public TableDataInfo list(AppUser appUser) {
        startPage();
        appUser.setType(1);
        List<AppUser> appUsers = appUserService.select(appUser);
        return getDataTable(appUsers);
    }
    
    /**
     * 下拉项
     * @param appUser
     * @return
     */
    @GetMapping("/findUserTree")
	@ResponseBody
	public List<AppUser> findUserTree(AppUser appUser) {
		return appUserService.findUserTree(appUser);
	}
    
    @GetMapping("/userListPage")
    public String listPage() {
        return "user/userList";
    }


    @ResponseBody
    @RequestMapping("/brokerList")
    public TableDataInfo brokerList(AppUser appUser) {
        startPage();
        appUser.setType(2);
        List<AppUser> appUsers = appUserService.select(appUser);
        return getDataTable(appUsers);
    }

    @GetMapping("/brokerListPage")
    public String brokerListPage() {
        return "user/brokerList";
    }


    @ResponseBody
    @RequestMapping("/companyList")
    public TableDataInfo companyList(HttpServletRequest request) {
        startPage();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        List<Map<String, Object>> companyListResult = appUserService.companyList(parameters);
        return getDataTable(companyListResult);
    }
    
    /**
	 * 公司列表-查看本月发展人数详情列表
	 * 1-月 2-总 3-被推荐人（月） 4-被推荐人（总）
	 * @param id
	 * @param mmap
	 * @return
	 */
	@GetMapping("detail/{id}/{type}")
	public String detail(@PathVariable("id")String id,@PathVariable("type")String type, ModelMap mmap) {
		AppUser member = appUserService.selectByPrimaryKey(id);
		mmap.put("member", member);
		//
		AppUser appUser=new AppUser();
		appUser.setSelect(SpringSecurityUtils.getUserId());
		appUser.setId(Long.valueOf(id));
		if("2".equals(type) ||"4".equals(type)){
			//总
		}else{
			//当月
			appUser.setType(1);
		}
		List<AppUser> userList = appUserService.findByMonth(appUser);
		mmap.put("userList", userList);
		if("3".equals(type) ||"4".equals(type)){
			//被推荐人弹框（总+月）
			return  "user/referrerNewList";
		}else{
			//普通弹框
			return  "user/detailMonth";
		}
	}
	
	
	
	
    @GetMapping("/companyListPage")
    public String companyListPage() {
        return "user/companyList";
    }


    /**
     * 推荐列表
     * @param appUserReferrer
     * @return
     */
    @ResponseBody
    @RequestMapping("/referrerList")
    public TableDataInfo referrerList(AppUserReferrer appUserReferrer) {
        startPage();
        List<ReferrerResult> companyListResult = appUserService.referrerList(appUserReferrer);
        return getDataTable(companyListResult);
    }
    @GetMapping("/referrerListPage")
    public String referrerListPage() {
        return "user/referrerList";
    }


    @GetMapping("isAppUser")
    public @ResponseBody
    Integer isAppUser(String phone) {
        AppUser au = appUserService.findByPhone(phone,null);
        return StringUtils.isNull(au) ? 0 : 1;
    }

    //=======================================用户跟进流程 start
    //跳转到列表页面
    @RequestMapping("toCxRlList/{userType}")
	public String entity(@PathVariable("userType")String userType,ModelMap mmap) {
		mmap.put("userType", userType);
		if (userType.equals("1")){
			//1个人-查询&认领
			return "appUser/personal/personalCxRlList";
		}else if(userType.equals("2")){
			//2经纪人-查询&认领
			return "appUser/agent/agentCxRlList";
		}else if(userType.equals("3")){
			//3公司-查询&认领
			return "appUser/company/companyCxRlList";
		}else{
			return "";
		}
	}
	
    /**
	 * 分页列表
	 * @param entity
	 * @return
	 */
	@RequestMapping("data/{userType}/{loginUserId}")
	@ResponseBody
	public TableDataInfo list(@PathVariable("userType")String userType,@PathVariable("loginUserId") String loginUserId,AppUser entity) {
		startPage();
		if( !loginUserId.equals("all")){
			//【我的用户my】
			if(entity.getFollowStatus()==null ){
				entity.setFollowStatus(1);//默认未回访
			}else if(entity.getFollowStatus()==-1){
				entity.setFollowStatus(null);//全部
			}
			entity.setRenlinUserId(Integer.valueOf(loginUserId));
		}else{
			//【用户查询&认领】
			if(StringUtils.isEmpty(entity.getRenlinType())){
				entity.setRenlinType("-11");//默认未认领
			}else if("-13".equals(entity.getRenlinType())){
				//全部的认领状态
				entity.setRenlinType(null);
			}
		}
		entity.setUserType(userType);
		if("2".equals(userType)){
			entity.setUserTypeAgent("2,4,5");//用户类型 : 2独立经纪人  4 公司下经纪人 5 独立经纪人下的经纪人
			entity.setUserType(null);
		}
		List<AppUser> list = this.appUserService.findList(entity);
		if(list !=null && list.size()>0){
			for(AppUser temp:list){
				List<Follow> chilList=this.appUserService.findFollowList(temp.getId()+"");
				temp.setRlCount(chilList==null?"0":chilList.size()+"");
				List<Fenpei> fpList=this.appUserService.findFenpeiList(temp.getId()+"");
				temp.setFpCount(fpList==null?"0":fpList.size()+"");
			}
		}
		return getDataTable(list);
	}
	
    
	/**
	 * 跳转到跟进页面
	 * @param mmap
	 * @return
	 */
	@RequestMapping("toMy/{userType}")
	public String toMy(@PathVariable("userType")String userType,ModelMap mmap) {
		mmap.put("loginUserId",SpringSecurityUtils.getUserId());
		mmap.put("currUserName",SpringSecurityUtils.getUser().getUserName());
		if (userType.equals("1")){
			//1个人-回访 
			return "appUser/personal/personalMy";
		}else if(userType.equals("2")){
			//2经纪人-跟进
			return "appUser/agent/agentMy";
		}else if(userType.equals("3")){
			//3公司-跟进
			return "appUser/company/companyMy";
		}else{
			return "";
		}
	}

	//查看-跳转
	@RequestMapping("/toShow/{ifEdit}/{id}")
	public String toShow(@PathVariable("ifEdit") String ifEdit,@PathVariable("id") String id,ModelMap mmap) {
		mmap.put("followList",this.appUserService.findFollowList(id+""));
		AppUser  entity=this.appUserService.selectByPrimaryKey(id);
		String userType=entity.getUserType();
		mmap.put("ifEdit", ifEdit);
		if (userType.equals("1")){
			//1个人-回访 
			return "appUser/personal/detailShow";
		}else if(userType.equals("2")){
			//统计数量
			TongJiEntity sumEntity=this.appUserService.sumPublishFangYuanCount(id);
			mmap.put("sumEntity",sumEntity);
			//分配记录集合
			mmap.put("fenpeiList",this.appUserService.findFenpeiList(id+""));
			//标题
			String createTime=DateUtils.getStringDate(entity.getCreateTime());
			String updateTime=DateUtils.getStringDate(entity.getUpdateTime());
			String title="来自北京的经纪人 "+entity.getAccountName()+"- "+entity.getAccount()+"于"+createTime+" 从"+entity.getPlat()+"注册，累计登陆"+entity.getLoginCount()+"次，最后于"+updateTime+"登陆 "+this.getSignName(entity.getSignStatusName()) +"";
			mmap.put("title", title);
			//2经纪人-跟进
			if("yes".equals(ifEdit)){
				//可以编辑-到跟进follow
				return "appUser/agent/detailFollow";
			}else{
				//不可编辑-只是查看分配记录
				return "appUser/agent/detailFenpei";
			}
		}else if(userType.equals("3")){
			//统计数量
			TongJiEntity sumEntity=this.appUserService.sumPublishFangYuanCount(id);
			mmap.put("sumEntity",sumEntity);
			//分配记录集合
			mmap.put("fenpeiList",this.appUserService.findFenpeiList(id+""));
			String accountName=entity.getAccountName();
			if(StringUtils.isEmpty(accountName)){
				accountName="暂无";
			}
			String companyName=entity.getCorporateName();
			if(StringUtils.isEmpty(companyName)){
				companyName="暂无";
			}
			//标题
			String title=""+companyName+"（负责人"+accountName+""+entity.getAccount()+"）  "+DateUtils.getStringDate(entity.getCreateTime())+"注册，"+this.getSignName(entity.getSignStatusName());
			mmap.put("title", title);
			//3公司-跟进
			if("yes".equals(ifEdit)){
				//可以编辑-到跟进follow
				return "appUser/company/detailFollow";
			}else{
				//不可编辑-只是查看分配记录
				return "appUser/company/detailFenpei";
			}
		}else{
			return "";
		}
	}

	//获取电子签文本描述
	public String getSignName(String signStatus){
		List<String> signList = Arrays.asList("未签署","未签署","已签署","签署失败","拒签");
		return signList.get(signStatus==null?0:Integer.valueOf(signStatus));
	}

	/**
	 * 单条认领提交
	 * @param mmap
	 * @return
	 */
	@PostMapping("saveRenlin")
	@ResponseBody
	public AjaxResult saveRenlin(AppUser entity) {
		entity.setRenlinUserId(Integer.valueOf(SpringSecurityUtils.getUserId().toString()));
		entity.setRenlinUserName(SpringSecurityUtils.getUser().getUserName());
		entity.setRenlinTime(new Date());
		return toAjax(appUserService.saveRenlin(entity));
	}
	/**
	 * 批量认领提交
	 * @param mmap
	 * @return
	 */
	@GetMapping("saveRenlinBatch")
	@ResponseBody
	public Map<String,Object> saveRenlinBatch(Long[] ids) {
			Map<String,Object> map = new HashMap<String,Object>();
			map.put("ids", ids);
			map.put("renlinUserId", Integer.valueOf(SpringSecurityUtils.getUserId().toString()));
			map.put("renlinUserName", SpringSecurityUtils.getUser().getUserName());
			map.put("renlinTime", new Date());
			appUserService.saveRenlinBatch(map);
			map.put("count", ids.length);
		return map;
	}
	
	/**
	 * 释放提交
	 * @param mmap
	 * @return
	 */
	@PostMapping("saveFree")
	@ResponseBody
	public AjaxResult saveFree(AppUser entity) {
		entity.setRenlinUserId(-1);
		return toAjax(appUserService.saveRenlin(entity));
	}
	
	/**
	 * 批量释放
	 * @param mmap
	 * @return
	 */
	@GetMapping("saveFreeBatch")
	@ResponseBody
	public Map<String,Object> saveFreeBatch(Long[] ids) {
			Map<String,Object> map = new HashMap<String,Object>();
			map.put("ids", ids);
			map.put("renlinUserId", "-1");//-1表示释放
			appUserService.saveRenlinBatch(map);
			map.put("count", ids.length);
		return map;
	}
	
	
	/**
	 * 保存回访
	 * @param shp
	 * @return
	 */
	@PostMapping("saveHuiFang")
	@ResponseBody
	public AjaxResult saveHuiFang(AppUser appUser) {
		int resInt=0;
		try {
			String loginUserId=SpringSecurityUtils.getUserId().toString();
			String loginUserName=SpringSecurityUtils.getUser().getUserName();
			String followRemark=appUser.getFollowRemark();
			//
			appUser=this.appUserService.selectByPrimaryKey(appUser.getId()+"");
			appUser.setFollowUserId(Integer.valueOf(loginUserId));
			appUser.setFollowUserName(loginUserName);
			appUser.setFollowTime(new Date());
			appUser.setFollowRemark(followRemark);
			appUser.setFollowStatus(2);
			//1）更新主表
			appUserService.updateHuiFang(appUser);
			//添加日志
			Follow follow=new Follow();
			follow.setFollowUserId(Integer.valueOf(loginUserId));
			follow.setFollowUserName(loginUserName);
			follow.setRid(appUser.getId()+"");
			follow.setUserType(appUser.getUserType());
			follow.setRemark(appUser.getFollowRemark());
			resInt=this.appUserService.saveFollow(follow);
		} catch (Exception e) {
			e.printStackTrace();
			return toAjax(0);
		}
		return toAjax(resInt);
	}
	
	
	/**
	 * 分配经济人
	 */
	@GetMapping("toDistribution")
	public String toDistribution(String ids, Model model) {
		//获取 经纪人列表
		List<AppUser> list = appUserService.selectAppUserForAgent(2); // selectUserByRole(null, "经纪人", companyId);
		model.addAttribute("sysAccounts", list);
		model.addAttribute("ids", ids);
		return "appUser/agent/agentOptions";
	}
	
	
	/**
	 * 保存分配经济人
	 * @param agentId  下拉框选中的某一个被分配人
	 * @param ids      批量选中的多条checkbox记录
	 * @param model
	 * @return
	 */
	@PostMapping("saveDistribution/{userType}")
	public @ResponseBody Integer saveDistribution(@PathVariable("userType")String userType,String beiUserId,String ids, Model model) {
		return this.appUserService.saveDistribution(beiUserId, ids, getUser(),userType);
	}
	
    //=======================================用户跟进流程 end
    
    
}
