/**
 * 
 */
package com.up.mls.interceptor;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.aop.support.AopUtils;
import org.springframework.core.Ordered;
import org.springframework.stereotype.Component;

import com.up.mls.util.ConfigurationUtils;
import com.up.mls.util.Constant;

/**
 * @author mingguangz
 *
 */
@Component
@Aspect
public class BeanPerformanceMonitor {
	private static final Logger logger = LoggerFactory.getLogger(BeanPerformanceMonitor.class);
	
	private static final ThreadLocal<Long> threadLocal = new ThreadLocal<Long>();

	@Pointcut("execution (* com.up.mls.mapper..*.*(..))")
	private void anyDaoMethod() {}//声明一个切入点
	
	@Pointcut("execution (* com.up.mls.service..*.*(..))")
	private void anyServiceMethod() {}//声明一个切入点
	
	/**
	 * 性能检测
	 * @param pjp
	 * @return
	 * @throws Throwable
	 */
	@Around("anyServiceMethod() || anyDaoMethod()")//环绕通知
	public Object doAround(ProceedingJoinPoint pjp) throws Throwable {
		threadLocal.set(System.currentTimeMillis());
		Object result = pjp.proceed();//执行目标方法
		long total = System.currentTimeMillis() - threadLocal.get();
//		if (!AopUtils.isAopProxy(pjp.getTarget())) {  
//			System.out.println("不是代理类");
//	    }  
//	  
//	    if (AopUtils.isJdkDynamicProxy(pjp.getTarget())) {  
//	    	System.out.println("jdk是代理类");
//	    } else { //cglib  
//	    	System.out.println("cglib代理类");
//	    }  
		if(total>ConfigurationUtils.getIntValue(Constant.METHOD_TIME)) {
			StringBuffer methodName = new StringBuffer();
			methodName.append(pjp.getTarget().getClass().getName());//目标类名称
			methodName.append(".");
			methodName.append(pjp.getSignature().getName());//方法名称
			StringBuffer logStr = new StringBuffer("access method:").append(methodName).append("	running time (millis) = ").append(total);
			logger.debug(logStr.toString());
		}
		return result;
	}

}
