/**
 * 
 */
package com.up.mls.interceptor;

import java.lang.reflect.InvocationTargetException;
import java.math.BigDecimal;
import java.sql.Statement;
import java.text.DateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;

import org.apache.ibatis.executor.statement.RoutingStatementHandler;
import org.apache.ibatis.executor.statement.StatementHandler;
import org.apache.ibatis.mapping.BoundSql;
import org.apache.ibatis.mapping.ParameterMapping;
import org.apache.ibatis.plugin.Interceptor;
import org.apache.ibatis.plugin.Intercepts;
import org.apache.ibatis.plugin.Invocation;
import org.apache.ibatis.plugin.Plugin;
import org.apache.ibatis.plugin.Signature;
import org.apache.ibatis.session.ResultHandler;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

/**
 * @author mingguangz
 * 
 */
@Intercepts({
		@Signature(type = StatementHandler.class, method = "query", args = { Statement.class, ResultHandler.class }),
		@Signature(type = StatementHandler.class, method = "update", args = { Statement.class }),
		@Signature(type = StatementHandler.class, method = "batch", args = { Statement.class }) })
@Component
public class MybatisSQLInterceptor implements Interceptor {
	private static final Logger logger = LoggerFactory.getLogger(MybatisSQLInterceptor.class);

	@Override
	public Object intercept(Invocation invocation) throws InvocationTargetException, IllegalAccessException {
		// 开始时间
		int i=0;
		long start = System.currentTimeMillis();
		try {
			return invocation.proceed();
		} finally {
			try {
				long end = System.currentTimeMillis();
				long time = end - start;
				RoutingStatementHandler statementHandler = (RoutingStatementHandler) invocation.getTarget();
				BoundSql boundSql = statementHandler.getBoundSql();
				logger.info(this.getSql(boundSql, time));
			} catch (Exception e) {
				logger.error(e.getMessage(), e);
			}
		}
	}

	@Override
	public Object plugin(Object arg0) {
		return Plugin.wrap(arg0, this);
	}

	@Override
	public void setProperties(Properties arg0) {
		// TODO Auto-generated method stub

	}

	private String getSql(BoundSql boundSql, long time) {
		String sql = showSql(boundSql);
		StringBuilder str = new StringBuilder();
		str.append("	");
		str.append(sql);
		str.append("	running time (millis) = ");
		str.append(time);
		return str.toString();
	}

	private String getParameterValue(Object obj) {
		String value = null;
		if (obj instanceof String) {
			value = "'" + obj.toString() + "'";
		} else if (obj instanceof Date) {
			DateFormat formatter = DateFormat.getDateTimeInstance(DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.CHINA);
			value = "'" + formatter.format(obj) + "'";
		} else {
			if (obj != null) {
				value = obj.toString();
			} else {
				value = "";
			}

		}
		return value;
	}

	private String showSql(BoundSql boundSql) {
		Object parameterObject = boundSql.getParameterObject();
		List<ParameterMapping> parameterMappings = boundSql.getParameterMappings();
		String sql = boundSql.getSql().replaceAll("[\\s]+", " ");
		for (ParameterMapping parameterMapping : parameterMappings) {
			String propertyName = parameterMapping.getProperty();
			if (parameterObject instanceof Map) {
				Map parameterMap = (Map) parameterObject;
				sql = sql.replaceFirst("\\?", this.getParameterValue(parameterMap.get(propertyName)));
			} else if (parameterObject instanceof String
						|| parameterObject instanceof Integer
						|| parameterObject instanceof Long
						|| parameterObject instanceof BigDecimal
						|| parameterObject instanceof Double
						|| parameterObject instanceof Character
						|| parameterObject instanceof Float
						|| parameterObject instanceof Date
						|| parameterObject instanceof java.sql.Date) {
				sql = sql.replaceFirst("\\?", getParameterValue(parameterObject));
			} 
		}
		return sql;
	}

}
