package com.up.mls.service.content.impl;

import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;

import com.up.mls.mapper.content.BrandContactsErrorAreaMapper;
import com.up.mls.mapper.content.BrandContactsErrorMapper;
import com.up.mls.mapper.system.AreasMapper;
import com.up.mls.service.content.BrandContactsErrorService;
import com.up.mls.service.content.IBrandLinkmanService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.content.BrandContactsError;
import com.up.mls.vo.content.BrandContactsErrorArea;
import com.up.mls.vo.content.BrandLinkman;
import com.up.mls.vo.system.Areas;



@Service
public class BrandContactsErrorServiceImpl implements BrandContactsErrorService{
	
	private static final Logger logger = LoggerFactory.getLogger(BrandContactsErrorServiceImpl.class);
	
	@Autowired
	private BrandContactsErrorMapper brandContactsErrorMapper;
	@Autowired
	private IBrandLinkmanService iBrandLinkmanService;
//	@Autowired
//	private BrandContactsMapper brandContactsMapper;
//	@Autowired
//	private BrandContactsAreaMapper brandContactsAreaMapper;
	@Autowired
	private BrandContactsErrorAreaMapper brandContactsErrorAreaMapper;
	@Autowired
	private AreasMapper areasMapper;
	
	
	@Override
	public List<BrandContactsError> selectbrandContactsErrorList(BrandContactsError brandContactsError) {
		brandContactsError.setUser(SpringSecurityUtils.getUser());
		return brandContactsErrorMapper.selectBrandContactsError(brandContactsError);
	}

	@Override
	public BrandContactsError selectbrandContactsErrorById(Long id) {
		BrandContactsError brandContactsError = brandContactsErrorMapper.selectByPrimaryKey(id);
		brandContactsError.setId(id);
		//纠错后区域获取
		BrandContactsErrorArea bcea = new BrandContactsErrorArea();
		bcea.setBrandContactsErrorId(id);
		List<BrandContactsErrorArea> bceaList = brandContactsErrorAreaMapper.selectBrandContactsErrorArea(bcea);
		StringBuilder areas = new StringBuilder();
		for(BrandContactsErrorArea bca1:bceaList) {
			Areas area = areasMapper.selectByPrimaryKey(String.valueOf(bca1.getProvinceId()));
			areas.append(area.getAreaName());
			areas.append(",");
		}
		if(areas.length() >= 1) {
			String areasStr = areas.substring(0,areas.length() - 1);
			brandContactsError.setAreaids(areasStr);
		}else {
			brandContactsError.setAreaids(String.valueOf(areas));
		}
		//纠错前区域获取
		return brandContactsError;
	}

	@Override
	public int updateBrandError(BrandContactsError brandContactsError) {
		//brandContactsError.setApproveUser(String.valueOf(SpringSecurityUtils.getUserId()));	//审批人
		brandContactsError.setApproveTime(new Date());										//审批时间
		if(brandContactsError.getFlag() == 2) {
			//审核通过 同步更新联系人
			updateBrandContacts(brandContactsError);
		}
		return brandContactsErrorMapper.update(brandContactsError);
	}
	
	/**
	 * 审核通过 同步更新品牌联系人信息
	 * 
	 * @param brandContactsError
	 */
	public void updateBrandContacts(BrandContactsError brandContactsError){
		BrandLinkman brandLinkman = iBrandLinkmanService.selectById(brandContactsError.getBrandContactsId().toString());
		brandLinkman.setName(brandContactsError.getUserName());
		brandLinkman.setPhone(brandContactsError.getMobile());
		brandLinkman.setDuty(brandContactsError.getPost());
		iBrandLinkmanService.update(brandLinkman);		
	}
	
	/**
     * 品牌联系人纠错service异常报错捕获
     * @param request
     * @param exception
     * @return 错误所在的类、方法、行号
     * @throws Exception
     */
    @ExceptionHandler(value=Exception.class)  
    public void exceptionHandler(HttpServletRequest request,  Exception exception, Model model){  
       StackTraceElement[] errorStr = exception.getStackTrace();
        StringBuffer sb = new StringBuffer();  
        sb.append(exception.toString());
        sb.append("<br/>");
        for(int i=0;i<errorStr.length;i++) {
        		String errorInfo = errorStr[i].toString();
        		if(errorInfo.contains("com.up.sell.controller")) {
        			sb.append(errorInfo);
        			sb.append("<br/>");
        		}
        }
        exception.printStackTrace();
        logger.info("品牌联系人纠错service出错：{}",sb);
        model.addAttribute("sb", sb);
    }
	
	
	
	
	
	@Override
	public int insertBrandError(BrandContactsError brandContactsError) {
		// TODO Auto-generated method stub
		return brandContactsErrorMapper.insert(brandContactsError);
	}

	@Override
	public int deletebrandContactsErrorById(Long id) {
		// TODO Auto-generated method stub
		return 0;
	}

	@Override
	public int deletebrandContactsErrorByIds(String ids) {
		// TODO Auto-generated method stub
		return 0;
	}



	


}
