package com.up.mls.service.content.impl;

import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.up.mls.mapper.content.BrandAreaMapper;
import com.up.mls.mapper.content.BrandBrandAreaMapper;
import com.up.mls.mapper.content.BrandMapper;
import com.up.mls.service.content.IBrandBrandAreaService;
import com.up.mls.service.content.IBrandService;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.support.Convert;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.content.Brand;
import com.up.mls.vo.content.BrandArea;
import com.up.mls.vo.system.Company;
import com.up.mls.vo.system.User;

@Service
public class BrandServiceImpl implements IBrandService {

    @Autowired
    private BrandMapper brandMapper;

    @Autowired
    private IBrandBrandAreaService iBrandBrandAreaService;
    @Autowired
    private BrandAreaMapper bAreaMapper;

	@Autowired
	private ICompanyService iCompanyService;
	
    private static final String advFlag = "0";

    @Override
    public List<Brand> selectList(Brand brand) {
    	brand.setCreateBy(SpringSecurityUtils.getUserId());
        List<Brand> bran = brandMapper.selectList(brand);
        bran.forEach(a -> {
        		if(StringUtils.isNotBlank(a.getAreaLower()) && StringUtils.isNotBlank(a.getAreaUpper())) {
        			a.setAreaLower(a.getAreaLower() + "-" + a.getAreaUpper() + "㎡");
            }
        		if(StringUtils.isNoneBlank(a.getCooperationLower()) && StringUtils.isNotBlank(a.getCooperationUpper())) {
        			a.setCooperationLower(a.getCooperationLower() + "-" + a.getCooperationUpper() + "年");
            }
        });
        return bran;
    }


    @Override
    @Transactional
    public int save(Brand brand) {
		User user = SpringSecurityUtils.getUser();
		Company company = iCompanyService.selectCompanyById(user.getCompanyId());
        if (null == brand.getId()) {
        	brand.setCreateBy(user.getUserId());
        	brand.setProvinceId(company.getProvinceId());
        	brand.setCityId(company.getCityId());
            Integer is = brandMapper.save(brand);
            return iBrandBrandAreaService.save(brand.getId(), brand.getAreaId());
        }
        if(null != brand.getAdvFlag()) {
        	brand.setUpdateBy(user.getUserId());
        	return brandMapper.update(brand);
        }
        iBrandBrandAreaService.remove(brand.getId());
        brandMapper.update(brand);
        return iBrandBrandAreaService.save(brand.getId(), brand.getAreaId());
    }

    @Override
    public Brand selectById(String id) {
    		Brand brand = brandMapper.selectById(id);
    		List<String> list = iBrandBrandAreaService.selectId(brand.getId());
    		StringBuilder strb = new StringBuilder();
    		for(String s:list) {
    			BrandArea bAreas = bAreaMapper.selectByPrimaryKey(Long.valueOf(s));
    			strb.append(bAreas.getName());
    			strb.append(",");
    		}
    		if(strb.length() > 1) {
    			brand.setExpandArea(strb.substring(0,strb.length()-1));
    		}else {
    			brand.setExpandArea(strb.toString());
    		}
        return brand;
    }

    @Override
    public int remove(String ids) throws Exception {
        String[] id = ids.split(",");
        for (int i = 0; i < id.length; i++) {
            String status = brandMapper.selectAdvFlag(id[i]);
            if (status.equals(advFlag)) {
                throw new Exception("上架数据不可删除");
            }
        }
        return brandMapper.remove(Convert.toIntArray(",", ids));
    }
    
    @Override
    public int selectOnOfflineCount(Brand brand) {
    		return brandMapper.selectOnOfflineCount(brand);
    }


	@Override
	public int updateForAuditStatus(Brand brand,Long auditAccount) {
		brand.setAuditAccount(auditAccount);
		return brandMapper.updateForAuditStatus(brand);
	}

}
