package com.up.mls.service.content.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.up.mls.mapper.content.BannerMapper;
import com.up.mls.mapper.system.AreasMapper;
import com.up.mls.redis.RedisBaseDao;
import com.up.mls.service.content.ISlideShowService;
import com.up.mls.support.Convert;
import com.up.mls.util.Constant;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.util.StringUtils;
import com.up.mls.vo.content.Banner;

/**
 * @author liuwei
 * 轮播图管理service
 */
@Service
public class SlideShowServiceImpl implements ISlideShowService {

	//private static final Logger logger = LoggerFactory.getLogger(SlideShowServiceImpl.class);
    @Autowired
    private BannerMapper bannerMapper;
    //@Autowired
    //private ICompanyService iCompanyService;
    @Autowired
    private RedisBaseDao redisBaseDao;
    @Autowired
    private AreasMapper areasMapper;
    @Autowired
    private ISlideShowService iSlideShowService;
    

    @Override
    public List<Banner> findBannerList(Banner banner) {
        List<Banner> list = bannerMapper.findBannerList(banner);
        for (Banner s : list) {
        	if(s.getType() == 1){
        		//app
        		s.setJumpContent(s.getAppUrl());
                s.setPic(s.getAppPic());
                //s.setUrl(s.getAppUrl());
        	}else{
        		 // pc
        		s.setJumpContent(s.getPcUrl());
                s.setPic(s.getPcPic());
                //s.setUrl(s.getPcUrl());
        	}
        }
        return list;
    }

    
    /**
     * 新增banner图片
     */
    @Override
    public int insertBanner(Banner banner) {
    	try {
    		int resInt;
    		banner.setCreateBy(SpringSecurityUtils.getUser().getUserId());
    		if(banner.getAdress().equals(1)){
    			//pc
    			banner.setPcPic(banner.getPic());
    			banner.setPcUrl(banner.getUrl());
    			banner.setType(0);
    		}else if(banner.getAdress().equals(2)){
    			//app
    			banner.setAppPic(banner.getPic());
    			banner.setAppUrl(banner.getUrl());
    			banner.setType(1);
    		}
    		resInt=bannerMapper.insertBanner(banner);
    		//循环清空缓存
    		if(StringUtils.isNotEmpty(banner.getCityId())){
    			for(String cityId:banner.getCityId().split(",")){
    				this.iSlideShowService.resetRedis(cityId, null);
    			}
    		}
    		return resInt;
    	} catch (Exception e) {
    		e.printStackTrace();
    		return 0;
    	}
    }
    
    
    //修改banner图
    @Override
    public int updateBanner(Banner banner) {
    	String oldCitys=this.bannerMapper.findEntityById(banner.getId()+"").getCityId();
    	int resInt;
    	if(banner.getAdress().equals(1)){
    		//pc
    		banner.setPcPic(banner.getPic());
    		banner.setPcUrl(banner.getUrl());
    		banner.setType(0);
    	}else if(banner.getAdress().equals(2)){
    		//app
    		banner.setAppPic(banner.getPic());
    		banner.setAppUrl(banner.getUrl());
    		banner.setType(1);
    	}
    	banner.setUpdateBy(SpringSecurityUtils.getUser().getUserId());
    	resInt=bannerMapper.updateBanner(banner);
    	//循环清空缓存
    	//old
    	if(StringUtils.isNotEmpty(oldCitys)){
			for(String cityId:oldCitys.split(",")){
				this.iSlideShowService.resetRedis(cityId, null);
			}
		}
    	//new
    	String newCitys=banner.getCityId();
		if(StringUtils.isNotEmpty(newCitys)){
			for(String cityId:newCitys.split(",")){
				this.iSlideShowService.resetRedis(cityId, null);
			}
		}
    	return resInt;
    }

    @Override
    public Banner selectById(String id) {
        return bannerMapper.findEntityById(id);
    }

    
   
	
	
    @Override
    public int resetRedis(String cityId,String userType){
    	if(StringUtils.isEmpty(cityId)){
    		cityId="110100";//默认北京
    	}
    	this.redisBaseDao.del(Constant.SHOW_INFO_PC +cityId+Constant.JOIN+"1");
    	this.redisBaseDao.del(Constant.SHOW_INFO_PC +cityId+Constant.JOIN+"2");
    	this.redisBaseDao.del(Constant.SHOW_INFO_APP +cityId+Constant.JOIN+"1");
    	this.redisBaseDao.del(Constant.SHOW_INFO_APP +cityId+Constant.JOIN+"2");
    	return 1;
    }
    
    @Override
	public int remove(String ids) throws Exception {
    	Banner entity= this.bannerMapper.findEntityById(ids);
    	 int resInt= bannerMapper.remove(Convert.toIntArray(",", ids));
		//循环清空缓存
 		if( entity !=null && StringUtils.isNotEmpty(entity.getCityId())){
 			for(String cityId:entity.getCityId().split(",")){
 				this.iSlideShowService.resetRedis(cityId, null);
 			}
 		}
 		return resInt;
	}

}
