package com.up.mls.service.exception;

import java.util.Objects;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.DataAccessException;
import org.springframework.dao.InvalidDataAccessApiUsageException;
import org.springframework.data.redis.RedisConnectionFailureException;
import org.springframework.data.redis.RedisSystemException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

import com.up.mls.common.Result;
import com.up.mls.common.ResultCode;
import com.up.mls.util.RequesUtil;


/**
 * 全局异常捕获
 * 
 * @author z.z.l
 *
 */
@ControllerAdvice
@ResponseBody
public class GlobalExceptionHandler {

	private static final Logger LOG = LoggerFactory.getLogger(GlobalExceptionHandler.class);
//	@Autowired
//	EmailService emailService;

	/**
	 * 所有的Exception处理
	 * 
	 * @param exception
	 * @return
	 * @throws Exception
	 */
	@ExceptionHandler(value = Exception.class)
	public String allExceptionHandler(Exception exception, HttpServletRequest request) throws Exception {
		LOG.error("全局异常处理-{}", exception.getMessage(), exception);
		LOG.error(RequesUtil.getRequstMethodAndUrlAndParam(request),exception);
//		emailService.sendErrorEmail("【异常】"+RequesUtil.getRequstMethodAndUrlAndParam(request),exception);
//		return Result.failure(ResultCode.ERROR);
		String tip = RequesUtil.getRequstMethodAndUrlAndParam(request);
		String exceptionHtml = getExceptonHtml(exception,tip);
        return exceptionHtml;
	}

	@ExceptionHandler(value = DataAccessException.class)
	public Result dataAccessExceptionHandler(DataAccessException exception)
			throws Exception {
		String errorTitle = null;
		String errorMsg = exception.getMessage();
		if (exception instanceof RedisSystemException) {
			errorTitle = String.format("redis系统异常处理-%s", errorMsg);
		} else if (exception instanceof RedisConnectionFailureException) {
			errorTitle = String.format("redis连接异常处理-%s", errorMsg);
		} else if (exception instanceof InvalidDataAccessApiUsageException) {
			errorTitle = String.format("不正确使用API时抛出的异常异常处理-%s", errorMsg);
		} else {
			errorTitle = exception.getLocalizedMessage();
		}
		LOG.error(errorTitle, exception);
//		emailService.sendErrorEmail(exception);
		return Result.failure(ResultCode.ERROR);
	}

	/**
	 * @param exception
	 * @return
	 */
	@ExceptionHandler(value = BusinessException.class)
	public Result businessException(BusinessException exception,HttpServletRequest request) throws Exception {
		LOG.error("优铺业务异常处理-{}", exception.getMessage(), exception);
//		emailService.sendErrorEmail(exception);
		if (Objects.isNull(exception.getResult())) {
			return Result.failure(ResultCode.ERROR);
		} else {
			return exception.getResult();
		}

	}
	
	
	public String getExceptonHtml(Exception exception,String tip) {
		StackTraceElement[] errorStr = exception.getStackTrace();
		StringBuffer sb = new StringBuffer();
		sb.append("<div class=\"middle-box text-center animated fadeInDown\">");
        sb.append("<center> <font size='30' color='red'>500</font></center>");
        sb.append("<center><font size='2'>服务器内部出错了，您可以返回首页</font></center>");
        sb.append("</div>");
        
        sb.append("<div style='display:none'>");
        sb.append(exception.toString());
        sb.append("<br/>");
        for(int i=0;i<errorStr.length;i++) {
        		String errorInfo = errorStr[i].toString();
        		if(errorInfo.contains("com.up.mls.controller")) {
        			sb.append(errorInfo);
        			sb.append("<br/>");
        		}
        }
        sb.append("<br/>");
        sb.append(tip);
        sb.append("</div>");
		return sb.toString();
	}

}
