package com.up.mls.service.monitor.impl;

import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.up.mls.common.constant.SystemConstants;
import com.up.mls.mapper.monitor.LogininforMapper;
import com.up.mls.service.monitor.ILogininforService;
import com.up.mls.support.Convert;
import com.up.mls.util.AddressUtils;
import com.up.mls.util.ServletUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.monitor.LoginLogInfo;

import eu.bitwalker.useragentutils.UserAgent;

/**
 * 系统访问日志情况信息 服务层处理
 * 
 * @author j.x.j
 */
@Service
public class LogininforServiceImpl implements ILogininforService
{

    @Autowired
    private LogininforMapper logininforMapper;

    /**
     * 新增系统登录日志
     * 
     * @param logininfor 访问日志对象
     */
    @Override
    public void insertLogininfor(LoginLogInfo log)
    {
    	HttpServletRequest request=ServletUtils.getRequest();
		UserAgent userAgent = UserAgent.parseUserAgentString(request.getHeader("User-Agent"));
		//获取操作系统
		String os = userAgent.getOperatingSystem().getName();
		// 获取客户端浏览器
		String browser = userAgent.getBrowser().getName();
		log.setIpaddr(ServletUtils.getIpAddress(request));
		log.setOs(os);
		log.setBrowser(browser);
//		log.setLoginLocation(AddressUtils.getRealAddressByIP(log.getIpaddr()));
        logininforMapper.insertLogininfor(log);
    }

    /**
     * 查询系统登录日志集合
     * 
     * @param logininfor 访问日志对象
     * @return 登录记录集合
     */
    @Override
    public List<LoginLogInfo> selectLogininforList(LoginLogInfo logininfor)
    {
        return logininforMapper.selectLogininforList(logininfor);
    }

    /**
     * 批量删除系统登录日志
     * 
     * @param ids 需要删除的数据
     * @return
     */
    @Override
    public int deleteLogininforByIds(String ids)
    {
        return logininforMapper.deleteLogininforByIds(Convert.toStrArray(ids));
    }

	@Override
	public void insertLogininfor() {
		HttpServletRequest request=ServletUtils.getRequest();
		LoginLogInfo log = new LoginLogInfo();
		log.setLoginName(SpringSecurityUtils.getLoginName());
		log.setLoginTime(new Date());
		log.setIpaddr(ServletUtils.getIpAddress(request));
		UserAgent userAgent = UserAgent.parseUserAgentString(request.getHeader("User-Agent"));
		String os = userAgent.getOperatingSystem().getName();
		// 获取客户端浏览器
		String browser = userAgent.getBrowser().getName();
		log.setStatus(SystemConstants.SUCCESS);
		log.setMsg("登录成功");
		log.setOs(os);
		log.setBrowser(browser);
//		log.setLoginLocation(AddressUtils.getRealAddressByIP(log.getIpaddr()));
		logininforMapper.insertLogininfor(log);
	}
}
