package com.up.mls.service.news.impl;

import com.up.mls.mapper.news.NewsMapper;
import com.up.mls.service.news.NewsService;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.umeng.UmengUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.news.News;
import org.apache.commons.lang3.StringUtils;
import org.jsoup.Jsoup;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;


@Service
public class NewsServiceImpl implements NewsService {

    @Autowired
    private NewsMapper newsMapper;
    @Autowired
    private ICompanyService companyService;

    UmengUtils umengUtils = new UmengUtils();

    @Override
    public int save(News news) throws Exception {
        news.setPushId(SpringSecurityUtils.getUserId());
        String createName = SpringSecurityUtils.getUser().getUserName();
        news.setCreateTime(new Date());
        news.setStatus(1);
        news.setMsgType("2");
        newsMapper.save(news);

        Map<String, Object> map = new HashMap<>();

        //  ----------判断接收用户类型----------
        //全部
        if (news.getChannel().equals("1,2,3")) {
            map.put("channel", 1);
        }

        //ios 安卓
        if (news.getChannel().equals("1,2")) {
            map.put("channel", 2);
        }

        //ios 支撑端
        if (news.getChannel().equals("1,3")) {
            map.put("channel", 3);
        }

        //ios
        if (news.getChannel().equals("1")) {
            map.put("channel", 4);
        }

        //安卓
        if (news.getChannel().equals("2")) {
            map.put("channel", 5);
        }

        //支撑端
        if (news.getChannel().equals("3")) {
            map.put("channel", 6);
        }

        //安卓 支撑端
        if (news.getChannel().equals("2,3")) {
            map.put("channel", 7);
        }

        //根据channel 查询出指定用户
        String channel = map.get("channel") + "";
        List<Map<String, Object>> mapList = newsMapper.selectAppUser(channel);

        //  ----------判断接收用户类型----------
        // 独立经纪人 经纪公公司及其团队 普通用户
        if (news.getPushType().equals("1,2,3")) {
            map.put("pushType", 1);
        }

        // 独立经纪人 经纪公公司及其团队
        if (news.getPushType().equals("1,2")) {
            map.put("pushType", 2);
            mapList = mapList.stream()
                    .filter(a -> a.get("user_type").equals("2") || a.get("user_type").equals("3"))
                    .collect(Collectors.toList());
        }

        //独立经纪人 普通用户
        if (news.getPushType().equals("1,3")) {
            map.put("pushType", 3);
            mapList = mapList.stream()
                    .filter(a -> a.get("user_type").equals("1") || a.get("user_type").equals("2"))
                    .collect(Collectors.toList());
        }

        //经纪公公司及其团队 普通用户
        if (news.getPushType().equals("2,3")) {
            map.put("pushType", 4);
            mapList = mapList.stream()
                    .filter(a -> a.get("user_type").equals("3") || a.get("user_type").equals("1"))
                    .collect(Collectors.toList());
        }

        //独立经纪人
        if (news.getPushType().equals("1")) {
            map.put("pushType", 5);
            mapList = mapList.stream()
                    .filter(a -> a.get("user_type").equals("2"))
                    .collect(Collectors.toList());
        }

        //经纪公公司及其团队
        if (news.getPushType().equals("2")) {
            map.put("pushType", 6);
            mapList = mapList.stream()
                    .filter(a -> a.get("user_type").equals("3"))
                    .collect(Collectors.toList());
        }

        //普通用户
        if (news.getPushType().equals("3")) {
            map.put("pushType", 7);
            mapList = mapList.stream()
                    .filter(a -> a.get("user_type").equals("1"))
                    .collect(Collectors.toList());
        }

        //组合List Map 如果只发送支撑端消息的话，此处为空
        if (mapList.size() > 0) {
            List<Map<String, Object>> newsUser = new ArrayList<>();
            for (int i = 0; i < mapList.size(); i++) {
                Map<String, Object> maps = new HashMap<>();
                maps.put("title", news.getTitle());
                maps.put("content", news.getContent());
                maps.put("types", "1");
                maps.put("create_name", createName);
                maps.put("if_see", "1");
                maps.put("status", 2);
                maps.put("create_time", new Date());
                maps.put("user_id", mapList.get(i).get("id"));
                newsUser.add(maps);
            }
            int i = newsMapper.installList(newsUser);
        }

        //此处处理支撑端数据
        if (news.getChannel().contains("3")) {
            List<Map<String, Object>> sysUser = new ArrayList<>();
            List<Map<String, Object>> list = newsMapper.selectSysUser();
            for (int j = 0; j < list.size(); j++) {
                Map<String, Object> maps = new HashMap<>();
                maps.put("title", news.getTitle());
                maps.put("content", news.getContent());
                maps.put("types", "2");
                maps.put("create_name", createName);
                maps.put("if_see", "1");
                maps.put("status", 2);
                maps.put("create_time", new Date());
                maps.put("user_id", list.get(j).get("user_id"));
                sysUser.add(maps);
            }
            newsMapper.installList(sysUser);
        }

        // TODO 友盟推送
        String content = Jsoup.parse(news.getContent()).text();
        if (content.length() > 50) {
            content = content.substring(0, 49);
        }

        // ios
        List<Integer> list = new ArrayList<>();
        list = mapList.stream()
                .filter(a -> (a.get("plat_form") + "").equals("1"))
                .map(a -> Integer.valueOf(a.get("id") + ""))
                .collect(Collectors.toList());
        umengUtils.sendIOSGroupcast(news.getTitle(), content, "2", news.getId(), list);

        // 安卓普通用户
        list = mapList.stream()
                .filter(a -> (a.get("plat_form") + "").equals("2"))
                .filter(a -> (a.get("user_type") + "").equals("1"))
                .map(a -> Integer.valueOf(a.get("id") + ""))
                .collect(Collectors.toList());
        if (list.size() > 0) {
            umengUtils.sendAndroidGroupcast(news.getTitle(), content, list, "1", news.getId());
        }

        // 安卓经纪人和公司
        list = mapList.stream()
                .filter(a -> (a.get("plat_form") + "").equals("0"))
                .filter(a -> !(a.get("user_type") + "").equals("1"))
                .map(a -> Integer.valueOf(a.get("id") + ""))
                .collect(Collectors.toList());
        if (list.size() > 0) {
            umengUtils.sendAndroidGroupcast(news.getTitle(), content, list, "2", news.getId());
        }

        return 1;
    }

    @Override
    public List<Map<String, Object>> selectList(Map<String, Object> parameters) {
        List<Map<String, Object>> mapList = newsMapper.selectList(parameters);

        for (int i = 0; i < mapList.size(); i++) {
            //设置城市
            List<String> list = Arrays.asList(String.valueOf(mapList.get(i).get("city_id")).split(","));
            String cityText = StringUtils.EMPTY;
            for (int j = 0; j < list.size(); j++) {
                if (StringUtils.isNotBlank(list.get(j))) {
                    String c = newsMapper.selectCityId(list.get(j));
                    mapList.get(i).put("cityText", cityText = cityText + "," + c);
                }
            }

            //接收范围
            String channelTest = StringUtils.EMPTY;
            //发布渠道，1：ios，2：安卓，3：支撑端（可多选）
            List<String> channel = Arrays.asList(String.valueOf(mapList.get(i).get("channel")).split(","));
            for (int j = 0; j < channel.size(); j++) {
                if (StringUtils.isNotBlank(channel.get(j))) {
                    if (channel.get(j).equals("1")) {
                        channelTest = channelTest + ",ios";
                    } else if (channel.get(j).equals("2")) {
                        channelTest = channelTest + ",安卓";
                    } else if (channel.get(j).equals("3")) {
                        channelTest = channelTest + ",支撑端";
                    }
                    mapList.get(i).put("channelTest", channelTest);
                }
            }

            //发布类型，1：独立经纪人，2：经纪人公司以及团队，3：普通用户（可多选）
            List<String> push_type = Arrays.asList(String.valueOf(mapList.get(i).get("push_type")).split(","));
            for (int j = 0; j < push_type.size(); j++) {
                if (StringUtils.isNotBlank(push_type.get(j))) {
                    if (push_type.get(j).equals("1")) {
                        channelTest = channelTest + ",独立经纪人";
                    } else if (push_type.get(j).equals("2")) {
                        channelTest = channelTest + ",经纪人公司以及团队";
                    } else if (push_type.get(j).equals("3")) {
                        channelTest = channelTest + ",普通用户";
                    }
                    mapList.get(i).put("channelTest", channelTest);
                }
            }
        }
        return mapList;
    }

    @Override
    public Map<String, Object> selectById(String id) {
        return newsMapper.selectById(id);
    }


    @Override
    public int remove(String id) {
        return newsMapper.remove(id);
    }

    //审核通过模板  恭喜！您发布的房源【房源名称】已经审核通过并自动上架啦，你可以去【⼯作管理】中进行查看。
    private String AUDIT_SUCCESS_TITLE_TEMP = "房源审核通过提醒";
    private String AUDIT_SUCCESS_COENT_TEMP = "恭喜！您发布的房源【FYMC】已经审核通过并自动上架啦，你可以去【⼯作管理】中进行查看。";
    //审核拒绝模板   您发布的房源【房源名称】审核未通过，您可以去【⼯作管理】中进⾏查看未通过的原因。
    private String AUDIT_FAIL_TITLE_TEMP = "房源审核未通过提醒";
    private String AUDIT_FAIL_CONENT_TEMP = "您发布的房源【FYMC】审核未通过，您可以去【工作管理】中查看未通过原因。";

    @Override
    public int sendSuccessMessage(String shopNum, Long agentId) {
        List<Map<String, Object>> newsUser = new ArrayList<>();
        Map<String, Object> maps = new HashMap<>();
        String content = AUDIT_SUCCESS_COENT_TEMP.replace("FYMC", shopNum);
        maps.put("title", AUDIT_SUCCESS_TITLE_TEMP);
        maps.put("content", content);
        maps.put("user_id", agentId);
        maps.put("types", 1);
        maps.put("if_see", 1);
        maps.put("create_time", new Date());
        newsUser.add(maps);
        return newsMapper.installList(newsUser);
    }

    @Override
    public int sendFailMessage(String shopNum, Long agentId) {
        List<Map<String, Object>> newsUser = new ArrayList<>();
        Map<String, Object> maps = new HashMap<>();
        String content = AUDIT_FAIL_CONENT_TEMP.replace("FYMC", shopNum);
        maps.put("title", AUDIT_FAIL_TITLE_TEMP);
        maps.put("content", content);
        maps.put("user_id", agentId);
        maps.put("types", 1);
        maps.put("if_see", 1);
        maps.put("create_time", new Date());
        newsUser.add(maps);
        return newsMapper.installList(newsUser);
    }

    @Override
    public int offlineBrand(String id) {
        return newsMapper.offlineBrand(id);
    }

    @Override
    public int onlineBrand(String id) {
        return newsMapper.onlineBrand(id);
    }
}
