package com.up.mls.service.office.impl;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.up.mls.mapper.office.OfficeDicMapper;
import com.up.mls.mapper.office.OfficeExtendMapper;
import com.up.mls.mapper.office.OfficeMapper;
import com.up.mls.mapper.system.AreasMapper;
import com.up.mls.mapper.system.DictionaryMapper;
import com.up.mls.mapper.system.RegionsMapper;
import com.up.mls.service.office.OfficeService;
import com.up.mls.util.DateUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.office.Audit;
import com.up.mls.vo.office.CommissionEntity;
import com.up.mls.vo.office.Office;
import com.up.mls.vo.office.OfficeDic;
import com.up.mls.vo.office.OfficeExtend;
import com.up.mls.vo.shop.Shop;
import com.up.mls.vo.system.Areas;



@Service
public class OfficeServiceImpl implements OfficeService{
	

	@Autowired
	private OfficeMapper officeMapper;
	@Autowired
	private OfficeDicMapper officeDicMapper;
	/*@Autowired
	private RedisService redisService;*/
	@Autowired
	private DictionaryMapper dictionaryMapper;
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private RegionsMapper regionsMapper;
	@Autowired
	private OfficeExtendMapper officeExtendMapper;
	


	//office 字典项中  type=2 为写字楼
	private static final String TYPE_OFFICE = "2";

	//dictionary字典项中 520 为商铺配置
	private static final String SHOP_CONFIG= "520";
	//dictionary字典项中 410 为写字楼特殊标签
	private static final String OFFICE_SPECIAL= "410";

	@Override
	public List<Office> selectOfficeList(Office office) {
		return officeMapper.selectOfficeList(office);
	}
	
	@Override
	public List<Audit> findAuditList(String officeId) {
		Map<String,Object> map=new HashMap<>();
		map.put("objectId", officeId);
		map.put("type", 2);
		return officeMapper.findAuditList(map);
	}
	@Override
	public Office selectByPrimaryKey(Long id) {
		return officeMapper.selectByPrimaryKey(id);
	}
	
	@Override
	public Office findEntityByOfficeNumber(String officeNumber) {
		return officeMapper.findEntityByOfficeNumber(officeNumber);
	}

	
	/**
	 * 发布写字楼
	 */
	@Override
	@Transactional
	public int insertOffice(Office office) {
		int saveResultNum = 1;
		try {
			office.setOfficeNumber(findNextOfficeNumber("F"));
			office.setCreateTime(new Date());
			office.setAgentId(SpringSecurityUtils.getUserId());
			
			//格式化佣金
			CommissionEntity commEn=this.jsonCommission(office.getRentType(), office.getCommissionValue()+"", office.getCommissionType());
			if(commEn!=null){
				office.setCommissionValue(commEn.getCommissionValue());
				office.setCommission(commEn.getCommission());
			}
			
			//格式化标题-处理分页列表显示的特殊标题
			Areas areasEn=this.areasMapper.selectProvinceIdByCityId(office.getAreaId()+"");
			office.setAreaName(areasEn==null?"":areasEn.getAreaName());
			office.setRegionName(this.regionsMapper.findNameById(office.getBusinessAreaId()+""));
			Map<String,String> pcRes=this.jsonPcPageOfficeTitle(office);
			office.setTitlePc(pcRes.get("titlePc"));
			office.setTitlePcSub(pcRes.get("titlePcSub"));
			Map<String,String> appRes=this.jsonAppPageOfficeTitle(office);
			office.setTitle(appRes.get("title"));
			office.setTitleSub(appRes.get("titleSub"));
			
			officeMapper.insertOffice(office);
			//商铺配套
			Set<String> set = office.getShopSupportingsId();  
			Iterator<String> it = set.iterator();  
			while (it.hasNext()) {  
			  String sssId = it.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(office.getId());
			  odic.setDValue(sssId);
			  odic.setType(TYPE_OFFICE);
			  odic.setDicType(SHOP_CONFIG);
			  officeDicMapper.insertOfficeDic(odic);
			}
			//特殊标签
			Set<String> tagSet = office.getShopTagId();
			Iterator<String> tagIt = tagSet.iterator();  
			while (tagIt.hasNext()) {  
			  String tagId = tagIt.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(office.getId());
			  odic.setDValue(tagId);
			  odic.setType(TYPE_OFFICE);
			  odic.setDicType(OFFICE_SPECIAL);
			  officeDicMapper.insertOfficeDic(odic);
			  
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return saveResultNum;
	}

	
	
	/**
	 * 格式化佣金
	 * @param channel
	 * @param rentType
	 * @param commissionValue
	 * @param commissionType
	 * @return
	 */
	@Override
	public CommissionEntity jsonCommission(String rentType,String commissionValue,String commissionType){
		CommissionEntity entity=new CommissionEntity();
		commissionValue=DateUtils.subZeroAndDot(commissionValue);//格式化去掉小数点后的0
		if("2".equals(commissionType)){
			entity.setCommission(commissionValue+"元");
			entity.setCommissionValue(new BigDecimal(commissionValue));
		}else{
			if("1".equals(rentType) || "3".equals(rentType)){
				entity.setCommission(commissionValue+"个月的租金");
				entity.setCommissionValue(new BigDecimal(commissionValue));
			}else{
				//出售，成本价
				entity.setCommission("成交价的"+commissionValue+"%");
				BigDecimal valueLess=new BigDecimal(commissionValue).divide(new BigDecimal(100),4, BigDecimal.ROUND_HALF_DOWN);
				entity.setCommissionValue(valueLess);//除100 佣金比
			}
		}
		return entity;
	}
	
	//app标题
	public Map<String,String> jsonAppPageOfficeTitle(Office entity)throws Exception{
		String rentType=entity.getRentType();
		Map<String,String> resMap=new HashMap<String,String>();
		String title="";
		String titleSub="";
		String areaName=entity.getAreaName();
		String resionsName=entity.getRegionName();
		String buildArea=entity.getBuildArea()+"";
		Map<String,Object> typeMap=new HashMap<String,Object>();
		typeMap.put("dValue", entity.getType());
		typeMap.put("parentKey", "510");
		String typeName=this.dictionaryMapper.selectByDValue(typeMap);
		String register="不可注册";
		if("2".equals(entity.getRegister())){
			register="可注册";
		}
		if("1".equals(rentType)){
			//租写字楼：区域+商圈l面积   [副标题]写字楼类型+可注册+类型（出租） areaRegion
			title=areaName+resionsName+"|"+buildArea+"㎡";
			titleSub=typeName+"|"+register+"出租";
		}else if("2".equals(rentType)){
			//买写字楼：区域+商圈l面积   [副标题]写字楼类型+可注册+类型（出售）
			title=areaName+resionsName+"|"+buildArea+"㎡";
			titleSub=typeName+"|"+register+"出售";
		}else {
			//楼盘名称  [副标题]区域-商圈|建面
			title=entity.getName(); 
			titleSub=areaName+resionsName+"|"+buildArea+"㎡";
		}
		resMap.put("title", title);
		resMap.put("titleSub", titleSub);
		return resMap;
	}

	
	/**
	 * 	pc分页标题
	 * 	写字楼出售：	标题：楼盘/面积/可注册/可分割（不可注册、不可分割不显示）;副标题1：区域商圈;副标题2：写字楼类型
	 *	写字楼出租：	标题：楼盘/面积/可分割（不可分割不显示）;副标题1：区域商圈;副标题2：写字楼类型
	 *	写字楼新盘:		标题：楼盘;	副标题1：详细地址;副标题2：写字楼类型
	 * @param entity
	 * @return
	 * @throws Exception
	 */
	public Map<String,String> jsonPcPageOfficeTitle(Office entity)throws Exception{
		String rentType=entity.getRentType();
		Map<String,String> resMap=new HashMap<String,String>();
		String titlePc="";
		String buildArea=entity.getBuildArea()+"";
		String areaName=entity.getAreaName();
		String resionsName=entity.getRegionName();
		String register="";
		String separate="";
		if("2".equals(entity.getSeparate())){
			separate="/可分割";
		}
		if("2".equals(entity.getRegister())){
			register="/可注册";
		}
		
		if("1".equals(rentType)){
			//写字楼出售：	标题：楼盘/面积/可注册/可分割（不可注册、不可分割不显示）;副标题：区域商圈;
			titlePc=entity.getName()+"/"+buildArea+"㎡"+register+separate;
		}else if("2".equals(rentType)){
			//写字楼出租：	标题：楼盘/面积/可分割（不可分割不显示）;副标题：区域商圈;
			titlePc=entity.getName()+"/"+buildArea+"㎡"+separate;
		}else {
			//写字楼新盘:	标题：楼盘;	副标题：详细地址;
			titlePc=entity.getName(); 
		}
		resMap.put("titlePc", titlePc);
		resMap.put("titlePcSub", areaName+"，"+resionsName);
		return resMap;
	}
	
	
	
	@Override
	public Office toEdit(Long id) {
		Office office = officeMapper.selectByPrimaryKey(id);
		//配套
		OfficeDic ods = new OfficeDic(id, TYPE_OFFICE, SHOP_CONFIG);
		Set<OfficeDic> odic = officeDicMapper.selectDicByOffice(ods);
		Set<String> supportSet = new HashSet<String>();
		odic.forEach(s -> {
			String supportId = s.getDValue();
			supportSet.add(supportId);
		});
		office.setShopSupportingsId(supportSet);
		//特殊标签
		OfficeDic odt = new OfficeDic(id, TYPE_OFFICE, OFFICE_SPECIAL);
		Set<OfficeDic> tagOdic = officeDicMapper.selectDicByOffice(odt);
		Set<String> tagSet = new HashSet<String>();
		tagOdic.forEach(s -> {
			String tagId = s.getDValue();
			tagSet.add(tagId);
		});
		office.setShopTagId(tagSet);
		return office;
	}
	
	@Override
	@Transactional
	public int updateOffice(Office office) {
		
		//1-更新商铺配套
		if(office.getShopSupportingsId() != null && !office.getShopSupportingsId().isEmpty()) {
			//1、删除原有配置
			OfficeDic ods = new OfficeDic(office.getId(), TYPE_OFFICE,SHOP_CONFIG);
			officeDicMapper.deleteDicTag(ods);
			//更新为最新配置
			Set<String> set = office.getShopSupportingsId();  
			Iterator<String> it = set.iterator();  
			while (it.hasNext()) {  
			  String sssId = it.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(office.getId());
			  odic.setDValue(sssId);
			  odic.setType(TYPE_OFFICE);
			  odic.setDicType(SHOP_CONFIG);
			  officeDicMapper.insertOfficeDic(odic);
			}
		}
		//2-跟新商铺标签
		if(office.getShopTagId() != null && !office.getShopTagId().isEmpty()) {
			OfficeDic odt = new OfficeDic(office.getId(), TYPE_OFFICE,OFFICE_SPECIAL);
			officeDicMapper.deleteDicTag(odt);
			Set<String> tagSet = office.getShopTagId();
			Iterator<String> tagIt = tagSet.iterator();
			while (tagIt.hasNext()) {  
			  String tagId = tagIt.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(office.getId());
			  odic.setDValue(tagId);
			  odic.setType(TYPE_OFFICE);
			  odic.setDicType(OFFICE_SPECIAL);
			  officeDicMapper.insertOfficeDic(odic);
			}
		}
		
		//格式化佣金
		CommissionEntity commEn=this.jsonCommission(office.getRentType(), office.getCommissionValue()+"", office.getCommissionType());
		office.setCommission(commEn==null?"暂无":commEn.getCommission());
		office.setCommissionValue(commEn.getCommissionValue());
		return officeMapper.updateOffice(office);
	}
	
	@Override
	public Office detail(Long id) {
		Office office = officeMapper.selectByPrimaryKey(id);
		//配套
		OfficeDic ods = new OfficeDic(office.getId(), TYPE_OFFICE, SHOP_CONFIG);
		Set<OfficeDic> odic = officeDicMapper.selectDicByOffice(ods);
		Set<String> supportSet = new HashSet<String>();
		odic.forEach(s -> {
			String supportId = s.getDValue();
			supportSet.add(supportId);
		}); 
		office.setShopSupportingsId(supportSet);
		//特殊标签
		OfficeDic odt = new OfficeDic(office.getId(), TYPE_OFFICE, OFFICE_SPECIAL);
		Set<OfficeDic> tagOdic = officeDicMapper.selectDicByOffice(odt);
		Set<String> tagSet = new HashSet<String>();
		tagOdic.forEach(s -> {
			String tagId = s.getDValue();
			tagSet.add(tagId);
		});
		office.setShopTagId(tagSet);


		return office;
	}
	
	@Override
	public int selectOnOfflineCount(String onlineStatus,String rentType) {
		return officeMapper.selectOnOfflineCount(onlineStatus,rentType);
	}
	/**
	 * 写字楼分配经济人
	 */
	@Override
	public int distribution(String saleId,String ids) {
		Integer count = 0;
		String[] str = ids.split(",");
		for(int i=0;i<str.length;i++) {
			 Office office = officeMapper.selectByPrimaryKey(Long.valueOf(str[i]));
			 office.setAgentId(Long.valueOf(saleId));
			 office.setDistTime(new Date());
			 office.setDistStatus(1);	//0:未分配 1:已分配
			 officeMapper.updateOfficeDistStatus(office);
			 count++;
		}
		return count;
	}
	
	@Override
	public List<Office> selectOfficeListForPromote(Office office) {
		return officeMapper.selectOfficeListForPromote(office);
	}

	@Override
	public int updateOfficePromote(Office office) {
		return officeMapper.updateOfficePromote(office);
	}
	
	@Override
	public int updateOfficeSort(Office office) {
		return officeMapper.updateOfficeSort(office);
	}
	
	@Override
	public synchronized String findNextOfficeNumber(String pre) {
		int rd = (int) ((Math.random() * 9 + 1) * 10000000);//前缀+8位随机数
		return pre+rd;
	}
	
	@Override
	public int updateOfficeOnlineStatus(Office office) {
		// TODO Auto-generated method stub
		return officeMapper.updateOfficeOnlineStatus(office);
	}
	
	@Override
	public int updateOfficeAudit(Office office,Long loginUserId,String loginUserName) {
		try {
			/*//更新主表
			office.setAuditStatus(office.getAuditStatus());
			office.setAuditUserName(SpringSecurityUtils.getLoginName());
			office.setAuditTime(new Date());
			office.setAuditUserId(Integer.valueOf(loginUserId.toString()));
			if(office.getAuditStatus() == 2){
				//审核通过后才能上架，且审核通过后默认自动上架；
				office.setOnlineStatus("1");
			}
			//officeMapper.updateOfficeAudit(office);
			//添加日志
			Audit auditEntity=new Audit();
			auditEntity.setAuditUserId(Integer.valueOf(loginUserId.toString()));
			auditEntity.setAuditUserName(loginUserName);
			auditEntity.setObjectId(Integer.valueOf(office.getId()+""));
			auditEntity.setType("2");
			auditEntity.setAuditStatus(office.getAuditStatus()+"");
			this.officeMapper.saveOfficeAudit(auditEntity);*/
		} catch (NumberFormatException e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
	
	
	//添加审核日志
	@Override
	public void addAudit(Office oldEn,Office officeNew){
		Audit auditEntity=new Audit();
		auditEntity.setAuditUserId(officeNew.getAuditUserId());
		auditEntity.setAuditUserName(officeNew.getAuditUserName());
		auditEntity.setObjectId(officeNew.getId().intValue());
		auditEntity.setType("2");
		auditEntity.setAuditStatus(officeNew.getAuditStatus()+"");
		auditEntity.setRemark(officeNew.getAuditReasion());
		//保存联系人手机号、佣金修改 前后值
		if(oldEn.getCommissionValue() != null && officeNew.getCommissionValue().compareTo(oldEn.getCommissionValue()) != 0) {
			auditEntity.setCommissionValueOld(oldEn.getCommissionValue());
		}
		if(oldEn.getPhone() != null && !officeNew.getPhone().equals(oldEn.getPhone())) {
			auditEntity.setPhoneOld(oldEn.getPhone());
		}
		if(oldEn.getJiafangUserId() != officeNew.getJiafangUserId()) {
			auditEntity.setJiafangOld(oldEn.getJiafangUserId()==null?-1:oldEn.getJiafangUserId().longValue());
		}
		if(oldEn.getJiedaiUserId() != officeNew.getJiedaiUserId()) {
			auditEntity.setJiedaiOld(oldEn.getJiedaiUserId()==null?-1:oldEn.getJiedaiUserId().longValue());
		}
		if(oldEn.getWeihuUserId() != officeNew.getWeihuUserId()) {
			auditEntity.setWeihuOld(officeNew.getWeihuUserId());
		}
		this.officeMapper.saveOfficeAudit(auditEntity);
	}

	
	@Override
	public int saveRenlin(Office entity) {
		try {
			this.officeMapper.saveRenlin(entity);
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
	
	@Override
	public int saveRenlinBatch(Map<String,Object> map) {
		try {
			this.officeMapper.saveRenlinBatch(map);
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
	
	@Override
	public int realseRenlinBatch(Map<String,Object> map) {
		try {
			this.officeMapper.saveRenlinBatch(map);
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
	
	@Override
	public int saveOfficeAudit(Audit entity) {
		try {
			this.officeMapper.saveOfficeAudit(entity);
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
	
	
	
	@Override
	public void jsonHuiXianOfficeCommission(Office office){
		//回显去掉多余的0
		office.setCommissionValue(new BigDecimal(DateUtils.subZeroAndDot(office.getCommissionValue()+"")));
		//如果是百分比要特殊处理(百分比&出售)
		if("1".equals(office.getCommissionType()) && ("2".equals(office.getRentType()) || "4".equals(office.getRentType()))){
			BigDecimal valueLess=office.getCommissionValue().multiply(new BigDecimal(100));
			office.setCommissionValue(valueLess);//佣金值乘以100
		}
	}
	
	
	@Override
	public OfficeExtend findExtendEntity(String officeId){
		return this.officeExtendMapper.findEntityById(officeId);
	}
	@Override
	public void addExtend(OfficeExtend offExtend){
		this.officeExtendMapper.saveEntity(offExtend);
	}
	@Override
	public void updateExtend(OfficeExtend offExtend){
		this.officeExtendMapper.updateEntity(offExtend);
	}
	
	@Override
	public int updateTopStatus(Office entity) {
		officeMapper.updateTopStatus(entity);
		return 1;
	}
	
	
	
}
