package com.up.mls.service.order.impl;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.up.mls.mapper.order.OrderMapper;
import com.up.mls.service.order.OrderService;
import com.up.mls.vo.deal.ProjectOrder;
import com.up.mls.vo.deal.ProjectOrderTrack;

@Service
public class OrderServiceImpl implements OrderService {

    @Autowired
    private OrderMapper orderMapper;

    @Override
    public List<Map<String, Object>> selectList(Map<String, Object> parameters) {
        return orderMapper.selectList(parameters);
    }
    
    /**
	 * 订单审核记录
	 * @param orderStatus
	 * @param paraMap
	 * @param resultObject
	 * @myRoleType:1-房源；2-客源
	 * @return
	 */
    @Override
	public List<Map<String,Object>>  findOrderLogList(String orderNo){
		List<Map<String,Object>> list=new ArrayList<Map<String,Object>>();
		List<String> types = Arrays.asList("终止","审核","联系","到访","认购","签约","结佣","完成");
		Map<String,Object> paraMap=new HashMap<String,Object>();
		paraMap.put("orderNo", orderNo);
		List<Map<String,Object>> listA=this.orderMapper.findTrackListByOid(paraMap);
		if(listA!=null && listA.size()>0 && listA.get(0) !=null){
			for(Map<String,Object> temp:listA){
				Map<String,Object> mapItem=new HashMap<String,Object>();
				//mapItem.put("orderNo", temp.get("order_no"));
				String statusName=types.get(Integer.valueOf(temp.get("order_status")+""));
				mapItem.put("title", temp.get("customer_name")+"，"+statusName+"成功");
				mapItem.put("agentId", temp.get("agent_id"));
				mapItem.put("imgs", temp.get("pic_path")==null?new ArrayList<>():Arrays.asList(String.valueOf(temp.get("pic_path")).split(",")));
				mapItem.put("createTime", temp.get("create_time"));
				list.add(mapItem);
			}
		}
		return list;
	}
	
    
    /**
     * 修改订单状态+ 增加结佣记录
     * 
     */
    @Override
	@Transactional
	public int updateOrder(ProjectOrder entity) {
		int saveResultNum = 1;
		try {
			
			Integer status=entity.getOrderStatus();
			ProjectOrder order = this.orderMapper.findOrderByOrderSn(entity.getOrderNo());
			if (order != null) {
				if(status ==6){
					// 更新订单状态
					order.setOrderStatus(6);
					order.setSettleTime(new Date());
					this.orderMapper.updateOrder(order);
					// 删除旧的记录日志
					this.orderMapper.updateIsDelByOrderNo(entity.getOrderNo());
					// 添加新的记录日志
					ProjectOrderTrack track = new ProjectOrderTrack();
					track.setOrderNo(entity.getOrderNo());
					track.setCreateTime(new Date());
					track.setProjectName(order.getProjectName());
					track.setCustomerName("线下审核结佣通过");
					track.setOrderStatus(order.getOrderStatus());
					track.setProjectId(order.getProjectId());
					track.setProjectType(order.getProjectType());
					track.setAgentId(order.getAgentId());
					this.orderMapper.saveTrackLog(track);
				}else{
					order.setFinishTime(new Date());
					this.orderMapper.updateOrder(entity);
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return saveResultNum;
	}

	
    
    
    
    
}
