package com.up.mls.service.redis.impl;

import java.math.BigInteger;
import java.text.DecimalFormat;
import java.util.Calendar;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.RandomUtils;
import org.apache.commons.lang3.StringUtils;
import org.redisson.api.RLock;
import org.redisson.api.RedissonClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataAccessException;
import org.springframework.data.redis.core.types.Expiration;
import org.springframework.stereotype.Service;

import com.up.mls.common.constant.RedisBusinesKeys;
import com.up.mls.mapper.office.OfficeMapper;
import com.up.mls.mapper.shop.ShopMapper;
import com.up.mls.service.redis.RedisService;
import com.up.mls.util.RedisUtil;



@Service
public class RedisServiceImpl implements RedisService {
	private static final Logger LOG = LoggerFactory.getLogger(RedisServiceImpl.class);
//	@Autowired
//	EmailService emailService;
	@Autowired
	ShopMapper shopMapper;
	@Autowired
	OfficeMapper officeMapper;
	@Autowired
	HttpServletRequest request;
	@Autowired
	RedissonClient redisson;
	

	@Override
	public boolean setBusinesKey(final RedisBusinesKeys keys, final String key, final Object value,
			final Expiration expiration) {
		boolean result = Boolean.FALSE;
		String redisKey = keys.getPrefix();
		try {
			if (StringUtils.isNotBlank(key)) {
				redisKey = keys.join(key);
			}
			RedisUtil.set(redisKey, value, expiration);
		} catch (DataAccessException e) {
			LOG.error(e.getLocalizedMessage(), e);
//			emailService.sendErrorEmail("【异常】redis设置值异常" + RequesUtil.getRequstMethodAndUrlAndParam(request), e);
		}
		return result;
	}

	@SuppressWarnings("unchecked")
	@Override
	public String getShopNumber() {
		DecimalFormat df = new DecimalFormat("000000");
		String key = RedisBusinesKeys.MLS_SHOP_SHOPNUMBER.getPrefix();
		try {
			if (!RedisUtil.hasKey(key)) {
				RLock lock = redisson.getLock("anyLock");
				try {
					// 尝试加锁，最多等待3秒，上锁以后10秒自动解锁
//					boolean res = lock.tryLock(3, 10, TimeUnit.SECONDS);
//					if (res) {
//						if (!RedisUtil.hasKey(key)) {
//							String shopNumber = shopMapper.selectMaxShopNum();
//							if(StringUtils.isBlank(shopNumber)) {
//								RedisUtil.set(key, 3000, null);
//							}else {
//								RedisUtil.set(key, Long.valueOf(shopNumber),null);
//							}
//						}
//
//					}
				} catch (Exception e) {
					e.printStackTrace();
				} finally {
					lock.unlock();
				}
			}

			String shopNumberStr = df.format(RedisUtil.incrLong(key, 1L));
			LOG.info("【redis】 生成商铺编号:{} ", shopNumberStr);
			return shopNumberStr;
		} catch (Exception e) {
			LOG.error("【redis】 生成商铺编号异常 ", e);
//			emailService.sendErrorEmail("【异常】 生成商铺编号异常 " + RequesUtil.getRequstMethodAndUrlAndParam(request), e);
			return null;
		}
	}
	
	
	@SuppressWarnings("unchecked")
	@Override
	public String getOfficeNumber() {
		DecimalFormat df = new DecimalFormat("000000");
		String key = RedisBusinesKeys.MLS_OFFICE_OFFICENUMBER.getPrefix();
		try {
			if (!RedisUtil.hasKey(key)) {
				RLock lock = redisson.getLock("anyLock");
				try {
					// 尝试加锁，最多等待3秒，上锁以后10秒自动解锁
					boolean res = lock.tryLock(3, 10, TimeUnit.SECONDS);
					if (res) {
						if (!RedisUtil.hasKey(key)) {
							String shopNumber = officeMapper.selectMaxOfficeNum();
							if(StringUtils.isBlank(shopNumber)) {
								RedisUtil.set(key, 3000, null);
							}else {
								RedisUtil.set(key, Long.valueOf(shopNumber),null);
							}
						}

					}
				} catch (Exception e) {
					e.printStackTrace();
				} finally {
					lock.unlock();
				}
			}

			String shopNumberStr = df.format(RedisUtil.incrLong(key, 1L));
			LOG.info("【redis】 生成写字楼编号:{} ", shopNumberStr);
			return shopNumberStr;
		} catch (Exception e) {
			LOG.error("【redis】 生成写字楼编号异常 ", e);
//			emailService.sendErrorEmail("【异常】 生成商铺编号异常 " + RequesUtil.getRequstMethodAndUrlAndParam(request), e);
			return null;
		}
	}

//	@Override
//	public Long getShopPVCount(final Long shopId) {
//		String key = RedisBusinesKeys.MLS_SHOP_PAGE_VIEW.join(shopId);
//		Long pvCount = null;
//		RLock lock = null;
//		try {
//			if (!RedisUtil.hasKey(key)) {
//				lock = redisson.getLock("browseLock");
//				// 尝试加锁，最多等待3秒，上锁以后10秒自动解锁
//				boolean res = lock.tryLock(3, 10, TimeUnit.SECONDS);
//				if (res) {
//					if (!RedisUtil.hasKey(key)) {
//						BrowseRecords br = browseRecordsService.findByShopId(shopId);
//						if (Objects.nonNull(br)) {
//							pvCount = br.getCount();
//						} else {
//							pvCount = RandomUtils.nextLong(50, 60);
//							browseRecordsService.save(new BrowseRecords(shopId, pvCount));
//						}
//						RedisUtil.set(key, pvCount, null);
//						RedisUtil.sAdd("pv:shops", shopId.toString());
//					}
//				}
//			}
//			pvCount = (Long) RedisUtil.incrLong(key, 1L);
//			LOG.info("【redis】 生成 商铺浏览量 商铺ID:{},商铺浏览量:{}", shopId, pvCount);
//		} catch (Exception e) {
//			emailService.sendErrorEmail("【异常】 redis生成商铺浏览量异常 " + RequesUtil.getRequstMethodAndUrlAndParam(request), e);
//			LOG.error("【redis】生成 商铺浏览量异常", e);
//		} finally {
//			if (Objects.nonNull(lock)) {
//				lock.unlock();
//			}
//		}
//		return pvCount;
//	}

	@Override
	public Long[] getCount() {
		Long expireTime = diffBy24Hour();
		Long newUpCount = BigInteger.ZERO.longValue();// 24小时新上商铺数量
		Long findCount = BigInteger.ZERO.longValue();// 在线找铺人数量
		Long onLineCount = BigInteger.ZERO.longValue();// 在线商铺数量

		String new24Key = RedisBusinesKeys.MLS_APP_SHOP_COUNT_BY_24_NEW.getPrefix();
		String findKey = RedisBusinesKeys.MLS_APP_SHOP_COUNT_BY_FIND.getPrefix();
		String onLine = RedisBusinesKeys.MLS_APP_SHOP_COUNT_BY_ON_LINE.getPrefix();
		try {
			if (RedisUtil.hasKey(new24Key)) {
				newUpCount = Long.valueOf(RedisUtil.get(new24Key, String.class));
			} else {
				newUpCount = RandomUtils.nextLong(500, 800);
				RedisUtil.set(new24Key, newUpCount, Expiration.milliseconds(expireTime));
			}

			if (RedisUtil.hasKey(findKey)) {
				findCount = Long.valueOf(RedisUtil.get(findKey, String.class));
			} else {
				findCount = RandomUtils.nextLong(50000, 80000);
				RedisUtil.set(findKey, findCount, Expiration.milliseconds(expireTime));
			}

			if (RedisUtil.hasKey(onLine)) {
				onLineCount = Long.valueOf(RedisUtil.get(onLine, String.class));
			} else {
				onLineCount = RandomUtils.nextLong(50000, 80000);
				RedisUtil.set(onLine, onLineCount, Expiration.milliseconds(expireTime));
			}

		} catch (Exception ex) {
			LOG.error("redis App商铺24小时新上商铺数量,在线商铺总量、正在找铺人数量 异常", ex);

		}
		return ArrayUtils.toArray(newUpCount, findCount, onLineCount);
	}

	public static Long diffBy24Hour() {
		final Calendar cal = Calendar.getInstance();
		cal.set(Calendar.DAY_OF_MONTH, cal.get(Calendar.DAY_OF_MONTH) + 1);
		cal.set(Calendar.HOUR_OF_DAY, 0);
		cal.set(Calendar.MINUTE, 0);
		cal.set(Calendar.SECOND, 0);
		cal.set(Calendar.MILLISECOND, 0);
		return cal.getTimeInMillis() - System.currentTimeMillis();
	}

//	public static void main(String[] args) {
//		Long expireTime = diffBy24Hour();
//		Expiration e = Expiration.milliseconds(expireTime);
//		System.out.println(e.getTimeUnit());
//		System.out.println(expireTime);
//	}
}
