package com.up.mls.service.shop.impl;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.*;

import javax.servlet.http.HttpSession;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.up.mls.common.constant.FlowStatus;
import com.up.mls.mapper.office.OfficeDicMapper;
import com.up.mls.mapper.shop.BusinessAreaMapper;
import com.up.mls.mapper.shop.ShopMapper;
import com.up.mls.mapper.system.AreasMapper;
import com.up.mls.mapper.system.RoadMapper;
import com.up.mls.service.content.ISlideShowService;
import com.up.mls.service.news.NewsService;
import com.up.mls.service.redis.RedisService;
import com.up.mls.service.shop.ShopService;
import com.up.mls.util.ServletUtils;
import com.up.mls.vo.office.Audit;
import com.up.mls.vo.office.OfficeDic;
import com.up.mls.vo.shop.BusinessArea;
import com.up.mls.vo.shop.Shop;
import com.up.mls.vo.shop.ShopExtend;
import com.up.mls.vo.system.Areas;
import com.up.mls.vo.system.Road;



@Service
public class ShopServiceImpl implements ShopService{
	
	private static final Logger log = LoggerFactory.getLogger(ShopServiceImpl.class);

	@Autowired
	private ShopMapper shopMapper;
	@Autowired
	private OfficeDicMapper officeDicMapper;
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private BusinessAreaMapper businessAreaMapper;
	@Autowired
	private RoadMapper roadMapper;
	@Autowired
	private RedisService redisService;
	@Autowired
	private ISlideShowService slideShowService;
	@Autowired
	private NewsService newService;


	//office 字典项中  type=1 为商铺
	private static final String TYPE_SHOP = "1";
	//dictionary字典项中 135 为商铺配套
	private static final String SHOP_MATING= "135";
	//dictionary字典项中 534 为新盘面积 复选
	private static final String NEW_ACREAGE= "534";
	//dictionary字典项中 136 商铺标签
	private static final String SHOP_TAG= "536";
	//dictionary字典项中 410 商铺标签
//	private static final String SHOP_NEW_TAG= "410";
	//dictionary字典项中 137 已有证件
	private static final String REFERRER_PAPERS= "137";

	@Override
	public List<Shop> selectShopList(Shop shop) {
		return shopMapper.selectShopList(shop);
	}
	
	@Override
	public Shop selectByPrimaryKey(Long id) {
		return shopMapper.selectByPrimaryKey(id);
	}
	
	@Override
	public Shop selectByShopNumber(String shopNumber) {
		return shopMapper.selectByShopNumber(shopNumber);
	}

	@Override
	@Transactional
	public int insertShop(Shop shop) {
		int saveResultNum = 1;
		//商铺来源
//		shop.setCreateType("7");		//后台录入
//		shop.setShopFlow("2");
		HttpSession session = ServletUtils.getSession();
//		shop.setProvinceId(session.getAttribute("currUserProvinceId").toString());
//		shop.setCityId(session.getAttribute("currUserCityId").toString());
		shop.setOnlineStatus("0");
		shop.setShopNumber(findNextShopNumber());
		shop.setCreateTime(new Date());
//		shop.setAgentId(SpringSecurityUtils.getUserId());
		//组装自定义名称 TODO
		StringBuffer name = new StringBuffer();
		Long areaId = shop.getAreaId();
		Long bussinessAreaId = shop.getBusinessAreaId();
//		Long roadId = shop.getRoadId();
		if(areaId != null && !"".equals(areaId)) {
			Areas areas = areasMapper.selectByPrimaryKey(areaId.toString());
			name.append(areas.getAreaName());
		}
		if(bussinessAreaId != null && !"".equals(bussinessAreaId)) {
			BusinessArea businessArea = businessAreaMapper.selectByPrimaryKey(bussinessAreaId);
			name.append(businessArea.getName());
		}
//		if(roadId != null && !"".equals(roadId)) {
//			Road road = roadMapper.selectByPrimaryKey(roadId);
//			name.append(road.getName());
//		}
		if (Objects.nonNull(shop.getUseArea())) {
			name.append(shop.getUseArea());
		}
		shop.setName(name.toString());
		int shopId = shopMapper.insertShop(shop);
		//商铺配套
		Set<String> set = shop.getShopSupportingsId();
		if (null != set){
			Iterator<String> it = set.iterator();
			while (it.hasNext()) {
				String sssId = it.next();
				OfficeDic odic = new OfficeDic();
				odic.setObjectId(shop.getId());
				odic.setDValue(sssId);
				odic.setType(TYPE_SHOP);
				odic.setDicType(SHOP_MATING);
				officeDicMapper.insertOfficeDic(odic);
			}
		}
		//新盘面积 复选
        List<String> shopMianJis = shop.getShopMianJis();
		if (null != shopMianJis){
			shopMianJis.forEach(m ->{
				OfficeDic odic = new OfficeDic();
				odic.setObjectId(shop.getId());
				odic.setDValue(m);
				odic.setType(TYPE_SHOP);
				odic.setDicType(NEW_ACREAGE);
				System.out.println(odic.toString());
				officeDicMapper.insertOfficeDic(odic);
			});
		}

        //特殊标签
		Set<String> tagSet = shop.getShopTagId();
		if (null != tagSet){
			Iterator<String> tagIt = tagSet.iterator();
			while (tagIt.hasNext()) {
				String tagId = tagIt.next();
				OfficeDic odic = new OfficeDic();
				odic.setObjectId(shop.getId());
				odic.setDValue(tagId);
				odic.setType(TYPE_SHOP);
				odic.setDicType(SHOP_TAG);
				officeDicMapper.insertOfficeDic(odic);
			}
		}

		//已有证件
		Set<String> paperSet = shop.getShopPaperId();
		if(paperSet !=null && paperSet.size()>0) {
			Iterator<String> paperIt = paperSet.iterator();  
			while (paperIt.hasNext()) {  
			  String paperId = paperIt.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(shop.getId());
			  odic.setDValue(paperId);
			  odic.setType(TYPE_SHOP);
			  odic.setDicType(REFERRER_PAPERS);
			  officeDicMapper.insertOfficeDic(odic);
			}
		}
		return saveResultNum;
	}
	@Override
	public Shop toEdit(Long id) {
		Shop shop = shopMapper.selectByPrimaryKey(id);
		//配套
		OfficeDic ods = new OfficeDic(id,TYPE_SHOP,SHOP_MATING);
		Set<OfficeDic> odic = officeDicMapper.selectDicByOffice(ods);
		Set<String> supportSet = new HashSet<String>();
		odic.forEach(s -> {
			String supportId = s.getDValue();
			supportSet.add(supportId);
		});
		shop.setShopSupportingsId(supportSet);
		//新盘面积
		OfficeDic odm = new OfficeDic(id,TYPE_SHOP,NEW_ACREAGE);
		Set<OfficeDic> mianJiodic = officeDicMapper.selectDicByOffice(odm);
		List<String> shopMianJis = new ArrayList<>();
		mianJiodic.forEach(s -> {
			String supportId = s.getDValue();
			shopMianJis.add(supportId);
		});
			shop.setShopMianJis(shopMianJis);
		//特色标签
		OfficeDic odt = new OfficeDic(id,TYPE_SHOP,SHOP_TAG);
		Set<OfficeDic> tagOdic = officeDicMapper.selectDicByOffice(odt);
		Set<String> tagSet = new HashSet<String>();
		tagOdic.forEach(s -> {
			String tagId = s.getDValue();
			tagSet.add(tagId);
		});
		shop.setShopTagId(tagSet);
		//已有证件
		OfficeDic odp = new OfficeDic(id,TYPE_SHOP,REFERRER_PAPERS);
		Set<OfficeDic> paperOdic = officeDicMapper.selectDicByOffice(odp);
		Set<String> paperSet = new HashSet<String>();
		paperOdic.forEach(s -> {
			String paperId = s.getDValue();
			paperSet.add(paperId);
		});
		shop.setShopPaperId(paperSet);
		return shop;
	}
	
	@Override
	public int saveEdit(Shop shop) {
		//返回待审核列表，重新审核该商铺
		shop.setOnlineStatus("0");
		shop.setShopAudit(1);
		shopMapper.updateShopAudit(shop);
		return updateShop(shop);
	}
	
	@Override
	@Transactional
	public int updateShop(Shop shop) {
		//1-更新商铺配套
		if(shop.getShopSupportingsId() != null && !shop.getShopSupportingsId().isEmpty()) {
			//1、删除原有配置
			OfficeDic ods = new OfficeDic(shop.getId(),TYPE_SHOP,SHOP_MATING);
			officeDicMapper.deleteDicTag(ods);
			//更新为最新配置
			Set<String> set = shop.getShopSupportingsId();  
			Iterator<String> it = set.iterator();  
			while (it.hasNext()) {  
			  String sssId = it.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(shop.getId());
			  odic.setDValue(sssId);
			  odic.setType(TYPE_SHOP);
			  odic.setDicType(SHOP_MATING);
			  officeDicMapper.insertOfficeDic(odic);
			}
		}
		//2-跟新商铺标签
		if(shop.getShopTagId() != null && !shop.getShopTagId().isEmpty()) {
			OfficeDic odt = new OfficeDic(shop.getId(),TYPE_SHOP,SHOP_TAG);
			officeDicMapper.deleteDicTag(odt);
			Set<String> tagSet = shop.getShopTagId();
			Iterator<String> tagIt = tagSet.iterator();  
			while (tagIt.hasNext()) {  
			  String tagId = tagIt.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(shop.getId());
			  odic.setDValue(tagId);
			  odic.setType(TYPE_SHOP);
			  odic.setDicType(SHOP_TAG);
			  officeDicMapper.insertOfficeDic(odic);
			}
		}
		 //3-更新已有证件
		if(shop.getShopPaperId() != null && !shop.getShopPaperId().isEmpty()) {
			OfficeDic odp = new OfficeDic(shop.getId(),TYPE_SHOP,REFERRER_PAPERS);
			officeDicMapper.deleteDicTag(odp);
			Set<String> paperSet = shop.getShopPaperId();
			Iterator<String> paperIt = paperSet.iterator();  
			while (paperIt.hasNext()) {  
			  String paperId = paperIt.next();
			  OfficeDic odic = new OfficeDic();
			  odic.setObjectId(shop.getId());
			  odic.setDValue(paperId);
			  odic.setType(TYPE_SHOP);
			  odic.setDicType(REFERRER_PAPERS);
			  officeDicMapper.insertOfficeDic(odic);
			}
		}
		//4-跟新商铺面积（新盘出租）
		if(shop.getShopMianJis() != null && !shop.getShopMianJis().isEmpty()) {
			OfficeDic odp = new OfficeDic(shop.getId(),TYPE_SHOP,NEW_ACREAGE);
			officeDicMapper.deleteDicTag(odp);
			List<String> mjs = shop.getShopMianJis();
			mjs.forEach(m -> {
				System.out.println("m: "+m);
				OfficeDic odic = new OfficeDic();
				odic.setObjectId(shop.getId());
				odic.setDValue(m);
				odic.setType(TYPE_SHOP);
				odic.setDicType(NEW_ACREAGE);
				officeDicMapper.insertOfficeDic(odic);
			});
		}
		//根据日租金计算月租金  月租=日租*面积*365/12
		//商铺出租 按日租金计算月租金 月租=日租*面积*365/12，结果保留整数
		if (Objects.nonNull(shop.getDailyRent()) || String.valueOf(shop.getDailyRent()).equals("-2")) {
		    BigDecimal dailyRent = shop.getDailyRent();
		    BigDecimal buildArea = shop.getBuildArea();
		    BigDecimal MonthlyRent = dailyRent.multiply(buildArea).multiply(new BigDecimal(365)).divide(new BigDecimal(12), BigDecimal.ROUND_HALF_UP);
		    shop.setMonthlyRent(MonthlyRent);
		}
		int result = shopMapper.updateShop(shop);
		return result;
	}
	@Override
	public Shop detail(Long id) {
		Shop shop = shopMapper.selectByPrimaryKey(id);
		//配套
		OfficeDic ods = new OfficeDic(shop.getId(),TYPE_SHOP,SHOP_MATING);
		Set<OfficeDic> odic = officeDicMapper.selectDicByOffice(ods);
		Set<String> supportSet = new HashSet<String>();
		odic.forEach(s -> {
			String supportId = s.getDValue();
			supportSet.add(supportId);
		});
		shop.setShopSupportingsId(supportSet);
		//特色标签
		 OfficeDic odt = new OfficeDic(id, TYPE_SHOP, SHOP_TAG);
		Set<OfficeDic> tagOdic = officeDicMapper.selectDicByOffice(odt);
		Set<String> tagSet = new HashSet<String>();
		tagOdic.forEach(s -> {
			String tagId = s.getDValue();
			tagSet.add(tagId);
		});
		shop.setShopTagId(tagSet);
		//已有证件
		OfficeDic odp = new OfficeDic(id, TYPE_SHOP, REFERRER_PAPERS);
		Set<OfficeDic> paperOdic = officeDicMapper.selectDicByOffice(odp);
		Set<String> paperSet = new HashSet<String>();
		paperOdic.forEach(s -> {
			String paperId = s.getDValue();
			paperSet.add(paperId);
		});
		shop.setShopPaperId(paperSet);
		//新盘面积
		OfficeDic omj = new OfficeDic(id, TYPE_SHOP, NEW_ACREAGE);
		Set<OfficeDic> mjOmj = officeDicMapper.selectDicByOffice(omj);
		List<String> mjList = new ArrayList<String>();
		mjOmj.forEach(s -> {
			String mjId = s.getDValue();
			mjList.add(mjId);
		});
		shop.setShopMianJis(mjList);
		return shop;
	}
	
	@Override
	public int updateShopOnlineStatus(Shop shop) {
		return shopMapper.updateShopOnlineStatus(shop);
	}
	
	@Override
	public int updateTopStatus(Shop shop) {
		shopMapper.updateTopStatus(shop);
		return 1;
	}

	@Override
	public Integer savePaidianAll(Shop shop) {
		return shopMapper.savePaidianAll(shop);
	}

	@Override
	public int selectOnOfflineCount(String onlineStatus,String rentType) {
		return shopMapper.selectOnOfflineCount(onlineStatus,rentType);
	}
	
	@Override
	public List<Shop> selectShopListForPromote(Shop shop) {
		// TODO Auto-generated method stub
		return shopMapper.selectShopListForPromote(shop);
	}
	@Override
	public int updateShopPromote(Shop shop) {
		// TODO Auto-generated method stub
		shopMapper.updateShopPromote(shop);
		slideShowService.resetRedis(shop.getCityId()+"",null);
		return 1;
	}
	@Override
	public int updateShopSort(Shop shop){
		shopMapper.updateShopSort(shop);
		slideShowService.resetRedis(shop.getCityId()+"",null);
		return 1;
	}
	/**
	 * 商铺核实
	 * @param shop
	 * @param currId
	 */
	@Override
	@Transactional
	public int updateShopVerify(Shop shop,Long currId){
		updateShop(shop);
		if(shop.getShopVerify() == 2) {
			shop.setShopAudit(1);
		}
		shop.setVerifyAccountId(currId);
		shop.setVerifyTime(new Date());
		shopMapper.updateShop(shop);
		return shopMapper.updateShopAudit(shop);
	}
	/**
	 * 审核商铺认领
	 * @param shop	商铺
	 * @param currId 当前登录人ID
	 * @return 
	 */
	@Override
	public int updateShopClaimForAudit(Shop shop,Long currId) {
		shop.setClaimStatus(1);
		shop.setClaimAuditAccountId(currId);
		shop.setClaimAuditTime(new Date());
		//下个流程节点 初始化为：待审核
		shop.setShopAudit(FlowStatus.AUDIT_OF_WAIT);
		return shopMapper.updateShopClaimForAudit(shop);
	}
	/**
	 * 审核商铺批量认领
	 * @param shop	商铺
	 * @param currId 当前登录人ID
	 * @return 
	 */
	@Override
	public int updateShopClaimForAuditByBatch(Long[] ids,Long currId) {
		Map<String,Object> map = new HashMap<String,Object>();
		map.put("ids",ids);
		map.put("claimStatus", 1);
		map.put("claimAuditAccountId", currId);
		map.put("claimAuditTime", new Date());
		//下个流程节点 初始化为：待审核
		map.put("shopAudit", FlowStatus.AUDIT_OF_WAIT);
		return shopMapper.updateShopClaimForAuditByBatch(map);
	}
	/**
	 * 单个释放
	 */
	@Override
	public int releaseShop(Shop shop) {
		//只更新认领状态 不清空最近认领人、最近审核相关信息
		shop.setClaimStatus(0);
		return shopMapper.updateShopClaimForAudit(shop);
	}
	/**
	 * 批量释放
	 * 释放时只改变认领节点状态，不改变其他信息
	 */
	@Override
	public int releaseShopByBatch(Long[] ids,Long currId) {
		Map<String,Object> map = new HashMap<String,Object>();
		map.put("ids", ids);
		//只更新认领状态 不清空最近认领人、最近审核相关信息
		map.put("claimStatus", 0);
		return shopMapper.updateShopClaimForAuditByBatch(map);
	}
	/**
	 * 商铺审核
	 * @param shop
	 * @param currId
	 */
	@Override
//	@Transactional
	public int updateShopAudit(Shop shop,Long currId,String currName){
		updateShop(shop);
		if(shop.getShopAudit() == FlowStatus.AUDIT_OF_SUCESS) {
			shop.setOnlineStatus("1");
		}else {
			shop.setOnlineStatus("0");
		}
		shop.setAuditAccountId(currId);
		shop.setAuditTime(new Date());
		shopMapper.updateShopAudit(shop);
		//新增审核记录
		Audit audit = new Audit(shop.getId().toString(),currId.toString(),currName,
				shop.getShopAudit().toString(),shop.getInvalidReason());
		//保存联系人手机号、佣金修改 前后值
		if(shop.getCommissionValue() != null && shop.getCommissionValue().compareTo(shop.getCommissionValueOld()) != 0) {
			audit.setCommissionValueOld(shop.getCommissionValueOld());
		}
		if(shop.getPhone() != null && !shop.getPhone().equals(shop.getPhoneOld())) {
			audit.setPhoneOld(shop.getPhoneOld());
		}
		if(shop.getJiafangUserId() != shop.getJiafangOld()) {
			audit.setJiafangOld(shop.getJiafangOld());
		}
		if(shop.getJiedaiOld() != shop.getJiedaiUserId()) {
			audit.setJiedaiOld(shop.getJiedaiOld());
		}
		shopMapper.saveShopAudit(audit);
		//保存商铺附加字段
		shopMapper.deleteShopExtendByShopId(shop.getId());
		ShopExtend extned = new ShopExtend(shop.getId(),shop.getJiafangUserId(),shop.getJiedaiUserId());
		shopMapper.insertShopExtend(extned);
		//给房源发布人 发送消息提醒
		Shop s = shopMapper.selectByPrimaryKey(shop.getId());
		if(shop.getShopAudit() == FlowStatus.AUDIT_OF_SUCESS) {
			newService.sendSuccessMessage(s.getTitle(), s.getAgentId());
		}else {
			newService.sendFailMessage(s.getTitle(), s.getAgentId());
		}
		return 1;
	}
	
	@Override
	public List<Audit> findAuditList(String shopId) {
		return shopMapper.findAuditList(shopId);
	}
	
	
	
	@Override
	public int isShopNumber(String shopNumber) {
		// TODO Auto-generated method stub
		return shopMapper.isShopNumber(shopNumber);
	}	
	
	@SuppressWarnings("unchecked")
	@Override
	public synchronized String findNextShopNumber() {
		String shopNumber = redisService.getShopNumber();
		if (StringUtils.isBlank(shopNumber)) {
			shopNumber = shopMapper.selectMaxShopNum();
			if (StringUtils.isEmpty(shopNumber)) {
				return "030000";
			} else {
				DecimalFormat df = new DecimalFormat("000000");
				shopNumber = df.format(Long.valueOf(shopNumber) + 1);
				log.info("系统生成商铺编号:{}", shopNumber);
				System.out.println("系统生成商铺编号: "+shopNumber);
				return shopNumber;
			}
		}
		return shopNumber;
	}
	
}
