package com.up.mls.service.system.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.up.mls.mapper.system.CompanyMapper;
import com.up.mls.service.system.ICompanyService;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.system.Company;

@Service
public class CompanyServiceImpl implements ICompanyService {

	@Autowired
	CompanyMapper companyMapper;

	@Override
	public int insertCompany(Company company) {

		company.setCreateBy(SpringSecurityUtils.getUserId());
		company.setUpdateBy(SpringSecurityUtils.getUserId());
		company.setIsDel(false);
		company.setUpdateTime(new Date());
		company.setCreateTime(new Date());
		if (company.getParentId() == 1L) {
			company.setAncestors("0," + company.getParentId());
		}else {
			Company parentCompany = companyMapper.selectById(company.getParentId());
			company.setAncestors(parentCompany.getAncestors() + "," + company.getParentId());
		}
		return companyMapper.insertCompany(company);
	}

	@Override
	public int updateCompany(Company company) {
		company.setUpdateBy(SpringSecurityUtils.getUserId());
		company.setUpdateTime(new Date());
		Company parentCompany = companyMapper.selectById(company.getParentId());
		company.setAncestors(parentCompany.getAncestors() + "," + company.getParentId());
		return companyMapper.updateCompany(company);
	}

	@Override
	public List<Company> selectCompanyList(Company company) {
		return companyMapper.selectCompanyList(company);
	}

	@Override
	public Company selectCompanyById(Long companyId) {
		Company company = new Company();
		company.setId(companyId);
		return companyMapper.selectCompany(company);
	}

	@Override
	public int checkCompanyNameUnique(Company company) {
		Long companyId = Optional.ofNullable(company.getId()).orElse(-1L);
		Company info = companyMapper.checkCompanyKeyUnique(company.getCompanyName());
		return Optional.ofNullable(info).map(c -> {
			if (info.getId() == companyId)
				return 0;
			return 1;
		}).orElse(0);
	}

	@Override
	public int deleteCompanyById(Long companyId) {
		return companyMapper.deleteCompanyById(companyId);
	}

	@SuppressWarnings("serial")
	public List<Map<String, Object>> selectCompanyTree() {
		return companyMapper.selectAll().stream().map(c -> new HashMap<String, Object>() {
			{
				put("id", c.getId());
				put("pId", c.getParentId());
				put("name", c.getCompanyName());
				put("title", c.getCompanyName());
			}
		}).collect(Collectors.toList());
	}

	@Override
	public int countChildByCompanyId(Long companyId) {
		return companyMapper.countByCompanyId(companyId);
	}

	@Override
	public List<Company> findByVerifyCity(Company company) {
		// TODO Auto-generated method stub
		return companyMapper.findByVerifyCity(company);
	}

	@Override
	public List<Company> selectCityForCompany() {
		// TODO Auto-generated method stub
		return companyMapper.selectCityForCompany();
	}

	@Override
	public List<Map<String, Object>> selectCompany() {
		return companyMapper.selectCompanyTree();
	}
}
