package com.up.mls.service.user.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.up.mls.mapper.customer.CustomerMapper;
import com.up.mls.mapper.news.NewsMapper;
import com.up.mls.mapper.system.UserMapper;
import com.up.mls.mapper.user.AppUserMapper;
import com.up.mls.service.user.IAppUserService;
import com.up.mls.umeng.UmengUtils;
import com.up.mls.util.SpringSecurityUtils;
import com.up.mls.vo.app.TongJiEntity;
import com.up.mls.vo.news.News;
import com.up.mls.vo.news.NewsUser;
import com.up.mls.vo.result.ReferrerResult;
import com.up.mls.vo.system.User;
import com.up.mls.vo.user.AppUser;
import com.up.mls.vo.user.AppUserReferrer;
import com.up.mls.vo.user.Fenpei;
import com.up.mls.vo.user.Follow;

@Service
public class AppUserServiceImpl implements IAppUserService {
	private static final Logger logger = LoggerFactory.getLogger(AppUserServiceImpl.class);
    @Autowired
    private AppUserMapper appUserMapper;
    @Autowired
    private UserMapper  userMapper;
    @Autowired
    private CustomerMapper customerMapper;
    @Autowired
    private NewsMapper newsMapper;

    @Override
    public AppUser selectByPrimaryKey(String id) {
        return appUserMapper.selectByPrimaryKey(id);
    }

    @Override
    public List<AppUser> selectAllUserId() {
        Long userId = SpringSecurityUtils.getUserId();
        return appUserMapper.selectAllUserId(userId);
    }

    @Override
    public List<AppUser> findList(AppUser appUser) {
        return appUserMapper.findRenLinList(appUser);
    }
    

    @Override
    public AppUser findByPhone(String phone,String cityId) {
        // TODO Auto-generated method stub
        return appUserMapper.selectByPhone(phone,cityId);
    }

    @Override
    public int updatePvNum(AppUser appUser) {
        // TODO Auto-generated method stub
        return appUserMapper.updatePvNum(appUser);
    }

    @Override
    public List<AppUser> selectVipUserId() {
        return appUserMapper.selectVipUserId(SpringSecurityUtils.getUserId());
    }

    @Override
    public List<AppUser> selectNotVipUserId() {
        return appUserMapper.selectNotVipUserId(SpringSecurityUtils.getUserId());
    }

    @Override
    public List<AppUser> select(AppUser appUser) {
        appUser.setSelect(SpringSecurityUtils.getUserId());
        return appUserMapper.select(appUser);
    }
    
    /**
     * 查看本月发展人数
     * @param appUser
     * @return
     */
    @Override
    public List<AppUser> findByMonth(AppUser appUser) {
        return appUserMapper.findByMonth(appUser);
    }
    
    

    @Override
    public List<AppUser> selectYesterdayUser() {
        Long userId = SpringSecurityUtils.getUserId();
        return appUserMapper.selectYesterdayUser(userId);
    }

    @Override
    public List<Map<String, Object>> companyList(Map<String, Object> parameters) {
        return appUserMapper.companyList(parameters);
    }

    @Override
    public List<ReferrerResult> referrerList(AppUserReferrer appUserReferrer) {
        return appUserMapper.referrerList(appUserReferrer);
    }

	@Override
	public List<AppUser> selectAppUserForAgent(Integer type) {
		// TODO Auto-generated method stub
		return appUserMapper.selectAppUserForAgent(type);
	}

    @Override
    public List<Map<String, String>> selectAuditAccount() {
        return appUserMapper.selectAuditAccount();
    }
    @Override
    public List<AppUser> findUserTree(AppUser entity) {
        return appUserMapper.findUserTree(entity);
    }

    @Override
    public List<Follow> findFollowList(String rid) {
        return appUserMapper.findFollowList(rid);
    }
    
    @Override
    public List<Fenpei> findFenpeiList(String rid) {
        return appUserMapper.findFenpeiList(rid);
    }
    
    @Override
	public int saveRenlin(AppUser entity) {
		try {
			this.appUserMapper.saveRenlin(entity);
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
    

    @Override
	public int saveRenlinBatch(Map<String,Object> map) {
		try {
			this.appUserMapper.saveRenlinBatch(map);
		} catch (Exception e) {
			e.printStackTrace();
			return 0;
		}
		return 1;
	}
    
	
    @Override
    public void updateHuiFang(AppUser appUser){
    	this.appUserMapper.updateHuiFang(appUser);
    }
    
    
    @Override
   	public int saveFollow(Follow follow) {
   		try {
   			this.appUserMapper.saveFollow(follow);
   		} catch (Exception e) {
   			e.printStackTrace();
   			return 0;
   		}
   		return 1;
   	}
   	
    /**
     * 发房源总数  发客源总数  
	        主勾搭总数  被勾搭总数
     */
    @Override
    public TongJiEntity sumPublishFangYuanCount(String agentId){
    	TongJiEntity entity=this.appUserMapper.sumPublishFangYuanCount(agentId);
    	TongJiEntity  customEn=this.customerMapper.sumPublishFangYuanCount(agentId);
    	if(entity !=null && customEn!=null){
    		entity.setLastPublishKeYuan(customEn.getLastPublishKeYuan());
    		entity.setPublishKeYuanCount(customEn.getPublishKeYuanCount());
    	}
    	return entity;
    }
    
    /**
	 * 经纪人分配
	 * 保存批量分配
	 */
	@Override
	public int saveDistribution(String beiUserId,String ids,User loginUser,String userType) {
		Integer count = 0;
		try {
			//主-当前登录人
			User zhuUser=SpringSecurityUtils.getUser();
			//被-选中的人
			User  beiUser=this.userMapper.selectUserById(Long.valueOf(beiUserId));
			if(beiUser==null){
				logger.info("选中的人beiUserId="+beiUserId+"查无数据！");
				return count;
			}
			String[] str = ids.split(",");
			for(int i=0;i<str.length;i++) {
				//批量选中的多条数据
				String chooseId=str[i];
				AppUser dataItem = this.selectByPrimaryKey(chooseId);
				if(dataItem !=null){
					//1)更新app_user表renlinUserId
					AppUser paramUser=new AppUser();
					paramUser.setId(Long.valueOf(chooseId));
					paramUser.setRenlinTime(new Date());
					paramUser.setRenlinUserId(beiUser.getUserId().intValue());
					paramUser.setRenlinUserName(beiUser.getUserName());
					this.appUserMapper.saveRenlin(paramUser);
					
					//2)保存分配记录表
					Fenpei fpEntity=new Fenpei();
					fpEntity.setRid(chooseId);
					fpEntity.setBeiUserId(Integer.valueOf(beiUserId));
					fpEntity.setBeiUserName(beiUser.getUserName());
					fpEntity.setZhuUserId(zhuUser.getUserId().intValue());
					fpEntity.setZhuUserName(zhuUser.getUserName());
					this.appUserMapper.saveFenpei(fpEntity);
					count++;
				}
			}
			//发站内信
			Map<String,String> dyParam=new HashMap<String,String>();
			dyParam.put("employees", beiUser.getUserName());
			dyParam.put("leaderName", zhuUser.getUserName());
			dyParam.put("count", count+"");
			dyParam.put("createBy", zhuUser.getUserId()+"");
			if("3".equals(userType)){
				//经济公司-跟进
				this.sendNewsContent("13",zhuUser.getUserName(), beiUser.getPhonenumber(), beiUser.getUserName(),dyParam);
			}else{
				//经纪人-跟进
				this.sendNewsContent("12",zhuUser.getUserName(), beiUser.getPhonenumber(), beiUser.getUserName(),dyParam);
			}
		} catch (NumberFormatException e) {
			count=0;
			e.printStackTrace();
		}
		
		return count;
	}
	
	//发送分配任务提醒消息
	public void sendNewsContent(String touchType,String createUserName, String phone,String userName,Map<String,String> dyParam){
		try {
			//根据手机号查询是否在前台注册过：user_app
			AppUser  au=this.appUserMapper.selectByPhone(phone, null);
			if(au !=null){
				News entity=this.newsMapper.findEntityByTouchType(touchType);
				if(entity !=null && StringUtils.isNotBlank(entity.getContent())){
					String content=entity.getContent();
					if(content.contains("${employees}")){
						content=content.replace("${employees}", dyParam.get("employees")==null?"张三":dyParam.get("employees"));
					}
					if(content.contains("${leaderName}")){
						content=content.replace("${leaderName}", dyParam.get("leaderName")==null?"李四":dyParam.get("leaderName"));
					}
					if(content.contains("${count}")){
						content=content.replace("${count}", dyParam.get("count")==null?"1":dyParam.get("count"));
					}
					NewsUser newsUser=new NewsUser();
					newsUser.setTitle(entity.getTitle());
					newsUser.setContent(content);
					newsUser.setUserId(au.getId().intValue());
					newsUser.setUserName(userName);
					newsUser.setCreateBy(Long.valueOf(dyParam.get("createBy")));
					newsUser.setIfSee("1");
					newsUser.setStatus("1");
					newsUser.setTypes("2");
					newsUser.setCreateName(createUserName);
					this.newsMapper.sendTouchMsg(newsUser);
					
					//友盟推送
					UmengUtils umengUtils=new UmengUtils();
					List<Integer> uList=new ArrayList<Integer>();
					uList.add(au.getId().intValue());
					umengUtils.sendIOSGroupcast(newsUser.getTitle(), content, "1", null, uList);
					umengUtils.sendAndroidGroupcast(newsUser.getTitle(), content, uList, "1", null);
				}
			}else{
				logger.info("【警告：发送站内信失败，手机号（"+phone+"）在前台没注册过发不出去！】");
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	
    
}
