/**
 * 
 */
package com.up.mls.util;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import com.up.mls.support.Convert;

/**
 * @author Administrator
 *
 */
public class ServletUtils {
	private static final Logger logger = LogManager.getLogger(ServletUtils.class);

	public static final String DEFAULT_COOKIE_PATH = "/";
	public static final int DEFAULT_COOKIE_MAXAGE = 60 * 60 * 24 * 365;// 单位为秒

	/**
	 * 
	 * @param request
	 * @return
	 */
	public static String getBaseURL(HttpServletRequest request) {
		StringBuffer baseURL = new StringBuffer("");
		baseURL.append(request.getScheme()).append("://").append(request.getServerName());
		int port = request.getServerPort();
		if (port != 80) {
			baseURL.append(":").append(request.getServerPort());
		}
		baseURL.append(request.getContextPath()).append("/");
		return baseURL.toString();
	}

	/**
	 * 获得当前访问的完整URL
	 * 
	 * @param request
	 * @return
	 */
	public static String getCurrentURL(HttpServletRequest request) {
		StringBuffer url = request.getRequestURL();
		String queryString = request.getQueryString();
		if (queryString != null) {
			url.append("?" + queryString);
		}
		return url.toString();
	}

	/**
	 * 获得访问者的IP
	 * 
	 * @param request
	 * @return
	 * @throws Exception
	 */
	public static String getIpAddress(HttpServletRequest request) {
		try {
			String ipString = request.getHeader("x-forwarded-for");
			if (StringUtils.isBlank(ipString) || "unknown".equalsIgnoreCase(ipString)) {
				ipString = request.getHeader("Proxy-Client-IP");
			}
			if (StringUtils.isBlank(ipString) || "unknown".equalsIgnoreCase(ipString)) {
				ipString = request.getHeader("WL-Proxy-Client-IP");
			}
			if (StringUtils.isBlank(ipString) || "unknown".equalsIgnoreCase(ipString)) {
				ipString = request.getRemoteAddr();
			}
			// 多个路由时，取第一个非unknown的ip
			String[] arr = ipString.split(",");
			for (String str : arr) {
				if (!"unknown".equalsIgnoreCase(str)) {
					ipString = str;
					break;
				}
			}
			if (isIp(ipString)) {
				return ipString;
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return "";
	}

	/**
	 * 判断是否是一个IP
	 * 
	 * @param ip
	 * @return
	 */
	public static boolean isIp(String ip) {
		boolean b = false;
		ip = StringUtils.trim(ip);
		if (ip.matches("\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}")) {
			String s[] = ip.split("\\.");
			if (Integer.parseInt(s[0]) < 255)
				if (Integer.parseInt(s[1]) < 255)
					if (Integer.parseInt(s[2]) < 255)
						if (Integer.parseInt(s[3]) < 255)
							b = true;
		}
		return b;
	}

	public static void addCookie(String name, String value, HttpServletResponse response) {
		addCookie(name, value, DEFAULT_COOKIE_PATH, DEFAULT_COOKIE_MAXAGE, response);
	}

	public static void addCookie(String name, String value, Integer maxAge, HttpServletResponse response) {
		addCookie(name, value, DEFAULT_COOKIE_PATH, maxAge, response);
	}

	public static void addCookie(String name, String value, String path, Integer maxAge, HttpServletResponse response) {
		Cookie cookie = new Cookie(name, value);
		cookie.setPath(path);
		if (maxAge != null) {
			cookie.setMaxAge(maxAge);
		}
		response.addCookie(cookie);
	}

	public static void removeCookie(String name, HttpServletResponse response) {
		Cookie cookie = new Cookie(name, null);
		cookie.setPath(DEFAULT_COOKIE_PATH);
		cookie.setMaxAge(0);
		response.addCookie(cookie);
	}

	public static void removeCookie(String name, String path, HttpServletResponse response) {
		Cookie cookie = new Cookie(name, null);
		cookie.setPath(path);
		cookie.setMaxAge(0);
		response.addCookie(cookie);
	}

	public static Cookie getCookieByName(String name, HttpServletRequest request) {
		return getCookies(request).get(name);
	}

	public static Map<String, Cookie> getCookies(HttpServletRequest request) {
		Map<String, Cookie> cookieMap = new HashMap<String, Cookie>();
		Cookie[] cookies = request.getCookies();
		if (null != cookies) {
			for (Cookie cookie : cookies) {
				cookieMap.put(cookie.getName(), cookie);
			}
		}
		return cookieMap;
	}

	public static String getCookieValueByName(String name, HttpServletRequest request) {
		return getCookieValues(request).get(name);
	}

	public static Map<String, String> getCookieValues(HttpServletRequest request) {
		Map<String, String> cookieMap = new HashMap<String, String>();
		Cookie[] cookies = request.getCookies();
		if (null != cookies) {
			for (Cookie cookie : cookies) {
				cookieMap.put(cookie.getName(), cookie.getValue());
			}
		}
		return cookieMap;
	}

	/**
	 * 判断是否为微信访问
	 * 
	 * @param request
	 * @return
	 */
	public static boolean isWeiXin(HttpServletRequest request) {
		String ua = request.getHeader("user-agent").toLowerCase();
		if (ua.indexOf("micromessenger") > 0) {// 是微信浏览器
			return true;
		} else {
			return false;
		}
	}

	/**
	 * 判断是否是手机访问
	 * 
	 * @param request
	 * @return
	 */
	public static boolean isMobile(HttpServletRequest request) {
		String userAgent = request.getHeader("user-agent").toLowerCase();
		if (null == userAgent) {
			userAgent = "";
		}
		String phoneReg = "\\b(ip(hone|od)|android|opera m(ob|in)i" + "|windows (phone|ce)|blackberry"
				+ "|s(ymbian|eries60|amsung)|p(laybook|alm|rofile/midp" + "|laystation portable)|nokia|fennec|htc[-_]"
				+ "|mobile|up.browser|[1-4][0-9]{2}x[1-4][0-9]{2})\\b";
		String tableReg = "\\b(ipad|tablet|(Nexus 7)|up.browser" + "|[1-4][0-9]{2}x[1-4][0-9]{2})\\b";

		// 移动设备正则匹配：手机端、平板
		Pattern phonePat = Pattern.compile(phoneReg, Pattern.CASE_INSENSITIVE);
		Pattern tablePat = Pattern.compile(tableReg, Pattern.CASE_INSENSITIVE);
		// 匹配
		Matcher matcherPhone = phonePat.matcher(userAgent);
		Matcher matcherTable = tablePat.matcher(userAgent);
		if (matcherPhone.find() || matcherTable.find()) {
			return true;
		} else {
			return false;
		}
	}

	public static void printWriter(HttpServletResponse response, String result) {
		response.setCharacterEncoding("UTF-8");
		response.setContentType("application/json; charset=utf-8");
		PrintWriter out = null;
		try {
			out = response.getWriter();
			out.append(result);
		} catch (IOException e) {
			logger.error(e.getMessage(), e);
		} finally {
			if (out != null) {
				out.close();
			}
		}
	}

	/**
	 * 获取String参数
	 */
	public static String getParameter(String name) {
		return getRequest().getParameter(name);
	}

	/**
	 * 获取String参数
	 */
	public static String getParameter(String name, String defaultValue) {
		return Convert.toStr(getRequest().getParameter(name), defaultValue);
	}

	/**
	 * 获取Integer参数
	 */
	public static Integer getParameterToInt(String name) {
		return Convert.toInt(getRequest().getParameter(name));
	}

	/**
	 * 获取Integer参数
	 */
	public static Integer getParameterToInt(String name, Integer defaultValue) {
		return Convert.toInt(getRequest().getParameter(name), defaultValue);
	}

	/**
	 * 获取request
	 */
	public static HttpServletRequest getRequest() {
		return getRequestAttributes().getRequest();
	}

	/**
	 * 获取response
	 */
	public static HttpServletResponse getResponse() {
		return getRequestAttributes().getResponse();
	}

	/**
	 * 获取session
	 */
	public static HttpSession getSession() {
		return getRequest().getSession();
	}

	public static ServletRequestAttributes getRequestAttributes() {
		RequestAttributes attributes = RequestContextHolder.getRequestAttributes();
		return (ServletRequestAttributes) attributes;
	}


	/**
	 * 是否是Ajax异步请求
	 * 
	 * @param request
	 */
	public static boolean isAjaxRequest(HttpServletRequest request) {

		String accept = request.getHeader("accept");
		if (accept != null && accept.indexOf("application/json") != -1) {
			return true;
		}

		String xRequestedWith = request.getHeader("X-Requested-With");
		if (xRequestedWith != null && xRequestedWith.indexOf("XMLHttpRequest") != -1) {
			return true;
		}

		String uri = request.getRequestURI();
		if (StringUtils.inStringIgnoreCase(uri, ".json", ".xml")) {
			return true;
		}

		String ajax = request.getParameter("__ajax");
		if (StringUtils.inStringIgnoreCase(ajax, "json", "xml")) {
			return true;
		}

		return false;
	}

	public static Map<String, Object> getParameters (HttpServletRequest request) {
		logger.info("【==========请求全路径是："+request.getRequestURL()+"?"+request.getQueryString()+"】");
		Map<String, Object> parameters = new HashMap<String, Object>();
		try {
			Enumeration<String> names = request.getParameterNames();
			String name = null;
			while (names.hasMoreElements()) {
				name = names.nextElement();
				if(org.apache.commons.lang.StringUtils.isNotBlank(org.apache.commons.lang.StringUtils.trim(request.getParameter(name))))
					parameters.put(name, request.getParameter(name));
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return parameters;
	}


}
