package com.up.mls.util;


import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.Random;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;


/**
 * 
 * @author lcf
 * @date 2015-4-15
 * @description
 * WebService动态客户端
 * address :服务器访问地址类似与http://localhost:8080/Service/ServiceHello?wsdl
 * methodName ：类里面的某个方法名，类似与getValue();
 * params：类的方法参数，类似与[name]
 * clientFolderName:客户端存放生成class的文件夹com.coc.utils
 */
public class WebServiceUtils {

	//添加Https WebService支持
	public static String request(String address,String methodName,Object[] params,String clientFolderName){
		
		/*if(address.indexOf("?wsdl") == -1){
			address += "?wsdl";
		}*/
		String target = "F:\\09_up_mls\\up-bmls\\up-bmls\\up-bmls-admin\\src";
		try {
			URL url = new URL(address);
			Document wsdl = new SAXReader().read(url);
			Element service = wsdl.getRootElement().element("service");//获得xml里面的service节点如：<service name="ServiceHelloService">
			String serviceName = service.attributeValue("name");//
			//同名服务覆盖问题待处理
			String pkg = clientFolderName !=null ? clientFolderName: "gust.client" + new Random().nextInt();//pkg是客户端保存生成后类的包名
			String portName = service.element("port").attributeValue("name");//得到服务名 ：ServiceHelloService
			File fle = new File(target);
			ClassLoader classloader = new URLClassLoader(new URL[]{fle.toURL()});//1)Classloader 类加载器，用来加载 Java 类到 Java 虚拟机中
			Class serviceClass = null;
			try{
				serviceClass = classloader.loadClass(pkg + "." + serviceName);//2)使用第一步得到的ClassLoader来载入B(serviceName)类 
			}catch(ClassNotFoundException e){
				//生成客户端
				//例如： wsimport -s E:\\WorkSpace\\TheClient\\src -p com.coc.test - keep http://localhost:8080/Service/ServiceHello?wsdl
				Process process = Runtime.getRuntime().exec("wsimport -keep -d " + target + " -p " + pkg + " " + address);
				BufferedReader br = new BufferedReader(new InputStreamReader(process.getInputStream()));
				String line = null;
				while((line = br.readLine()) != null){
					System.out.println(line);
				}
				serviceClass = classloader.loadClass(pkg + "." + serviceName);//反射得到ServiceHelloService.class
			}
			Object obj = serviceClass.newInstance();//3)有Object的类得到一个Object的实例
			Method getPort;
			try{
				getPort = serviceClass.getMethod(portName);//得到ServiceHelloService类的getServiceHello()方法
			}catch(NoSuchMethodException e){
				getPort = serviceClass.getMethod(portName.substring(0,1).toUpperCase() + portName.substring(1));//转大写
			}
			/**
			代理服务器（Proxy Server），在开放系统互联(OSI)模型的会话层，起到防火墙的作用
			*/
			Proxy proxy = (Proxy) getPort.invoke(obj);
			InvocationHandler handler = Proxy.getInvocationHandler(proxy);
			Class cls = getPort.getReturnType();//获得的是class类对象
			Class[] paramsClass = new Class[params.length];
			for (int i = 0; i < params.length; i++) {
				paramsClass[i] = params[i].getClass();
			}
			try {
				Method method = cls.getMethod(methodName,paramsClass);//获取当前类所有的方法名称和参数
				Object rtn = handler.invoke(proxy, method, params);
				return rtn.toString();
			} catch (NoSuchMethodException e) {
				/**
				 * 生成的对象与原对象包名不同，导致找不到
				 * 这时需要复制所有值到新的对象中，而自定义的枚举类型需要特殊处理
				 */
				Class[] desClass = new Class[paramsClass.length];
				Object[] desObjs = new Object[paramsClass.length];
				for (int i = 0; i < paramsClass.length; i++) {
					Class source = paramsClass[i];
					String name = source.getSimpleName();
					Class des = classloader.loadClass(pkg + "." + name);
					Object desObj;
					if(des.isEnum()){
						try {
							desObj = Enum.valueOf(des, ((Enum)params[i]).name());
						} catch (IllegalArgumentException e2) {
							Method fromValue = des.getMethod("fromValue",new Class[]{String.class});
							desObj = fromValue.invoke(des, ((Enum)params[i]).name());
						}
					}else{
						desObj = des.newInstance();
						Field[] fields = source.getDeclaredFields();
						for (int j = 0; j < fields.length; j++) {
							Field sourceField = fields[j];
							sourceField.setAccessible(true);
							String sourceName = sourceField.getName();
							Field desField = des.getDeclaredField(sourceName);
							desField.setAccessible(true);
							desField.set(desObj, sourceField.get(params[i]));
						}
					}
					desClass[i] = des;
					desObjs[i] = desObj;
				}
				Method method = cls.getMethod(methodName,desClass);
				Object rtn = handler.invoke(proxy, method, desObjs);
				return rtn.toString();
			}
		} catch (org.dom4j.DocumentException e) {
			return "disconnect";
		} catch (Exception e) {
			e.printStackTrace();
		} catch (Throwable e) {
			e.printStackTrace();
		}
		
		return "";
	}
}
