package com.up.mls.vo.office;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Set;
import java.util.stream.Stream;

import org.springframework.util.StringUtils;

import com.google.common.collect.Lists;
import com.up.mls.vo.BaseDomain;
import com.up.mls.vo.shop.BusinessArea;
import com.up.mls.vo.system.Areas;
import com.up.mls.vo.system.Road;
import com.up.mls.vo.user.AppUser;

import lombok.Getter;
import lombok.Setter;


/**
 * 写字楼
 * 写字楼出租、写字楼出售、新盘写字楼出租、新盘写字楼出售
 * @author joker
 *
 */

@Getter
@Setter
public class Office extends BaseDomain {

	private static final long serialVersionUID = 3586785706053144731L;
	
//	↓↓↓↓↓↓↓ 基础属性 ↓↓↓↓↓↓↓
	/**
	 * 写字楼类型
	 */
	private String type;
	/**
	 * 单价（二手出售）
	 */
	private BigDecimal unitPrice=new BigDecimal(0.00);
	/**
	 * 均价（新盘）
	 */
	private BigDecimal avePrice=new BigDecimal(0.00);
	/**
	 * 日租金（2位小数,元/天/㎡）（出租）
	 */
	private BigDecimal dailyRent=new BigDecimal(0.00);
	
	/**
	 * 建筑面积
	 */
	private BigDecimal buildArea=new BigDecimal(0.00);
	
	private String singleFamily;
	/**
	 * 总楼层
	 */
	private String floorTotal;
	/**
	 * 所在楼层
	 */
	private String floorCurrent;
	/**
	 * 层高
	 */
	private String shopHeight;
	/**
	 * 工位数1
	 */
	private int station1;
	/**
	 * 工位数2
	 */
	private int station2;
	/**
	 * 层高
	 */
	private BigDecimal floorHeight;
	/**
	 * 物业费
	 */
	private BigDecimal feeProperty;
	/**
	 * 装修情况
	 */
	private String decorate;
	/**
	 * 是否可注册
	 */
	private String register;
	/**
	 * 是否可分割
	 */
	private String separate;
	/**
	 * 配套
	 */
	private Set<String> shopSupportingsId;

	private Set<String> shopTagId;
	
	private Set<String> shopPaperId;
	/**
	 * 日租金（2位小数,元/天/㎡）
	 */
	public String getDailyRentText() {
		return dailyRent + "元/天/㎡";
	}

	/**
	 * 月租金（2位小数,元/月）
	 */
	private BigDecimal monthlyRent;

	/**
	 * 支付方式
	 */
	private String payMethod;
	
	/**
	 * 商铺租售状态（0：租赁中，1：已成交，2：已租出一部分，3：停转/租-违建拆除，4：停转/租-房东收回，5：停转/租-被查封，6：停转/租-继续经营）
	 */
	private Integer status;
	/**
	 * x坐标
	 */
	private String positionX;

	/**
	 * y坐标
	 */
	private String positionY;
	/**
	 * 物业费
	 */
	private Double propertyFee;
	/**
	 * 电费
	 */
	private Double electricityFee;
	/**
	 * 水费
	 */
	private Double waterFee;
	
	/**
	 * 房源描述
	 */
	private String introduce;
	
	/**
	 * 简介
	 */
	private String profile;
	 /**
	  * 周边配套
	  */
	private String supportProfile;
	/**
	 * 联系人
	 */
	private String linkman;
	/**
	 * 电话
	 */
	private String phone;
//	↑↑↑↑↑↑↑↑  基础属性  ↑↑↑↑↑↑↑↑
//	↓↓↓↓↓↓↓ 楼盘属性 ↓↓↓↓↓↓↓
	/**
	 * 楼盘名称
	 */
	private String name;
	/**
	 * 开发商
	 */
	private String developer;
	/**
	 * 开盘时间
	 */
	private Date openTime;
	
//	↑↑↑↑↑↑↑↑  楼盘属性  ↑↑↑↑↑↑↑↑
//	↓↓↓↓↓↓↓ 相关图片属性 ↓↓↓↓↓↓↓
	/**
	 * 证件照片
	 */
	private String imgPaper;
	/**
	 * 委托书证件照
	 */
	private String entrustPaper;
	/**
	 * 封面图
	 */
	private String coverImg;
	/**
	 * 写字楼图片
	 */
	private String imgs;
	/**
	 * 写字楼位置图片
	 */
	private String siteImgs;
	/**
	 * 写字楼平面图片
	 */
	private String planeImgs;
	
//	↑↑↑↑↑↑↑↑  相关图片属性  ↑↑↑↑↑↑↑↑	
//	↓↓↓↓↓↓↓ 位置相关属性 ↓↓↓↓↓↓↓
	private Long cityAreaId;
	/**
	 * 城市
	 */
	private Long cityId;
	/**
	 * 区域
	 */
	private Long areaId;
	private Areas area;
	/**
	 * 道路
	 */
	private Long roadId;
	private Road road;
	/**
	 * 商圈
	 */
	private Long businessAreaId;
	private BusinessArea businessArea;
	/**
	 * 详细地址
	 */
	private String realAddress;
//	↑↑↑↑↑↑↑↑  位置相关属性  ↑↑↑↑↑↑↑↑
//	↓↓↓↓↓↓↓ 经纪人相关属性 ↓↓↓↓↓↓↓
	/**
	 * 经济人
	 */
	private Long agentId;
	private AppUser agent;
	/**
	 * 分配经济人时间
	 */
	private Date distTime;
	/**
	 * 分配状态（0：未分配 1：已分配）
	 */
	private int distStatus;
	/**
	 * 合作佣金
	 */
	private String commission;
	
	private BigDecimal commissionValue=new BigDecimal(0.00);
	//佣金类型：1-百分比 2-直接填金额
	private String commissionType;
	/**
	 * 结佣时间（天数）
	 */
	private int expired;
	
	private Integer sort;
	
	private String title;
	private String titleSub;
	private String titlePc;
	private String titlePcSub;
	private String regionName;
	
//	↑↑↑↑↑↑↑↑  经纪人相关属性  ↑↑↑↑↑↑↑↑	
//	↓↓↓↓↓↓↓ 后台操作相关属性 ↓↓↓↓↓↓↓
	private String ifIndex;
	
	/**
	 * 写字楼所属类别(0:新盘出租、1:新盘出售、2:二手出租、3:二手出售)
	 */
	private String rentType;

	/**
	 * 上架状态（0 下架 1 上架）
	 */
	private String onlineStatus;
	/**
	 * 平台服务费
	 */
	private BigDecimal feeService;
	/**
	 * 核实
	 */
	private Integer officeVerify;
	
	private Date verifyTime;
	
	private Long verifyAccountId;
	/**
	 * 写字楼审核状态
	 */
	private Integer auditUserId;
	private Integer auditStatus;
	private String auditUserName;
	private Date auditTime;
	private String auditReasion;//非持久化字段
	private String auditRemark;//数据字段
	//认领人
	private Integer renlinUserId;
	private Integer renlinStatus=1;
	private String renlinUserName;
	private Date renlinTime;
	
//	↑↑↑↑↑↑↑↑  后台操作相关属性  ↑↑↑↑↑↑↑↑
	
	
	/**
	 * 前台委托书
	 */
	private String[] entrustPaperArray;

	/**
	 * 前台展示位置图
	 */
	private String[] siteImgsArray;


	/**
	 * 前台展示位置图
	 */
	public String[] getSiteImgsArray() {
		if (StringUtils.isEmpty(siteImgs)) {
			return null;
		} else {
			return siteImgs.split(",");
		}
	}

	/**
	 * 后台展示图片
	 */
	public String[] getPlaneImgArray() {
		if (StringUtils.isEmpty(planeImgs)) {
			return null;
		} else {
			return planeImgs.split(",");
		}
	}
	/**
	 * 后台展示平面图片
	 */
	public String[] getImgArray() {
		if (StringUtils.isEmpty(imgs)) {
			return null;
		} else {
			return imgs.split(",");
		}
	}
	/**
	 * 后台展示委托证书图片
	 */
	public String[] getEntrustPaperArray() {
		if (StringUtils.isEmpty(entrustPaper)) {
			return null;
		} else {
			return entrustPaper.split(",");
		}
	}

	public void setEntrustPaperArray() {
		if (!StringUtils.isEmpty(entrustPaper))
			this.entrustPaperArray = entrustPaper.split(",");
	}

	/**
	 * 前天展示图片
	 * 
	 * @return
	 */
	public String[] getImgStyleArray() {
		if (StringUtils.isEmpty(imgs)) {
			return null;
		} else {
			List<String> list = Lists.newArrayList();
			Stream.of(imgs.split(",")).forEach(s -> {
				if (s.contains("aliyuncs")) {
					s = s.replace("up-img.oss-cn-beijing.aliyuncs.com", "cdn.youpuchina.com");
					if (!s.contains("x-oss-process")) {
						s += "?x-oss-process=style/watermark";
					}
				}
				list.add(s);
			});
			return list.toArray(new String[] {});
		}
	}

	
	private Long shopRoadObstructsId;

	
	

	


//	↓↓↓↓↓↓↓ 暂未使用字段 ↓↓↓↓↓↓↓
	/**
	 * 编号
	 */
	private String officeNumber;
	/**
	 * 封面图
	 */
	private String cover;
	/**
	 * 链接地址
	 */
	private String keyUrl;

	/**
	 * 链接地址MD5值
	 */
	private String keyUrlMd5;

	/**
	 * 爬虫时间
	 */
	private Date crawlerDate;

	private String areaName;
	
	private String invalidReason;

	/**
	 * 爬虫数据商铺编号(乐铺)
	 */
	private String crawlerShopNumber;
	
	
	
	
	/**
	 * 置顶结束时间
	 */
	private Date topEndTime; 
	
	/**
	 * 复核状态
	 * 0：待复核 1：复核中 2：已复核
	 */
	private Integer checkStatus;
	
	private Integer checkNums;	//已复核次数
	
//	@Transient
	private Long times;	//被查看次数
	
	/**
	 * 是否在发布列表展示标识 0 不展示 1 展示
	 */
	private Integer showFlag;
	private  Long shopTypeId;
	private Date onlineTime;
	private String channel;
	private Date topBeginTime; 
	private String topStatus;

	
	
	
	
	
	
	public Office() {

	}
	public Office(String officeNumber) {
		this.officeNumber = officeNumber;
	}
	

	//传参参数
	private String provinceId;
	private Integer buildArea0;
	private Integer buildArea1;
	private BigDecimal monthlyRent0;
	private BigDecimal monthlyRent1;
	private String labe;
	private String userId;
	
	
	//扩展表里的字段 start
	private Integer  jiafangUserId;
	private String jiafangUserName;
	private Integer jiedaiUserId;
	private String jiedaiUserName;
	private Long weihuUserId;
	private String weihuUserName;
	//扩展表里的字段 end
	
	
	//查询优化
	private int isQuery;
	//审核次数
	private String shCount;
	
	//非持久化字段
	private String renlinType;
	private String agentType;
	private String dateType;
	private String beginTime;
	private String endTime;
	private String agentName;
	private String agentPhone;
	private int listType;
	
}
