package com.up.mls.vo.shop;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Stream;

import org.springframework.util.StringUtils;

import com.google.common.collect.Lists;
import com.up.mls.vo.BaseDomain;
import com.up.mls.vo.system.Areas;
import com.up.mls.vo.system.User;
import com.up.mls.vo.user.AppUser;

import lombok.Getter;
import lombok.Setter;


/**
 * 商铺
 *
 * @author joker
 *
 */

@Getter
@Setter
public class Shop extends BaseDomain {

	private static final long serialVersionUID = 3586785706053144731L;

	public Shop() {}

	public Shop(String shopNumbmer) {
		this.shopNumber = shopNumbmer;
	}
	
	//城市
	private Long cityId;
	//区域
	private Long areaId;
	private Areas area;
	//商圈
	private Long businessAreaId;
	private BusinessArea businessArea;

	/**
	 * 详细地址
	 */
	private String realAddress;
	
	/**
	 * 商铺类型
	 */
	private String type;

	/**
	 * 建筑面积
	 */
	private BigDecimal buildArea;

	/**
	 * 使用面积
	 */
	private BigDecimal useArea;
	/**
	 * 当前经营/经营业态（一级）
	 */
	private Long parentManageTypeId;
	
	/**
	 * 当前经营/经营业态（二级）
	 */
	private Long sonManageTypeId;
	/**
	 * 新盘适合业态
	 */
	private ShopBusinessType shopBusinessType;
	/**
	 * 配套
	 */
	private Set<String> shopSupportingsId;
	/**
	 * 楼层 一层、二层、三层、四层、高层、半地下
	 */
	private Boolean floor1;
	private Boolean floor2;
	private Boolean floor3;
	private Boolean floor4;
	private Boolean floorHigh;
	private Boolean floorUnder;
	/**
	 * 商铺状态（0：营业中，1:空铺）
	 */
	private Integer manageStatus;
	/**
	 * 是否临街(false 否；true 是)
	 */
	private Boolean frontage;
	/**
	 * 层高
	 */
	private BigDecimal floorHeight;
	private Double shopHeight;
	/**
	 * 面宽
	 */
	private BigDecimal faceWidth;
	/**
	 * 进深
	 */
	private BigDecimal depth;
	/**
	 * 日租金（2位小数,元/天/㎡）
	 */
	private BigDecimal dailyRent;

	public String getDailyRentText() {
		if (dailyRent == null) {
			return null;
		} else if (dailyRent.intValue() == -2) {
			return "面议";
		} else {
			return monthlyRent + "元/天/㎡";
		}
	}
	/**
	 * 押金
	 */
	private Integer pledgeMethod; //0:个月  1：元 2 : 无
	 
	private String pledgeInfo;
	/*
	 * 单价（销售类-二手）
	 */
	private BigDecimal unitPrice;
	private BigDecimal price;
	/**
	 * 均价（销售类-新盘）
	 */
	private BigDecimal avePrice;
	private BigDecimal shopAverage;
	/**
	 * 转让费（1位小数,万元）
	 */
	private BigDecimal transferFee;

	public String getTransferFeeText() {
		if (transferFee == null) {
			return null;
		} else if (transferFee.intValue() == -1) {
			return "无";
		} else if (transferFee.intValue() == -2) {
			return "面议";
		} else {
			return transferFee + "万元";
		}
	}
	/**
	 * 支付方式
	 */
	private String payMethod;
	/**
	 * 商铺出售
	 */
	//物业费
	private Double propertyFee;
	//电费
	private Double electricityFee;
	//水费
	private Double waterFee;
	
	/**
	 * 商铺标签
	 */
	private Set<String> shopTagId;
	/**
	 * 证照（0：不可办照，1：可办照，2：公司照可过户，3：有照可增项，4：大照/集体照，5：个人照可用，6：公司照可用，7：个人照可过户）
	 */
	private Integer license;
	/**
	 * 已有证件
	 */
	private Set<String> shopPaperId;
	/**
	 * 商铺简介
	 */
	private String introduce;
	/**
	 * 周边配套
	 */
	private String supportProfile;
	/**
	 * 选择商铺图片
	 */
	private String imgs;
	/**
	 * 封面图
	 */
	private String cover;
	/**
	 * 合作佣金
	 */
	private String commissionType;
	private String commission;
	private BigDecimal commissionValue;
	/**
	 * 结佣时间（天数）
	 */
	private int expired;
	/**
	 * 联系人
	 */
	private String linkman;
	/**
	 * 电话
	 */
	private String phone;
	/**
	 * 委托书证件照
	 */
	private String entrustPaper;
	private String entrustImg;
	
	/**
	 * 关联office_dic  复选商铺面积 插入字段   新盘面积
	 */
	private List<String> shopMianJis;
	
	
	
	
	
	
	
	/**
	 * 编号
	 */
	private String shopNumber;
	/**
	 * 名称
	 */
	private String name;
	

	/**
	 * 年租金（整数,万元）
	 */
	private BigDecimal yearlyRent;

	public String getYearlyRentText() {
		if(Objects.nonNull(yearlyRent) && !Objects.equals(yearlyRent.intValue(), -2)) {
			yearlyRent = yearlyRent.setScale(0,BigDecimal.ROUND_HALF_UP);
		}
		if (yearlyRent == null) {
			return null;
		} else if (yearlyRent.intValue() == -2) {
			return "面议";
		} else {
			return yearlyRent + "万元/年";
		}
	}

	/**
	 * 月租金（2位小数,元/月）
	 */
	private BigDecimal monthlyRent;

	public String getMonthlyRentText() {
		if(Objects.nonNull(monthlyRent) && !Objects.equals(monthlyRent.intValue(), -2)) {
			monthlyRent = monthlyRent.setScale(0,BigDecimal.ROUND_HALF_UP);
		}
		if (monthlyRent == null) {
			return null;
		} else if (monthlyRent.intValue() == -2) {
			return "面议";
		} else {
			return monthlyRent + "元/月";
		}
	}
	
	
	/**
	 * 商铺租售状态（0：租赁中，1：已成交，2：已租出一部分，3：停转/租-违建拆除，4：停转/租-房东收回，5：停转/租-被查封，6：停转/租-继续经营）
	 */
//	private Integer status;
	/**
	 * 租售类型销售类别（1:出租 2:出售 3:新盘出租 4-新盘出售）
	 */
	private String rentType;
	
	/**
	 * 是否分隔(false 否；true 是)
	 */
	private Boolean separate;
	
	
	
	
	
	/**
	 * 店名
	 */
	private String shopName;
	
//	private Set<String> shopAdvantageId;
	
	
	/**
	 * 证件照
	 */
	private String paperImgs;
	
	private String shopFlow;

//	private Set<String> shopIssueId;	
	/**
	 * 楼盘名称(销售类)
	 */
	private String proName;
	private String floorName;
	/**
	 * 开发商(销售类)
	 */
	private String openWorker;
	private Date   openTime;
	
	private Long sonShopBisTypeId;
	

	/**
	 * x坐标
	 */
	private String positionX;

	/**
	 * y坐标
	 */
	private String positionY;

	//道路阻隔
//	private Long shopRoadObstructsId;

	
	
	/**
	 * 营业额分成
	 */
//	private String turnoverShare;
	
//	private String submitStatus;
	/**
	 * 上架状态（0 下架 1 上架）
	 */
	private String onlineStatus;
	/**
	 * 商铺来源 (0:经纪人发布, 1：安居客, 2：五八同城,)
	 */
	private String createType;
	/**
	 * 商铺渠道(android,ios,pc)
	 */
	private String channel;
	
	//推荐首页
	private String ifIndex;
	
	
	//商铺简介
	private String shopProfile;
	
	
	
	//保存旧值 传值用
	private BigDecimal commissionValueOld; 
	private String phoneOld;

	private String userName;

	
	/**
	 * 平台服务费
	 */
	private String feeService;
	/**
	 * 排序
	 */
	private Integer sort;
	
	//经纪人ID
	private Long agentId;
	private AppUser agent;
	
	
	/**
	 * 位置图
	 */
	private String positionImg;
	
	/**
	 * 平面图
	 */
	private String planeImg;

	private String title;
	private String titlePcSub;
	/**
	 * 后台展示商铺图片
	 */
	public String[] getImgArray() {
		if (StringUtils.isEmpty(imgs)) {
			return null;
		} else {
			return imgs.split(",");
		}
	}
	
	/**
	 * 后台展示商铺图片
	 */
	public String[] getPlaneImgArray() {
		if (StringUtils.isEmpty(planeImg)) {
			return null;
		} else {
			return planeImg.split(",");
		}
	}
	
	/**
	 * 后台展示商铺图片
	 */
	public String[] getPositionImgArray() {
		if (StringUtils.isEmpty(positionImg)) {
			return null;
		} else {
			return positionImg.split(",");
		}
	}
	
	/**
	 * 后台展示委托图片
	 */
	public String[] getEntrustPaperArray() {
		if (StringUtils.isEmpty(entrustPaper)) {
			return null;
		} else {
			return entrustPaper.split(",");
		}
	}
	
	public String[] getEntrustImgArray() {
		if (StringUtils.isEmpty(entrustImg)) {
			return null;
		} else {
			return entrustImg.split(",");
		}
	}

	/**
	 * 后台展示委托图片
	 */
	public String[] getPaperImgsPaperArray() {
		if (StringUtils.isEmpty(paperImgs)) {
			return null;
		} else {
			return paperImgs.split(",");
		}
	}

	/**
	 * 后台展示展示平面图
	 */
	public String[] getPlaneImgPaperArray() {
		if (StringUtils.isEmpty(planeImg)) {
			return null;
		} else {
			return planeImg.split(",");
		}
	}

	/**
	 * 展示图片
	 */
	public String[] getPaperImgArray() {
		if (StringUtils.isEmpty(paperImgs)) {
			return null;
		} else {
			List<String> list = Lists.newArrayList();
			Stream.of(paperImgs.split(",")).forEach(s -> {
				if (s.contains("aliyuncs") && !s.contains("x-oss-process")) {
					s += "?x-oss-process=style/watermark";
				} else if (!s.contains("aliyuncs")) {
					s = "https://static.youpuchina.com" + s;
				}
				list.add(s);
			});
			return list.toArray(new String[] {});
		}
	}
	
	/**
	 * 前天展示图片
	 * 
	 * @return
	 */
	public String[] getImgStyleArray() {
		if (StringUtils.isEmpty(imgs)) {
			return null;
		} else {
			List<String> list = Lists.newArrayList();
			Stream.of(imgs.split(",")).forEach(s -> {
				if (s.contains("aliyuncs")) {
					s = s.replace("up-img.oss-cn-beijing.aliyuncs.com", "cdn.youpuchina.com");
					if (!s.contains("x-oss-process")) {
						s += "?x-oss-process=style/watermark";
					}
				}
				list.add(s);
			});
			return list.toArray(new String[] {});
		}
	}
	
	/**
	 * 核实
	 */
	private Integer shopVerify;	//1:待核实 2:通过 3:拒绝
	
	private Date verifyTime;
	
	private Long verifyAccountId;
	
	/**
	 * 审核认领
	 */
	private Long claimAuditAccountId;	//审核认领人
	private User claimAuditAccount;
	
	private Date claimAuditTime;		  //审核认领时间
	
	private Integer claimStatus;	//查询传值用

	/**
	 * 审核
	 */
	private Integer shopAudit;	//1:待审核 2:通过 3:拒绝
	
	private Date auditTime;
	
	private Long auditAccountId;
	private User auditAccount;
	
	//审核次数
	private Integer auditNum;
	
	
	/**
	 * 链接地址
	 */
	private String keyUrl;

	/**
	 * 链接地址MD5值
	 */
	private String keyUrlMd5;

	/**
	 * 爬虫时间
	 */
	private Date crawlerDate;

	private String areaName;

	
	
	private String invalidReason;

	/**
	 * 爬虫数据商铺编号(乐铺)
	 */
	private String crawlerShopNumber;
	
	private Date   topBeginTime;
	private String topStatus;

	//传参参数
	private String provinceId;
	
	private Long jiafangUserId;
	private String jiafangUserName;
	private Long jiedaiUserId;
	private String jiedaiUserName;
	private Long weihuUserId;
	private String weihuUserName;
	
	private Long jiafangOld;
	private Long jiedaiOld;
	private Long weihuOld;
	
	
	//查询传参
	private Integer buildArea0;
	private Integer buildArea1;
	private BigDecimal monthlyRent0;
	private BigDecimal monthlyRent1;
	private String labe;
	
	private String userId;
	private int listType; //列表页面 1:待认领列表 2：待审核列表 3：商铺管理列表
	private Integer timeType;
	//查询优化
	private int isQuery;
	

}
