package com.up.mls.vo.system;

import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Objects;

import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import com.google.common.collect.Lists;
import com.up.mls.vo.BaseEntity;

import lombok.Getter;
import lombok.Setter;

/**
 * 用户对象 sys_user
 * 
 * @author j.x.j
 */
@Getter
@Setter
public class User extends BaseEntity implements UserDetails {

	private static final long serialVersionUID = 1L;

	/** 用户ID */
	private Long userId;

	/** 部门ID */
	private Long deptId;

	/** 部门父ID */
	private Long parentId;

	/** 登录名称 */
	private String loginName;

	/** 用户名称 */
	private String userName;

	/** 用户邮箱 */
	private String email;

	/** 手机号码 */
	private String phonenumber;

	/** 用户性别 */
	private String sex;

	/** 用户头像 */
	private String avatar;

	/** 密码 */
	private String password;

	// /** 盐加密 */
	// private String salt;

	/** 帐号状态（0正常 1停用） */
	private Integer status;

	/** 删除标志（0代表存在 2代表删除） */
	private String delFlag;

	/** 最后登陆IP */
	private String loginIp;

	/** 最后登陆时间 */
	private Date loginDate;

	/** 部门对象 */
	private Dept dept;
	
	/**公司对象**/
	private Company company;

	/** 角色组 */
	private Long[] roleIds;

	/** 岗位组 */
	private Long[] postIds;

	/** 公司外键 **/
	private Long companyId;

	private List<Role> roles;
	
	private String beginTime;
	private String endTime;
	
	private String auditName;
	

	public boolean isAdmin() {
		return isAdmin(this.userId);
	}

	public static boolean isAdmin(Long userId) {
		return userId != null && 1L == userId;
	}

	private Collection<? extends GrantedAuthority> authorities = Lists.newArrayList();

	@Override
	public Collection<? extends GrantedAuthority> getAuthorities() {
		return authorities;
	}

	// 账号未过期
	@Override
	public boolean isAccountNonExpired() {
		return Boolean.TRUE;
	}

	// 账号是否未锁定
	@Override
	public boolean isAccountNonLocked() {
		return Boolean.TRUE;
	}

	// 账号凭证是否未过期
	@Override
	public boolean isCredentialsNonExpired() {
		return Boolean.TRUE;
	}

	// 账号启用 true:启用 可以登录 false:无法登录
	@Override
	public boolean isEnabled() {
		if (Objects.isNull(status)) {
			return Boolean.TRUE;
		} else {
			if (0 == status) {
				return Boolean.TRUE;
			}
			return Boolean.FALSE;
		}
	}

	@Override
	public String toString() {
		return "User [userId=" + userId + ", deptId=" + deptId + ", parentId=" + parentId + ", loginName=" + loginName
				+ ", userName=" + userName + ", email=" + email + ", phonenumber=" + phonenumber + ", sex=" + sex
				+ ", avatar=" + avatar + ", password=" + password + ", status=" + status + ", delFlag=" + delFlag
				+ ", loginIp=" + loginIp + ", loginDate=" + loginDate + ", dept=" + dept + ", roleIds="
				+ Arrays.toString(roleIds) + ", postIds=" + Arrays.toString(postIds) + "]";
	}

	@Override
	public String getUsername() {
		return loginName;
	}

	public void setAuthorities(Collection<? extends GrantedAuthority> authorities) {
		this.authorities = authorities;
	}

	public String getUserName() {
		return userName;
	}


}
